@@ -1,7 +1,6 @@
 import logging
-from typing import List
 
-from genologics.entities import Container, Containertype, Project, Researcher, Sample
+from genologics.entities import Container, Containertype, Project, Sample
 from lxml import etree
 from lxml.objectify import ObjectifiedElement
 
@@ -49,14 +48,12 @@ class OrderHandler:
         results = self.save_xml(artifact_uri, artifact_details)
         return results
 
-    def submit_project(self, project_name: str, samples: List[dict], researcher_id: str = "3"):
+    def submit_project(self, project_name: str, samples: list[dict]):
         """Parse Scout project."""
         containers = self.prepare(samples)
 
-        lims_project = Project.create(
-            self, researcher=Researcher(self, id=researcher_id), name=project_name
-        )
-        LOG.info("%s: created new LIMS project", lims_project.id)
+        lims_project = Project.create(self, researcher=self.user, name=project_name)
+        LOG.info(f"{lims_project.id}: created new LIMS project")
 
         containers_data = [
             batch.build_container(
@@ -65,7 +62,7 @@ class OrderHandler:
             for container in containers
         ]
         container_details = batch.build_container_batch(containers_data)
-        LOG.debug("%s: saving containers", lims_project.name)
+        LOG.debug(f"{lims_project.name}: saving containers")
         container_map = self.save_containers(container_details)
 
         reagentlabel_samples = [
@@ -78,7 +75,7 @@ class OrderHandler:
         samples_data = []
         for container in containers:
             for sample in container["samples"]:
-                LOG.debug("%s: adding sample to container: %s", sample["name"], container["name"])
+                LOG.debug(f"{sample['name']}: adding sample to container: {container['name']}")
                 lims_container = container_map[container["name"]]
                 sample_data = batch.build_sample(
                     name=sample["name"],
