@@ -1,18 +1,24 @@
-""" Trailblazer API for cg """ ""
+""" Trailblazer API for cg."""
+
 import datetime
-import datetime as dt
 import logging
-from typing import Any, Optional
+from typing import Any
 
 from google.auth import jwt
 from google.auth.crypt import RSASigner
 
-from cg.apps.tb.models import TrailblazerAnalysis
-from cg.constants import Pipeline
-from cg.constants.constants import APIMethods, FileFormat, WorkflowManager
+from cg.apps.tb.dto.create_job_request import CreateJobRequest
+from cg.apps.tb.dto.summary_response import AnalysisSummary, SummariesResponse
+from cg.apps.tb.models import AnalysesResponse, TrailblazerAnalysis
+from cg.constants import Workflow
+from cg.constants.constants import APIMethods, FileFormat, JobType, WorkflowManager
 from cg.constants.priority import SlurmQos
 from cg.constants.tb import AnalysisStatus
-from cg.exc import TrailblazerAPIHTTPError
+from cg.exc import (
+    AnalysisNotCompletedError,
+    TrailblazerAnalysisNotFound,
+    TrailblazerAPIHTTPError,
+)
 from cg.io.controller import APIRequest, ReadStream
 
 LOG = logging.getLogger(__name__)
@@ -51,7 +57,7 @@ class TrailblazerAPI:
     def query_trailblazer(
         self, command: str, request_body: dict, method: str = APIMethods.POST
     ) -> Any:
-        url = self.host + "/" + command
+        url = f"{self.host}/{command}"
         LOG.debug(f"REQUEST HEADER {self.auth_header}")
         LOG.debug(f"{method}: URL={url}; JSON={request_body}")
 
@@ -67,46 +73,23 @@ class TrailblazerAPI:
         LOG.debug(f"RESPONSE BODY {response.text}")
         return ReadStream.get_content_from_stream(file_format=FileFormat.JSON, stream=response.text)
 
-    def analyses(
-        self,
-        case_id: str = None,
-        query: str = None,
-        status: str = None,
-        deleted: bool = None,
-        temp: bool = False,
-        before: dt.datetime = None,
-        is_visible: bool = None,
-        family: str = None,
-        data_analysis: Pipeline = None,
-    ) -> list:
-        request_body = {
-            "case_id": case_id,
-            "status": status,
-            "query": query,
-            "deleted": deleted,
-            "temp": temp,
-            "before": str(before) if before else None,
-            "is_visible": is_visible,
-            "family": family,
-            "data_analysis": data_analysis.upper() if data_analysis else None,
-        }
-        response = self.query_trailblazer(command="query-analyses", request_body=request_body)
-        if response:
-            if isinstance(response, list):
-                return [TrailblazerAnalysis.parse_obj(analysis) for analysis in response]
-            if isinstance(response, dict):
-                return [TrailblazerAnalysis.parse_obj(response)]
-        return response
+    def get_latest_completed_analysis(self, case_id: str) -> TrailblazerAnalysis | None:
+        endpoint = f"analyses?case_id={case_id}&status[]={AnalysisStatus.COMPLETED}&limit=1"
+        response = self.query_trailblazer(command=endpoint, request_body={}, method=APIMethods.GET)
+        validated_response = AnalysesResponse.model_validate(response)
+        if validated_response.analyses:
+            return validated_response.analyses[0]
+        raise TrailblazerAnalysisNotFound(f"No completed analysis found for case {case_id}")
 
-    def get_latest_analysis(self, case_id: str) -> Optional[TrailblazerAnalysis]:
+    def get_latest_analysis(self, case_id: str) -> TrailblazerAnalysis | None:
         request_body = {
             "case_id": case_id,
         }
         response = self.query_trailblazer(command="get-latest-analysis", request_body=request_body)
         if response:
-            return TrailblazerAnalysis.parse_obj(response)
+            return TrailblazerAnalysis.model_validate(response)
 
-    def get_latest_analysis_status(self, case_id: str) -> Optional[str]:
+    def get_latest_analysis_status(self, case_id: str) -> str | None:
         latest_analysis = self.get_latest_analysis(case_id=case_id)
         if latest_analysis:
             return latest_analysis.status
@@ -123,20 +106,6 @@ class TrailblazerAPI:
     def is_latest_analysis_qc(self, case_id: str) -> bool:
         return self.get_latest_analysis_status(case_id=case_id) == AnalysisStatus.QC
 
-    def mark_analyses_deleted(self, case_id: str) -> Optional[list]:
-        """Mark all analyses for case deleted without removing analysis files"""
-        request_body = {
-            "case_id": case_id,
-        }
-        response = self.query_trailblazer(
-            command="mark-analyses-deleted", request_body=request_body
-        )
-        if response:
-            if isinstance(response, list):
-                return [TrailblazerAnalysis.parse_obj(analysis) for analysis in response]
-            if isinstance(response, dict):
-                return [TrailblazerAnalysis.parse_obj(response)]
-
     def add_pending_analysis(
         self,
         case_id: str,
@@ -145,7 +114,8 @@ class TrailblazerAPI:
         out_dir: str,
         slurm_quality_of_service: SlurmQos,
         email: str = None,
-        data_analysis: Pipeline = None,
+        order_id: int | None = None,
+        workflow: Workflow = None,
         ticket: str = None,
         workflow_manager: str = WorkflowManager.Slurm,
     ) -> TrailblazerAnalysis:
@@ -154,16 +124,18 @@ class TrailblazerAPI:
             "email": email,
             "type": analysis_type,
             "config_path": config_path,
+            "order_id": order_id,
             "out_dir": out_dir,
             "priority": slurm_quality_of_service,
-            "data_analysis": str(data_analysis).upper(),
+            "workflow": workflow.upper(),
             "ticket": ticket,
             "workflow_manager": workflow_manager,
         }
-        LOG.debug("Submitting job to Trailblazer: %s", request_body)
-        response = self.query_trailblazer(command="add-pending-analysis", request_body=request_body)
-        if response:
-            return TrailblazerAnalysis.parse_obj(response)
+        LOG.debug(f"Submitting job to Trailblazer: {request_body}")
+        if response := self.query_trailblazer(
+            command="add-pending-analysis", request_body=request_body
+        ):
+            return TrailblazerAnalysis.model_validate(response)
 
     def set_analysis_uploaded(self, case_id: str, uploaded_at: datetime) -> None:
         """Set a uploaded at date for a trailblazer analysis."""
@@ -194,3 +166,35 @@ class TrailblazerAPI:
         self.query_trailblazer(
             command="add-comment", request_body=request_body, method=APIMethods.PUT
         )
+
+    def add_upload_job_to_analysis(self, analysis_id: int, slurm_id: int) -> None:
+        create_request = CreateJobRequest(slurm_id=slurm_id, job_type=JobType.UPLOAD)
+        request_body: dict = create_request.model_dump()
+        self.query_trailblazer(
+            command=f"/analysis/{analysis_id}/jobs",
+            request_body=request_body,
+            method=APIMethods.POST,
+        )
+
+    def get_summaries(self, order_ids: list[int]) -> list[AnalysisSummary]:
+        orders_param = "orderIds=" + ",".join(map(str, order_ids))
+        endpoint = f"summary?{orders_param}"
+        response = self.query_trailblazer(command=endpoint, request_body={}, method=APIMethods.GET)
+        response_data = SummariesResponse.model_validate(response)
+        return response_data.summaries
+
+    def get_analyses_to_deliver(self, order_id: int) -> list[TrailblazerAnalysis]:
+        """Return the analyses in the order ready to be delivered."""
+        endpoint = (
+            f"analyses?orderId={order_id}&status[]={AnalysisStatus.COMPLETED}&delivered=false"
+        )
+        raw_response = self.query_trailblazer(
+            command=endpoint, request_body={}, method=APIMethods.GET
+        )
+        validated_response = AnalysesResponse.model_validate(raw_response)
+        return validated_response.analyses
+
+    def verify_latest_analysis_is_completed(self, case_id: str, force: bool = False) -> None:
+        """Raises an AnalysisNotCompletedError if the latest analysis for the case has not completed."""
+        if not self.is_latest_analysis_completed(case_id) and not force:
+            raise AnalysisNotCompletedError(f"The latest analysis for {case_id} has not completed.")
