@@ -1,38 +1,57 @@
 """ Start of CLI """
-from pathlib import Path
 
 import logging
 import sys
-from typing import Optional
+from pathlib import Path
 
-import cg
 import click
 import coloredlogs
-from cg.cli.delete.base import delete
-from cg.cli.set.base import set_cmd
-from cg.constants.constants import FileFormat
-from cg.cli.store.store import store as store_cmd
-from cg.io.controller import ReadFile
-from cg.models.cg_config import CGConfig
-from cg.store import Store
+from sqlalchemy.orm import scoped_session
 
+import cg
+from cg.cli.sequencing_qc.sequencing_qc import sequencing_qc
+from cg.cli.validate import validate
 from cg.cli.add import add as add_cmd
+from cg.cli.archive import archive
 from cg.cli.backup import backup
 from cg.cli.clean import clean
 from cg.cli.compress.base import compress, decompress
+from cg.cli.delete.base import delete
 from cg.cli.deliver.base import deliver as deliver_cmd
 from cg.cli.demultiplex.base import demultiplex_cmd_group as demultiplex_cmd
+from cg.cli.downsample import downsample
+from cg.cli.generate.base import generate as generate_cmd
 from cg.cli.get import get
+from cg.cli.set.base import set_cmd
+from cg.cli.store.base import store as store_cmd
 from cg.cli.transfer import transfer_group
 from cg.cli.upload.base import upload
+from cg.cli.utils import CLICK_CONTEXT_SETTINGS
+from cg.cli.validate import validate
 from cg.cli.workflow.base import workflow as workflow_cmd
-from cg.cli.generate.base import generate as generate_cmd
+from cg.constants.cli_options import FORCE
+from cg.constants.constants import FileFormat
+from cg.io.controller import ReadFile
+from cg.models.cg_config import CGConfig
+from cg.store.database import (
+    create_all_tables,
+    drop_all_tables,
+    get_scoped_session_registry,
+    get_tables,
+)
 
 LOG = logging.getLogger(__name__)
 LEVELS = ["DEBUG", "INFO", "WARNING", "ERROR"]
 
 
-@click.group()
+def teardown_session():
+    """Ensure that the session is closed and all resources are released to the connection pool."""
+    registry: scoped_session | None = get_scoped_session_registry()
+    if registry:
+        registry.remove()
+
+
+@click.group(context_settings=CLICK_CONTEXT_SETTINGS)
 @click.option("-c", "--config", type=click.Path(exists=True), help="path to config file")
 @click.option("-d", "--database", help="path/URI of the SQL database")
 @click.option(
@@ -44,7 +63,7 @@ LEVELS = ["DEBUG", "INFO", "WARNING", "ERROR"]
 def base(
     context: click.Context,
     config: click.Path,
-    database: Optional[str],
+    database: str | None,
     log_level: str,
     verbose: bool,
 ):
@@ -61,30 +80,31 @@ def base(
         else {"database": database}
     )
     context.obj = CGConfig(**raw_config)
+    context.call_on_close(teardown_session)
 
 
 @base.command()
-@click.option("--reset", is_flag=True, help="reset database before setting up tables")
-@click.option("--force", is_flag=True, help="bypass manual confirmations")
+@click.option("--reset", is_flag=True, help="Reset database before setting up tables")
+@FORCE
 @click.pass_obj
 def init(context: CGConfig, reset: bool, force: bool):
     """Setup the database."""
-    status_db: Store = context.status_db
-    existing_tables = status_db.engine.table_names()
+    existing_tables: list[str] = get_tables()
     if force or reset:
         if existing_tables and not force:
             message = f"Delete existing tables? [{', '.join(existing_tables)}]"
             click.confirm(click.style(message, fg="yellow"), abort=True)
-        status_db.drop_all()
+        drop_all_tables()
     elif existing_tables:
         LOG.error("Database already exists, use '--reset'")
         raise click.Abort
 
-    status_db.create_all()
-    LOG.info("Success! New tables: %s", ", ".join(status_db.engine.table_names()))
+    create_all_tables()
+    LOG.info(f"Success! New tables: {', '.join(get_tables())}")
 
 
 base.add_command(add_cmd)
+base.add_command(archive)
 base.add_command(backup)
 base.add_command(clean)
 base.add_command(compress)
@@ -99,3 +119,6 @@ base.add_command(store_cmd)
 base.add_command(deliver_cmd)
 base.add_command(demultiplex_cmd)
 base.add_command(generate_cmd)
+base.add_command(downsample)
+base.add_command(validate)
+base.add_command(sequencing_qc)
