@@ -2,13 +2,13 @@
 
 import datetime
 import logging
-from typing import List
 
 import click
+
 from cg.cli.get import get_case as print_case
-from cg.constants.constants import DRY_RUN, SKIP_CONFIRMATION
-from cg.store import Store
-from cg.store.models import Sample, Family
+from cg.constants.cli_options import DRY_RUN, SKIP_CONFIRMATION
+from cg.store.models import Case, Sample
+from cg.store.store import Store
 
 LOG = logging.getLogger(__name__)
 
@@ -18,7 +18,7 @@ LOG = logging.getLogger(__name__)
 @DRY_RUN
 @SKIP_CONFIRMATION
 @click.pass_context
-def delete_case(context: click.Context, case_id: str, dry_run: bool, yes: bool):
+def delete_case(context: click.Context, case_id: str, dry_run: bool, skip_confirmation: bool):
     """Delete case with links and samples.
 
     The command will stop if the case has any analyses made on it.
@@ -29,7 +29,7 @@ def delete_case(context: click.Context, case_id: str, dry_run: bool, yes: bool):
     sample.
     """
     status_db: Store = context.obj.status_db
-    case: Family = status_db.get_case_by_internal_id(internal_id=case_id)
+    case: Case = status_db.get_case_by_internal_id(internal_id=case_id)
     if not case:
         LOG.error(f"Could not find case {case_id}")
         raise click.Abort
@@ -40,13 +40,15 @@ def delete_case(context: click.Context, case_id: str, dry_run: bool, yes: bool):
     context.invoke(print_case, case_ids=[case_id])
 
     if case.links and not (
-        yes or click.confirm(f"Case {case_id} has links: {case.links}, continue?")
+        skip_confirmation or click.confirm(f"Case {case_id} has links: {case.links}, continue?")
     ):
         raise click.Abort
 
-    _delete_links_and_samples(case_obj=case, dry_run=dry_run, status_db=status_db, yes=yes)
+    _delete_links_and_samples(
+        case_obj=case, dry_run=dry_run, status_db=status_db, skip_confirmation=skip_confirmation
+    )
 
-    if not (yes or click.confirm(f"Do you want to DELETE case: {case}?")):
+    if not (skip_confirmation or click.confirm(f"Do you want to DELETE case: {case}?")):
         raise click.Abort
 
     if dry_run:
@@ -58,38 +60,42 @@ def delete_case(context: click.Context, case_id: str, dry_run: bool, yes: bool):
     status_db.session.commit()
 
 
-def _delete_links_and_samples(case_obj: Family, dry_run: bool, status_db: Store, yes: bool):
+def _delete_links_and_samples(
+    case_obj: Case, dry_run: bool, status_db: Store, skip_confirmation: bool
+):
     """Delete all links from a case to samples"""
-    samples_to_delete: List[Sample] = []
+    samples_to_delete: list[Sample] = []
     for case_link in case_obj.links:
-        if not (yes or click.confirm(f"Do you want to DELETE link: {case_link}?")):
+        if not (skip_confirmation or click.confirm(f"Do you want to DELETE link: {case_link}?")):
             raise click.Abort
 
         samples_to_delete.append(case_link.sample)
 
         if dry_run:
-            LOG.info("Link: %s was NOT deleted due to --dry-run", case_link)
+            LOG.info(f"Link: {case_link} was NOT deleted due to --dry-run")
         else:
-            LOG.info("Deleting link: %s", case_link)
+            LOG.info(f"Deleting link: {case_link}")
             status_db.session.delete(case_link)
             status_db.session.commit()
 
     for sample in samples_to_delete:
-        _delete_sample(dry_run=dry_run, sample=sample, status_db=status_db, yes=yes)
+        _delete_sample(
+            dry_run=dry_run, sample=sample, status_db=status_db, skip_confirmation=skip_confirmation
+        )
 
 
-def _delete_sample(dry_run: bool, sample: Sample, status_db: Store, yes: bool):
+def _delete_sample(dry_run: bool, sample: Sample, status_db: Store, skip_confirmation: bool):
     if _has_sample_been_lab_processed(sample):
         _log_sample_process_information(sample)
         return
 
     if _is_sample_linked(sample):
-        LOG.info("Can NOT delete sample: %s", sample.internal_id)
+        LOG.info(f"Can NOT delete sample: {sample.internal_id}")
         _log_sample_links(sample)
         return
 
     if not (
-        yes
+        skip_confirmation
         or click.confirm(
             f"Sample {sample.internal_id} is not linked to anything, "
             f"do you want to DELETE sample:"
@@ -99,36 +105,36 @@ def _delete_sample(dry_run: bool, sample: Sample, status_db: Store, yes: bool):
         return
 
     if dry_run:
-        LOG.info("Sample: %s was NOT deleted due to --dry-run", sample)
+        LOG.info(f"Sample: {sample} was NOT deleted due to --dry-run")
         return
 
-    LOG.info("Deleting sample: %s", sample)
+    LOG.info(f"Deleting sample: {sample}")
     status_db.session.delete(sample)
 
 
 def _log_sample_process_information(sample: Sample):
-    LOG.info("Can NOT delete processed sample: %s", sample.internal_id)
-    LOG.info("Sample was received: %s", sample.received_at)
-    LOG.info("Sample was prepared: %s", sample.prepared_at)
-    LOG.info("Sample was sequenced: %s", sample.sequenced_at)
-    LOG.info("Sample was delivered: %s", sample.delivered_at)
-    LOG.info("Sample has invoice: %s", sample.invoice_id)
+    LOG.info(f"Can NOT delete processed sample: {sample.internal_id}")
+    LOG.info(f"Sample was received: {sample.received_at}")
+    LOG.info(f"Sample was prepared: {sample.prepared_at}")
+    LOG.info(f"Sample's reads were updated: {sample.last_sequenced_at}")
+    LOG.info(f"Sample was delivered: {sample.delivered_at}")
+    LOG.info(f"Sample has invoice: {sample.invoice_id}")
 
 
 def _log_sample_links(sample: Sample):
     for sample_link in sample.links:
-        LOG.info("Sample is linked to: %s", sample_link.family.internal_id)
+        LOG.info(f"Sample is linked to: {sample_link.case.internal_id}")
     for sample_link in sample.mother_links:
-        LOG.info("Sample is linked as mother to: %s", sample_link.mother.internal_id)
+        LOG.info(f"Sample is linked as mother to: {sample_link.mother.internal_id}")
     for sample_link in sample.father_links:
-        LOG.info("Sample is linked as father to: %s", sample_link.father.internal_id)
+        LOG.info(f"Sample is linked as father to: {sample_link.father.internal_id}")
 
 
 def _has_sample_been_lab_processed(sample: Sample) -> datetime.datetime:
     return (
         sample.received_at
         or sample.prepared_at
-        or sample.sequenced_at
+        or sample.last_sequenced_at
         or sample.delivered_at
         or sample.invoice_id
     )
