@@ -1,22 +1,25 @@
 """CLI for delivering files with CG"""
+
 import logging
 from pathlib import Path
-from typing import List, Optional
 
 import click
-from cg.meta.rsync.rsync_api import RsyncAPI
-from cg.apps.tb import TrailblazerAPI
-from cg.constants.delivery import PIPELINE_ANALYSIS_OPTIONS, PIPELINE_ANALYSIS_TAG_MAP
-from cg.meta.deliver import DeliverAPI
-from cg.meta.deliver_ticket import DeliverTicketAPI
 
+from cg.apps.tb import TrailblazerAPI
+from cg.cli.utils import CLICK_CONTEXT_SETTINGS
+from cg.constants.cli_options import DRY_RUN
+from cg.constants.delivery import PIPELINE_ANALYSIS_OPTIONS, PIPELINE_ANALYSIS_TAG_MAP
+from cg.meta.deliver import DeliverAPI, DeliverTicketAPI
+from cg.meta.rsync.rsync_api import RsyncAPI
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from cg.store.models import Family
+from cg.services.fastq_concatenation_service.fastq_concatenation_service import (
+    FastqConcatenationService,
+)
+from cg.store.models import Case
+from cg.store.store import Store
 
 LOG = logging.getLogger(__name__)
 
-DRY_RUN = click.option("--dry-run", is_flag=True)
 DELIVERY_TYPE = click.option(
     "-d",
     "--delivery-type",
@@ -43,7 +46,7 @@ IGNORE_MISSING_BUNDLES = click.option(
 )
 
 
-@click.group()
+@click.group(context_settings=CLICK_CONTEXT_SETTINGS)
 def deliver():
     """Deliver files with CG."""
     LOG.info("Running CG deliver")
@@ -61,9 +64,9 @@ def deliver():
 @click.pass_obj
 def deliver_analysis(
     context: CGConfig,
-    case_id: Optional[str],
-    ticket: Optional[str],
-    delivery_type: List[str],
+    case_id: str | None,
+    ticket: str | None,
+    delivery_type: list[str],
     dry_run: bool,
     force_all: bool,
     ignore_missing_bundles: bool,
@@ -93,19 +96,20 @@ def deliver_analysis(
             delivery_type=delivery,
             force_all=force_all,
             ignore_missing_bundles=ignore_missing_bundles,
+            fastq_file_service=FastqConcatenationService(),
         )
         deliver_api.set_dry_run(dry_run)
-        cases: List[Family] = []
+        cases: list[Case] = []
         if case_id:
-            case_obj: Family = status_db.get_case_by_internal_id(internal_id=case_id)
+            case_obj: Case = status_db.get_case_by_internal_id(internal_id=case_id)
             if not case_obj:
-                LOG.warning("Could not find case %s", case_id)
+                LOG.warning(f"Could not find case {case_id}")
                 return
             cases.append(case_obj)
         else:
-            cases: List[Family] = status_db.get_cases_by_ticket_id(ticket_id=ticket)
+            cases: list[Case] = status_db.get_cases_by_ticket_id(ticket_id=ticket)
             if not cases:
-                LOG.warning("Could not find cases for ticket %s", ticket)
+                LOG.warning(f"Could not find cases for ticket {ticket}")
                 return
 
         for case_obj in cases:
@@ -123,7 +127,7 @@ def rsync(context: CGConfig, ticket: str, dry_run: bool):
     tb_api: TrailblazerAPI = context.trailblazer_api
     rsync_api: RsyncAPI = RsyncAPI(config=context)
     slurm_id = rsync_api.run_rsync_on_slurm(ticket=ticket, dry_run=dry_run)
-    LOG.info("Rsync to the delivery server running as job %s", slurm_id)
+    LOG.info(f"Rsync to the delivery server running as job {slurm_id}")
     rsync_api.add_to_trailblazer_api(
         tb_api=tb_api, slurm_job_id=slurm_id, ticket=ticket, dry_run=dry_run
     )
@@ -139,7 +143,7 @@ def concatenate(context: click.Context, ticket: str, dry_run: bool):
     """
     cg_context: CGConfig = context.obj
     deliver_ticket_api = DeliverTicketAPI(config=cg_context)
-    deliver_ticket_api.concatenate(ticket=ticket, dry_run=dry_run)
+    deliver_ticket_api.concatenate_fastq_files(ticket=ticket, dry_run=dry_run)
 
 
 @deliver.command(name="ticket")
@@ -157,7 +161,7 @@ def concatenate(context: click.Context, ticket: str, dry_run: bool):
 @click.pass_context
 def deliver_ticket(
     context: click.Context,
-    delivery_type: List[str],
+    delivery_type: list[str],
     dry_run: bool,
     force_all: bool,
     ticket: str,
@@ -183,10 +187,6 @@ def deliver_ticket(
     else:
         LOG.info("Files already delivered to customer inbox on the HPC")
         return
-    is_concatenation_needed: bool = deliver_ticket_api.check_if_concatenation_is_needed(
-        ticket=ticket
-    )
-    if is_concatenation_needed and "fastq" in delivery_type:
-        context.invoke(concatenate, ticket=ticket, dry_run=dry_run)
+
     deliver_ticket_api.report_missing_samples(ticket=ticket, dry_run=dry_run)
     context.invoke(rsync, ticket=ticket, dry_run=dry_run)
