@@ -1,27 +1,28 @@
 """Set data in the status database and LIMS."""
+
 import datetime
 import getpass
 import logging
-from typing import Iterable, List, Optional
+from typing import Iterable
 
 import click
-from cg.cli.set.cases import set_cases
+
 from cg.cli.set.case import set_case
-from cg.constants import FLOWCELL_STATUS
+from cg.cli.set.cases import set_cases
+from cg.cli.utils import CLICK_CONTEXT_SETTINGS
+from cg.constants import SequencingRunDataAvailability
+from cg.constants.cli_options import SKIP_CONFIRMATION
 from cg.exc import LimsDataError
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from cg.store.models import Sample, Customer, ApplicationVersion, Flowcell
+from cg.store.models import ApplicationVersion, Customer, IlluminaSequencingRun, Sample
+from cg.store.store import Store
 
 CONFIRM = "Continue?"
 HELP_KEY_VALUE = "Give a property on sample and the value to set it to, e.g. -kv name Prov52"
 HELP_SKIP_LIMS = "Skip setting value in LIMS"
-HELP_YES = "Answer yes on all confirmations"
 OPTION_LONG_KEY_VALUE = "--key-value"
 OPTION_LONG_SKIP_LIMS = "--skip-lims"
-OPTION_LONG_YES = "--yes"
 OPTION_SHORT_KEY_VALUE = "-kv"
-OPTION_SHORT_YES = "-y"
 NOT_CHANGEABLE_SAMPLE_ATTRIBUTES = [
     "application_version_id",
     "customer_id",
@@ -40,7 +41,7 @@ NOT_CHANGEABLE_SAMPLE_ATTRIBUTES = [
 LOG = logging.getLogger(__name__)
 
 
-@click.group("set")
+@click.group("set", context_settings=CLICK_CONTEXT_SETTINGS)
 def set_cmd():
     """Update information in the database."""
     pass
@@ -66,7 +67,7 @@ def set_cmd():
     help="Give a property on sample and the value to set it to, e.g. -kv name Prov52",
 )
 @click.option("--skip-lims", is_flag=True, help="Skip setting value in LIMS")
-@click.option("-y", "--yes", is_flag=True, help="Answer yes on all confirmations")
+@SKIP_CONFIRMATION
 @click.argument("case_id", required=False)
 @click.pass_context
 def samples(
@@ -74,12 +75,12 @@ def samples(
     identifiers: click.Tuple([str, str]),
     kwargs: click.Tuple([str, str]),
     skip_lims: bool,
-    yes: bool,
+    skip_confirmation: bool,
     case_id: str,
 ):
     """Set values on many samples at the same time."""
     store: Store = context.obj.status_db
-    sample_objs: List[Sample] = _get_samples(case_id=case_id, identifiers=identifiers, store=store)
+    sample_objs: list[Sample] = _get_samples(case_id=case_id, identifiers=identifiers, store=store)
 
     if not sample_objs:
         LOG.error("No samples to alter!")
@@ -90,25 +91,29 @@ def samples(
     for sample_obj in sample_objs:
         LOG.info(f"{sample_obj}")
 
-    if not (yes or click.confirm(CONFIRM)):
+    if not (skip_confirmation or click.confirm(CONFIRM)):
         raise click.Abort
 
     for sample_obj in sample_objs:
         context.invoke(
-            sample, sample_id=sample_obj.internal_id, kwargs=kwargs, yes=yes, skip_lims=skip_lims
+            sample,
+            sample_id=sample_obj.internal_id,
+            kwargs=kwargs,
+            skip_confirmation=skip_confirmation,
+            skip_lims=skip_lims,
         )
 
 
-def _get_samples(case_id: str, identifiers: click.Tuple([str, str]), store: Store) -> List[Sample]:
+def _get_samples(case_id: str, identifiers: click.Tuple([str, str]), store: Store) -> list[Sample]:
     """Get samples that match both case_id and identifiers if given."""
     samples_by_case_id = None
     samples_by_id = None
 
     if case_id:
-        samples_by_case_id: List[Sample] = store.get_samples_by_case_id(case_id=case_id)
+        samples_by_case_id: list[Sample] = store.get_samples_by_case_id(case_id=case_id)
 
     if identifiers:
-        samples_by_id: List[Sample] = _get_samples_by_identifiers(identifiers, store)
+        samples_by_id: list[Sample] = _get_samples_by_identifiers(identifiers, store)
 
     if case_id and identifiers:
         sample_objs = set(set(samples_by_case_id) & set(samples_by_id))
@@ -118,7 +123,7 @@ def _get_samples(case_id: str, identifiers: click.Tuple([str, str]), store: Stor
     return sample_objs
 
 
-def _get_samples_by_identifiers(identifiers: click.Tuple([str, str]), store: Store) -> List[Sample]:
+def _get_samples_by_identifiers(identifiers: click.Tuple([str, str]), store: Store) -> list[Sample]:
     """Get samples matched by given set of identifiers."""
     identifier_args = {
         identifier_name: identifier_value for identifier_name, identifier_value in identifiers
@@ -127,7 +132,7 @@ def _get_samples_by_identifiers(identifiers: click.Tuple([str, str]), store: Sto
     return list(store.get_samples_by_any_id(**identifier_args))
 
 
-def is_locked_attribute_on_sample(key: str, skip_attributes: List[str]) -> bool:
+def is_locked_attribute_on_sample(key: str, skip_attributes: list[str]) -> bool:
     """Returns true if the attribute is private or in the skip list."""
     return is_private_attribute(key) or key in skip_attributes
 
@@ -138,10 +143,10 @@ def is_private_attribute(key: str) -> bool:
 
 
 def list_changeable_sample_attributes(
-    sample: Optional[Sample] = None, skip_attributes: List[str] = []
+    sample: Sample | None = None, skip_attributes: list[str] = []
 ) -> None:
     """List changeable attributes on sample and its current value."""
-    LOG.info(f"Below is a set of changeable sample attributes, to combine with -kv flag:\n")
+    LOG.info("Below is a set of changeable sample attributes, to combine with -kv flag:\n")
 
     sample_attributes: Iterable[str] = Sample.__dict__.keys()
     for attribute in sample_attributes:
@@ -158,7 +163,7 @@ def list_changeable_sample_attributes(
 @click.pass_obj
 def list_keys(
     context: CGConfig,
-    sample_id: Optional[str],
+    sample_id: str | None,
 ):
     """List all available modifiable keys."""
     status_db: Store = context.status_db
@@ -180,14 +185,14 @@ def list_keys(
     help=HELP_KEY_VALUE,
 )
 @click.option(OPTION_LONG_SKIP_LIMS, is_flag=True, help=HELP_SKIP_LIMS)
-@click.option(OPTION_SHORT_YES, OPTION_LONG_YES, is_flag=True, help=HELP_YES)
+@SKIP_CONFIRMATION
 @click.pass_obj
 def sample(
     context: CGConfig,
-    sample_id: Optional[str],
+    sample_id: str | None,
     kwargs: click.Tuple([str, str]),
     skip_lims: bool,
-    yes: bool,
+    skip_confirmation: bool,
 ):
     """Set key values on a sample.
 
@@ -239,7 +244,7 @@ def sample(
 
         LOG.info(f"Would change from {new_key}={old_value} to {new_key}={new_value} on {sample}")
 
-        if not (yes or click.confirm(CONFIRM)):
+        if not (skip_confirmation or click.confirm(CONFIRM)):
             continue
 
         if key == "comment":
@@ -256,7 +261,7 @@ def sample(
             new_value = sample.priority_human if key == "priority" else value
             LOG.info(f"Would set {new_key} to {new_value} for {sample.internal_id} in LIMS")
 
-            if not (yes or click.confirm(CONFIRM)):
+            if not (skip_confirmation or click.confirm(CONFIRM)):
                 raise click.Abort
 
             try:
@@ -281,23 +286,34 @@ def _update_comment(comment, obj):
             obj.comment = f"{timestamp}-{getpass.getuser()}: {comment}" + "\n" + obj.comment
 
 
-@set_cmd.command()
-@click.option("-s", "--status", type=click.Choice(FLOWCELL_STATUS))
-@click.argument("flow_cell_name")
+@set_cmd.command("sequencing-run")
+@click.option(
+    "-d", "--data-availability", type=click.Choice(SequencingRunDataAvailability.statuses())
+)
+@click.argument("flow_cell_id")
 @click.pass_obj
-def flowcell(context: CGConfig, flow_cell_name: str, status: Optional[str]):
-    """Update information about a flow cell."""
+def set_sequencing_run(context: CGConfig, flow_cell_id: str, data_availability: str):
+    """Update data availability information for a sequencing run."""
     status_db: Store = context.status_db
-    flowcell_obj: Flowcell = status_db.get_flow_cell_by_name(flow_cell_name=flow_cell_name)
+    sequencing_run: IlluminaSequencingRun = (
+        status_db.get_illumina_sequencing_run_by_device_internal_id(flow_cell_id)
+    )
 
-    if flowcell_obj is None:
-        LOG.warning(f"flow cell not found: {flow_cell_name}")
+    if not sequencing_run:
+        LOG.error(f"Sequencing run with {flow_cell_id} not found")
         raise click.Abort
-    prev_status: str = flowcell_obj.status
-    flowcell_obj.status = status
+    if not data_availability:
+        LOG.error(
+            f"Please provide a data availability status. Choose from: {SequencingRunDataAvailability.statuses()}"
+        )
+        raise click.Abort
+    prev_status: str = sequencing_run.data_availability
+    sequencing_run.data_availability = data_availability
 
     status_db.session.commit()
-    LOG.info(f"{flow_cell_name} set: {prev_status} -> {status}")
+    LOG.info(
+        f"Changed data availability from {prev_status} to {data_availability} for {flow_cell_id}"
+    )
 
 
 set_cmd.add_command(set_case)
