@@ -1,20 +1,21 @@
 """Code for uploading to scout via CLI"""
+
 import logging
 from pathlib import Path
-from typing import Dict, Optional
 
 import click
 from housekeeper.store.models import File, Version
 
 from cg.apps.housekeeper.hk import HousekeeperAPI
 from cg.apps.scout.scoutapi import ScoutAPI
-from cg.constants.scout_upload import ScoutCustomCaseReportTags
 from cg.cli.upload.utils import suggest_cases_to_upload
-from cg.constants import Pipeline
+from cg.constants import Workflow
+from cg.constants.cli_options import DRY_RUN
 from cg.constants.constants import FileFormat
+from cg.constants.scout import ScoutCustomCaseReportTags
 from cg.io.controller import WriteStream
-from cg.meta.upload.upload_api import UploadAPI
 from cg.meta.upload.scout.uploadscoutapi import UploadScoutAPI
+from cg.meta.upload.upload_api import UploadAPI
 from cg.meta.workflow.balsamic import BalsamicAnalysisAPI
 from cg.meta.workflow.balsamic_umi import BalsamicUmiAnalysisAPI
 from cg.meta.workflow.mip_dna import MipDNAAnalysisAPI
@@ -22,9 +23,8 @@ from cg.meta.workflow.mip_rna import MipRNAAnalysisAPI
 from cg.meta.workflow.rnafusion import RnafusionAnalysisAPI
 from cg.models.cg_config import CGConfig
 from cg.models.scout.scout_load_config import ScoutLoadConfig
-from cg.store import Store
-from cg.store.models import Family
-
+from cg.store.models import Case
+from cg.store.store import Store
 
 LOG = logging.getLogger(__name__)
 
@@ -67,10 +67,10 @@ def create_scout_load_config(context: CGConfig, case_id: str, print_console: boo
     status_db: Store = context.status_db
 
     LOG.info("Fetching family object")
-    case_obj: Family = status_db.get_case_by_internal_id(internal_id=case_id)
+    case_obj: Case = status_db.get_case_by_internal_id(internal_id=case_id)
 
     if not case_obj.analyses:
-        LOG.warning("Could not find analyses for %s", case_id)
+        LOG.warning(f"Could not find analyses for {case_id}")
         raise click.Abort
 
     context.meta_apis["upload_api"]: UploadAPI = get_upload_api(cg_config=context, case=case_obj)
@@ -82,11 +82,11 @@ def create_scout_load_config(context: CGConfig, case_id: str, print_console: boo
     try:
         scout_load_config: ScoutLoadConfig = scout_upload_api.generate_config(case_obj.analyses[0])
     except SyntaxError as error:
-        LOG.warning("%s", error)
+        LOG.warning(repr(error))
         raise click.Abort from error
-    LOG.info("Found load config %s", scout_load_config)
+    LOG.info(f"Found load config {scout_load_config}")
     root_dir: str = context.meta_apis["upload_api"].analysis_api.root
-    LOG.info("Set root dir to %s", root_dir)
+    LOG.info(f"Set root dir to {root_dir}")
     file_path: Path = Path(root_dir, case_id, "scout_load.yaml")
 
     if print_console:
@@ -95,11 +95,11 @@ def create_scout_load_config(context: CGConfig, case_id: str, print_console: boo
                 content=scout_load_config.dict(exclude_none=True), file_format=FileFormat.YAML
             )
         )
-        LOG.info("Would save file to %s", file_path)
+        LOG.info(f"Would save file to {file_path}")
         return
 
     if file_path.exists():
-        LOG.warning("Scout load config %s already exists", file_path)
+        LOG.warning(f"Scout load config {file_path} already exists")
         if re_upload:
             LOG.info("Deleting old load config")
             file_path.unlink()
@@ -128,7 +128,7 @@ def create_scout_load_config(context: CGConfig, case_id: str, print_console: boo
     is_flag=True,
     help="re-upload existing analysis",
 )
-@click.option("--dry-run", is_flag=True)
+@DRY_RUN
 @click.argument("case_id")
 @click.pass_obj
 def upload_case_to_scout(context: CGConfig, re_upload: bool, dry_run: bool, case_id: str):
@@ -141,7 +141,7 @@ def upload_case_to_scout(context: CGConfig, re_upload: bool, dry_run: bool, case
 
     tag_name: str = UploadScoutAPI.get_load_config_tag()
     version: Version = housekeeper_api.last_version(bundle=case_id)
-    scout_config_file: Optional[File] = housekeeper_api.get_latest_file_from_version(
+    scout_config_file: File | None = housekeeper_api.get_latest_file_from_version(
         version=version, tags={tag_name}
     )
 
@@ -158,7 +158,7 @@ def upload_case_to_scout(context: CGConfig, re_upload: bool, dry_run: bool, case
 
 
 @click.command(name="rna-to-scout")
-@click.option("--dry-run", is_flag=True)
+@DRY_RUN
 @click.option("-r", "--research", is_flag=True, help="Upload research report instead of clinical")
 @click.argument("case_id")
 @click.pass_context
@@ -167,6 +167,7 @@ def upload_rna_to_scout(context, case_id: str, dry_run: bool, research: bool) ->
 
     LOG.info("----------------- UPLOAD RNA TO SCOUT -----------------------")
 
+    context.invoke(upload_rna_alignment_file_to_scout, case_id=case_id, dry_run=dry_run)
     context.invoke(upload_multiqc_to_scout, case_id=case_id, dry_run=dry_run)
     context.invoke(
         upload_rna_fusion_report_to_scout, case_id=case_id, dry_run=dry_run, research=research
@@ -174,8 +175,19 @@ def upload_rna_to_scout(context, case_id: str, dry_run: bool, research: bool) ->
     context.invoke(upload_rna_junctions_to_scout, case_id=case_id, dry_run=dry_run)
 
 
+@click.command(name="rna-alignment-file-to-scout")
+@DRY_RUN
+@click.argument("case_id")
+@click.pass_obj
+def upload_rna_alignment_file_to_scout(context: CGConfig, case_id: str, dry_run: bool) -> None:
+    """Upload RNA alignment file for a case to Scout."""
+    LOG.info("----------------- UPLOAD RNA ALIGNMENT FILE TO SCOUT -----------------------")
+    scout_upload_api: UploadScoutAPI = context.meta_apis["upload_api"].scout_upload_api
+    scout_upload_api.upload_rna_alignment_file(case_id=case_id, dry_run=dry_run)
+
+
 @click.command(name="rna-fusion-report-to-scout")
-@click.option("--dry-run", is_flag=True)
+@DRY_RUN
 @click.option("--research", is_flag=True)
 @click.argument("case_id")
 @click.pass_obj
@@ -193,7 +205,7 @@ def upload_rna_fusion_report_to_scout(
 
 
 @click.command(name="rna-junctions-to-scout")
-@click.option("--dry-run", is_flag=True)
+@DRY_RUN
 @click.argument("case_id")
 @click.pass_obj
 def upload_rna_junctions_to_scout(context: CGConfig, case_id: str, dry_run: bool) -> None:
@@ -206,7 +218,7 @@ def upload_rna_junctions_to_scout(context: CGConfig, case_id: str, dry_run: bool
 
 
 @click.command(name="multiqc-to-scout")
-@click.option("--dry-run", is_flag=True)
+@DRY_RUN
 @click.argument("case_id")
 @click.pass_obj
 def upload_multiqc_to_scout(context: CGConfig, case_id: str, dry_run: bool) -> None:
@@ -215,9 +227,9 @@ def upload_multiqc_to_scout(context: CGConfig, case_id: str, dry_run: bool) -> N
 
     scout_upload_api: UploadScoutAPI = context.meta_apis["upload_api"].scout_upload_api
     status_db: Store = context.status_db
-    case: Family = status_db.get_case_by_internal_id(internal_id=case_id)
+    case: Case = status_db.get_case_by_internal_id(internal_id=case_id)
     scout_report_type, multiqc_report = scout_upload_api.get_multiqc_html_report(
-        case_id=case_id, pipeline=case.data_analysis
+        case_id=case_id, workflow=case.data_analysis
     )
     if scout_report_type == ScoutCustomCaseReportTags.MULTIQC_RNA:
         scout_upload_api.upload_rna_report_to_dna_case_in_scout(
@@ -235,15 +247,15 @@ def upload_multiqc_to_scout(context: CGConfig, case_id: str, dry_run: bool) -> N
         )
 
 
-def get_upload_api(case: Family, cg_config: CGConfig) -> UploadAPI:
+def get_upload_api(case: Case, cg_config: CGConfig) -> UploadAPI:
     """Return the upload API based on the data analysis type"""
 
-    analysis_apis: Dict[Pipeline, UploadAPI] = {
-        Pipeline.BALSAMIC: BalsamicAnalysisAPI,
-        Pipeline.BALSAMIC_UMI: BalsamicUmiAnalysisAPI,
-        Pipeline.MIP_RNA: MipRNAAnalysisAPI,
-        Pipeline.MIP_DNA: MipDNAAnalysisAPI,
-        Pipeline.RNAFUSION: RnafusionAnalysisAPI,
+    analysis_apis: dict[Workflow, UploadAPI] = {
+        Workflow.BALSAMIC: BalsamicAnalysisAPI,
+        Workflow.BALSAMIC_UMI: BalsamicUmiAnalysisAPI,
+        Workflow.MIP_RNA: MipRNAAnalysisAPI,
+        Workflow.MIP_DNA: MipDNAAnalysisAPI,
+        Workflow.RNAFUSION: RnafusionAnalysisAPI,
     }
 
     return UploadAPI(
