@@ -1,30 +1,25 @@
 """CLI support to start microsalt"""
 
-import datetime as dt
 import logging
 from pathlib import Path
-from typing import Any, List, Optional
+from typing import Any
 
 import click
+
+from cg.cli.utils import CLICK_CONTEXT_SETTINGS
 from cg.cli.workflow.commands import resolve_compression, store, store_available
-from cg.constants import EXIT_FAIL, EXIT_SUCCESS, Pipeline
+from cg.constants import EXIT_FAIL, EXIT_SUCCESS
+from cg.constants.cli_options import DRY_RUN
 from cg.constants.constants import FileFormat
-from cg.exc import CgError
-from cg.io.controller import WriteStream, WriteFile
+from cg.exc import AnalysisNotReadyError, CgError
+from cg.io.controller import WriteFile, WriteStream
+from cg.meta.workflow.analysis import AnalysisAPI
 from cg.meta.workflow.microsalt import MicrosaltAnalysisAPI
 from cg.models.cg_config import CGConfig
-from cg.store.models import Analysis, Sample
-from housekeeper.store.models import File
-from cg.meta.workflow.analysis import AnalysisAPI
+from cg.store.models import Sample
 
 LOG = logging.getLogger(__name__)
 
-OPTION_DRY_RUN = click.option(
-    "-d",
-    "--dry-run",
-    help="Print command to console without executing",
-    is_flag=True,
-)
 OPTION_SAMPLE = click.option(
     "-s",
     "--sample",
@@ -40,14 +35,12 @@ OPTION_TICKET = click.option(
 ARGUMENT_UNIQUE_IDENTIFIER = click.argument("unique_id", required=True, type=click.STRING)
 
 
-@click.group(invoke_without_command=True)
+@click.group(invoke_without_command=True, context_settings=CLICK_CONTEXT_SETTINGS)
 @click.pass_context
 def microsalt(context: click.Context) -> None:
     """Microbial workflow"""
     AnalysisAPI.get_help(context)
-    context.obj.meta_apis["analysis_api"] = MicrosaltAnalysisAPI(
-        config=context.obj,
-    )
+    context.obj.meta_apis["analysis_api"] = MicrosaltAnalysisAPI(config=context.obj)
 
 
 microsalt.add_command(store)
@@ -58,7 +51,7 @@ microsalt.add_command(resolve_compression)
 @microsalt.command()
 @OPTION_TICKET
 @OPTION_SAMPLE
-@OPTION_DRY_RUN
+@DRY_RUN
 @ARGUMENT_UNIQUE_IDENTIFIER
 @click.pass_obj
 def link(context: CGConfig, ticket: bool, sample: bool, unique_id: str, dry_run: bool) -> None:
@@ -76,7 +69,7 @@ def link(context: CGConfig, ticket: bool, sample: bool, unique_id: str, dry_run:
 
 
 @microsalt.command("config-case")
-@OPTION_DRY_RUN
+@DRY_RUN
 @OPTION_TICKET
 @OPTION_SAMPLE
 @ARGUMENT_UNIQUE_IDENTIFIER
@@ -90,13 +83,13 @@ def config_case(
     case_id, sample_id = analysis_api.resolve_case_sample_id(
         sample=sample, ticket=ticket, unique_id=unique_id
     )
-    sample_objs: List[Sample] = analysis_api.get_samples(case_id=case_id, sample_id=sample_id)
+    sample_objs: list[Sample] = analysis_api.get_samples(case_id=case_id, sample_id=sample_id)
 
     if not sample_objs:
         LOG.error("No sample found for that ticket/sample_id")
         raise click.Abort
 
-    parameters: List[dict] = [analysis_api.get_parameters(sample_obj) for sample_obj in sample_objs]
+    parameters: list[dict] = [analysis_api.get_parameters(sample_obj) for sample_obj in sample_objs]
     filename: str = sample_id or case_id
     config_case_path: Path = analysis_api.get_config_path(filename=filename)
     if dry_run:
@@ -107,11 +100,11 @@ def config_case(
     WriteFile.write_file_from_content(
         content=parameters, file_format=FileFormat.JSON, file_path=config_case_path
     )
-    LOG.info("Saved config %s", config_case_path)
+    LOG.info(f"Saved config {config_case_path}")
 
 
 @microsalt.command()
-@OPTION_DRY_RUN
+@DRY_RUN
 @OPTION_TICKET
 @OPTION_SAMPLE
 @ARGUMENT_UNIQUE_IDENTIFIER
@@ -165,9 +158,7 @@ def run(
         analysis_api.add_pending_trailblazer_analysis(case_id=case_id)
     except Exception as error:
         LOG.warning(
-            "Trailblazer warning: Could not track analysis progress for case %s! %s",
-            case_id,
-            error.__class__.__name__,
+            f"Trailblazer warning: Could not track analysis progress for case {case_id}! {error.__class__.__name__}"
         )
     try:
         analysis_api.set_statusdb_action(case_id=case_id, action="running")
@@ -180,7 +171,7 @@ def run(
 
 @microsalt.command()
 @ARGUMENT_UNIQUE_IDENTIFIER
-@OPTION_DRY_RUN
+@DRY_RUN
 @OPTION_TICKET
 @OPTION_SAMPLE
 @click.pass_context
@@ -188,15 +179,17 @@ def start(
     context: click.Context, ticket: bool, sample: bool, unique_id: str, dry_run: bool
 ) -> None:
     """Start whole microSALT workflow by providing case, ticket or sample id"""
-    LOG.info("Starting Microsalt workflow for %s", unique_id)
-
+    LOG.info(f"Starting Microsalt workflow for {unique_id}")
+    if not (sample or ticket):
+        analysis_api: MicrosaltAnalysisAPI = context.obj.meta_apis["analysis_api"]
+        analysis_api.prepare_fastq_files(case_id=unique_id, dry_run=dry_run)
     context.invoke(link, ticket=ticket, sample=sample, unique_id=unique_id, dry_run=dry_run)
     context.invoke(config_case, ticket=ticket, sample=sample, unique_id=unique_id, dry_run=dry_run)
     context.invoke(run, ticket=ticket, sample=sample, unique_id=unique_id, dry_run=dry_run)
 
 
 @microsalt.command("start-available")
-@OPTION_DRY_RUN
+@DRY_RUN
 @click.pass_context
 def start_available(context: click.Context, dry_run: bool = False):
     """Start full analysis workflow for all cases ready for analysis"""
@@ -204,9 +197,11 @@ def start_available(context: click.Context, dry_run: bool = False):
     analysis_api: MicrosaltAnalysisAPI = context.obj.meta_apis["analysis_api"]
 
     exit_code: int = EXIT_SUCCESS
-    for case_obj in analysis_api.get_cases_to_analyze():
+    for case in analysis_api.get_cases_ready_for_analysis():
         try:
-            context.invoke(start, unique_id=case_obj.internal_id, dry_run=dry_run)
+            context.invoke(start, unique_id=case.internal_id, dry_run=dry_run)
+        except AnalysisNotReadyError as error:
+            LOG.error(error)
         except CgError as error:
             LOG.error(error)
             exit_code = EXIT_FAIL
@@ -217,21 +212,15 @@ def start_available(context: click.Context, dry_run: bool = False):
         raise click.Abort
 
 
-@microsalt.command("qc-microsalt")
+@microsalt.command("qc")
 @ARGUMENT_UNIQUE_IDENTIFIER
 @click.pass_context
 def qc_microsalt(context: click.Context, unique_id: str) -> None:
     """Perform QC on a microsalt case."""
     analysis_api: MicrosaltAnalysisAPI = context.obj.meta_apis["analysis_api"]
+    metrics_file_path: Path = analysis_api.get_metrics_file_path(unique_id)
     try:
-        analysis_api.microsalt_qc(
-            case_id=unique_id,
-            run_dir_path=analysis_api.get_latest_case_path(case_id=unique_id),
-            lims_project=analysis_api.get_project(
-                analysis_api.status_db.get_case_by_internal_id(internal_id=unique_id)
-                .samples[0]
-                .internal_id
-            ),
-        )
+        LOG.info(f"Performing QC on case {unique_id}")
+        analysis_api.quality_checker.quality_control(metrics_file_path)
     except IndexError:
         LOG.error(f"No existing analysis directories found for case {unique_id}.")
