@@ -1,23 +1,36 @@
-"""Commands to start MIP rare disease DNA workflow"""
+"""Commands to start MIP rare disease DNA workflow."""
 
 import logging
 
 import click
+
+from cg.cli.utils import CLICK_CONTEXT_SETTINGS
 from cg.cli.workflow.commands import (
-    ensure_flow_cells_on_disk,
+    ensure_illumina_runs_on_disk,
     link,
     resolve_compression,
     store,
     store_available,
 )
-from cg.cli.workflow.mip.base import config_case, panel, run, start, start_available
-from cg.meta.workflow.mip_dna import MipDNAAnalysisAPI
+from cg.cli.workflow.mip.base import (
+    config_case,
+    managed_variants,
+    panel,
+    run,
+    start,
+    start_available,
+)
 from cg.meta.workflow.analysis import AnalysisAPI
+from cg.meta.workflow.mip_dna import MipDNAAnalysisAPI
 
 LOG = logging.getLogger(__name__)
 
 
-@click.group("mip-dna", invoke_without_command=True)
+@click.group(
+    "mip-dna",
+    invoke_without_command=True,
+    context_settings=CLICK_CONTEXT_SETTINGS,
+)
 @click.pass_context
 def mip_dna(
     context: click.Context,
@@ -30,8 +43,9 @@ def mip_dna(
 
 for sub_cmd in [
     config_case,
-    ensure_flow_cells_on_disk,
+    ensure_illumina_runs_on_disk,
     link,
+    managed_variants,
     panel,
     resolve_compression,
     run,
