@@ -1,8 +1,7 @@
 """Constants for cg."""
 
-import click
+from enum import Enum, IntEnum, StrEnum, auto
 
-from cg.utils.enums import StrEnum
 from cg.utils.date import get_date
 
 VALID_DATA_IN_PRODUCTION = get_date("2017-09-27")
@@ -32,38 +31,59 @@ CAPTUREKIT_OPTIONS = (
 )
 
 
+class JobType(StrEnum):
+    UPLOAD: str = "upload"
+    ANALYSIS: str = "analysis"
+
+
 class CaseActions(StrEnum):
     ANALYZE: str = "analyze"
     HOLD: str = "hold"
     RUNNING: str = "running"
 
+    @classmethod
+    def actions(cls) -> list[str]:
+        return list(map(lambda action: action.value, cls))
 
-CASE_ACTIONS = [action.value for action in CaseActions]
-
-COLLABORATORS = ("cust000", "cust002", "cust003", "cust004", "cust042")
-
-COMBOS = {
-    "DSD": ("DSD", "DSD-S", "HYP", "SEXDIF", "SEXDET"),
-    "CM": ("CNM", "CM"),
-    "Horsel": ("Horsel", "141217", "141201"),
-}
 
 CONTAINER_OPTIONS = ("Tube", "96 well plate", "No container")
 
-CONTROL_OPTIONS = ("", "negative", "positive")
 
-DEFAULT_CAPTURE_KIT = "twistexomerefseq_9.1_hg19_design.bed"
+class ControlOptions(StrEnum):
+    NEGATIVE: str = "negative"
+    POSITIVE: str = "positive"
+    EMPTY: str = ""
 
 
-class FlowCellStatus(StrEnum):
+DEFAULT_CAPTURE_KIT = "twistexomecomprehensive_10.2_hg19_design.bed"
+
+
+class CustomerId(StrEnum):
+    CG_INTERNAL_CUSTOMER: str = "cust000"
+    CUST001: str = "cust001"
+    CUST002: str = "cust002"
+    CUST003: str = "cust003"
+    CUST004: str = "cust004"
+    CUST032: str = "cust032"
+    CUST042: str = "cust042"
+    CUST110: str = "cust110"
+    CUST127: str = "cust127"
+    CUST132: str = "cust132"
+    CUST143: str = "cust143"
+    CUST147: str = "cust147"
+    CUST999: str = "cust999"
+
+
+class SequencingRunDataAvailability(StrEnum):
     ON_DISK: str = "ondisk"
     REMOVED: str = "removed"
     REQUESTED: str = "requested"
     PROCESSING: str = "processing"
     RETRIEVED: str = "retrieved"
 
-
-FLOWCELL_STATUS = [status.value for status in FlowCellStatus]
+    @classmethod
+    def statuses(cls) -> list[str]:
+        return list(map(lambda status: status.value, cls))
 
 
 class AnalysisType(StrEnum):
@@ -74,6 +94,14 @@ class AnalysisType(StrEnum):
     OTHER: str = "other"
 
 
+class CancerAnalysisType(StrEnum):
+    TUMOR_NORMAL = auto()
+    TUMOR_NORMAL_PANEL = auto()
+    TUMOR_NORMAL_WGS = auto()
+    TUMOR_PANEL = auto()
+    TUMOR_WGS = auto()
+
+
 class PrepCategory(StrEnum):
     COVID: str = "cov"
     MICROBIAL: str = "mic"
@@ -84,27 +112,62 @@ class PrepCategory(StrEnum):
     WHOLE_TRANSCRIPTOME_SEQUENCING: str = "wts"
 
 
-PREP_CATEGORIES = ("cov", "mic", "rml", "tgs", "wes", "wgs", "wts")
+class SexOptions(StrEnum):
+    MALE: str = "male"
+    FEMALE: str = "female"
+    UNKNOWN: str = "unknown"
 
-SEX_OPTIONS = ("male", "female", "unknown")
 
 SARS_COV_REGEX = "^[0-9]{2}CS[0-9]{6}$"
 
 STATUS_OPTIONS = ("affected", "unaffected", "unknown")
 
 
+class StatusOptions(StrEnum):
+    AFFECTED: str = "affected"
+    UNAFFECTED: str = "unaffected"
+    UNKNOWN: str = "unknown"
+
+
+class Workflow(StrEnum):
+    BALSAMIC: str = "balsamic"
+    BALSAMIC_PON: str = "balsamic-pon"
+    BALSAMIC_QC: str = "balsamic-qc"
+    BALSAMIC_UMI: str = "balsamic-umi"
+    DEMULTIPLEX: str = "demultiplex"
+    FASTQ: str = "fastq"
+    FLUFFY: str = "fluffy"
+    JASEN: str = "jasen"
+    MICROSALT: str = "microsalt"
+    MIP_DNA: str = "mip-dna"
+    MIP_RNA: str = "mip-rna"
+    MUTANT: str = "mutant"
+    RAREDISEASE: str = "raredisease"
+    RNAFUSION: str = "rnafusion"
+    RSYNC: str = "rsync"
+    SPRING: str = "spring"
+    TAXPROFILER: str = "taxprofiler"
+    TOMTE: str = "tomte"
+
+
 class FileFormat(StrEnum):
+    CSV: str = "csv"
     FASTQ: str = "fastq"
     JSON: str = "json"
-    YAML: str = "yaml"
-    CSV: str = "csv"
+    PNG: str = "png"
+    TSV: str = "tsv"
+    TXT: str = "txt"
     XML: str = "xml"
+    YAML: str = "yaml"
 
 
 class GenomeVersion(StrEnum):
-    hg19: str = "hg19"
-    hg38: str = "hg38"
-    canfam3: str = "canfam3"
+    GRCh37: str = "GRCh37"
+    GRCh38: str = "GRCh38"
+    T2T_CHM13: str = "T2T-CHM13v2.0"
+    CANFAM3 = auto()
+    HG19 = auto()
+    HG38 = auto()
 
 
 class SampleType(StrEnum):
@@ -133,18 +196,34 @@ class HastaSlurmPartitions(StrEnum):
 
 class FileExtensions(StrEnum):
     BED: str = ".bed"
+    COMPLETE: str = ".complete"
+    CONFIG: str = ".config"
     CRAM: str = ".cram"
     CSV: str = ".csv"
+    FASTQ: str = ".fastq"
+    FASTQ_GZ: str = ".fastq.gz"
     GPG: str = ".gpg"
     GZIP: str = ".gz"
+    HTML: str = ".html"
     JSON: str = ".json"
     KEY: str = ".key"
+    LOG: str = ".log"
+    MD5: str = ".md5"
+    MD5SUM: str = ".md5sum"
     NO_EXTENSION: str = ""
+    PASS_PHRASE: str = ".passphrase"
+    PENDING: str = ".pending"
+    PNG: str = ".png"
+    SBATCH: str = ".sbatch"
     SPRING: str = ".spring"
+    SH: str = ".sh"
     TAR: str = ".tar"
     TMP: str = ".tmp"
+    TSV: str = ".tsv"
+    TXT: str = ".txt"
     VCF: str = ".vcf"
     XML: str = ".xml"
+    YAML: str = ".yaml"
 
 
 class APIMethods(StrEnum):
@@ -155,33 +234,22 @@ class APIMethods(StrEnum):
     PATCH: str = "PATCH"
 
 
-DRY_RUN = click.option(
-    "-d",
-    "--dry-run",
-    is_flag=True,
-    default=False,
-    help="Runs the command without making any changes",
-)
-
-SKIP_CONFIRMATION = click.option(
-    "-y",
-    "--yes",
-    is_flag=True,
-    default=False,
-    help="Skip confirmation",
-)
-
-
 class MicrosaltQC:
-    QC_PERCENT_THRESHOLD_MWX: float = 0.1
+    AVERAGE_COVERAGE_THRESHOLD: int = 10
+    MWX_THRESHOLD_SAMPLES_PASSING: float = 0.9
     COVERAGE_10X_THRESHOLD: float = 0.75
+    DUPLICATION_RATE_THRESHOLD: float = 0.8
+    INSERT_SIZE_THRESHOLD: int = 100
+    MAPPED_RATE_THRESHOLD: float = 0.3
     NEGATIVE_CONTROL_READS_THRESHOLD: float = 0.2
     TARGET_READS: int = 6000000
+    TARGET_READS_FAIL_THRESHOLD: float = 0.7
 
 
 class MicrosaltAppTags(StrEnum):
     MWRNXTR003: str = "MWRNXTR003"
     MWXNXTR003: str = "MWXNXTR003"
+    VWGNXTR001: str = "VWGNXTR001"
     PREP_CATEGORY: str = "mic"
 
 
@@ -195,3 +263,37 @@ class MetaApis:
 class WorkflowManager(StrEnum):
     Slurm: str = "slurm"
     Tower: str = "nf_tower"
+
+
+class Strandedness(StrEnum):
+    """Strandedness types."""
+
+    FORWARD: str = "forward"
+    REVERSE: str = "reverse"
+    UNSTRANDED: str = "unstranded"
+
+
+class ReadDirection(IntEnum):
+    """Read direction types."""
+
+    FORWARD: int = 1
+    REVERSE: int = 2
+
+
+PIPELINES_USING_PARTIAL_ANALYSES: list[Workflow] = [Workflow.MICROSALT, Workflow.MUTANT]
+
+
+class MultiQC(StrEnum):
+    """MultiQC constants"""
+
+    MULTIQC: str = "multiqc"
+    MULTIQC_DATA: str = "multiqc_data"
+
+
+NG_UL_SUFFIX: str = " ng/uL"
+
+
+class SequencingQCStatus(Enum):
+    FAILED = auto()
+    PASSED = auto()
+    PENDING = auto()
