@@ -1,24 +1,30 @@
 """Constants for delivery."""
 
-from cgmodels.cg.constants import Pipeline
+from cg.constants.constants import Workflow
+from cg.constants.housekeeper_tags import (
+    HK_DELIVERY_REPORT_TAG,
+    AlignmentFileTag,
+    AnalysisTag,
+    HermesFileTag,
+)
 
-ONLY_ONE_CASE_PER_TICKET = [
-    Pipeline.FASTQ,
-    Pipeline.MICROSALT,
-    Pipeline.SARS_COV_2,
+ONLY_ONE_CASE_PER_TICKET: list[Workflow] = [
+    Workflow.FASTQ,
+    Workflow.MICROSALT,
+    Workflow.MUTANT,
 ]
 
-SKIP_MISSING = [
-    Pipeline.FASTQ,
-    Pipeline.MICROSALT,
-    Pipeline.SARS_COV_2,
+SKIP_MISSING: list[Workflow] = [
+    Workflow.FASTQ,
+    Workflow.MICROSALT,
+    Workflow.MUTANT,
 ]
 
-BALSAMIC_ANALYSIS_CASE_TAGS = [
+BALSAMIC_ANALYSIS_CASE_TAGS: list[set[str]] = [
     {"delivery-report"},
     {"multiqc-html"},
     {"metrics"},
-    {"visualization"},
+    {"cnv-report"},
     {"coverage"},
     {"germline"},
     {"vcf-sv"},
@@ -36,21 +42,22 @@ BALSAMIC_ANALYSIS_CASE_TAGS = [
     {"vcf2cytosure"},
 ]
 
-BALSAMIC_ANALYSIS_SAMPLE_TAGS = [
-    {"cram"},
-    {"cram-index"},
+BALSAMIC_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
+    {AlignmentFileTag.CRAM},
+    {AlignmentFileTag.CRAM_INDEX},
 ]
 
-BALSAMIC_QC_ANALYSIS_CASE_TAGS = [
+BALSAMIC_QC_ANALYSIS_CASE_TAGS: list[set[str]] = [
+    {"delivery-report"},
     {"multiqc-html"},
 ]
 
-BALSAMIC_QC_ANALYSIS_SAMPLE_TAGS = [
+BALSAMIC_QC_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
     {"qc-cram"},
     {"qc-cram-index"},
 ]
 
-BALSAMIC_UMI_ANALYSIS_CASE_TAGS = [
+BALSAMIC_UMI_ANALYSIS_CASE_TAGS: list[set[str]] = [
     {"vcf-umi-snv"},
     {"vcf-umi-snv-index"},
     {"vcf-umi-snv-research"},
@@ -61,7 +68,7 @@ BALSAMIC_UMI_ANALYSIS_CASE_TAGS = [
 
 BALSAMIC_UMI_ANALYSIS_CASE_TAGS.extend(BALSAMIC_ANALYSIS_CASE_TAGS)
 
-BALSAMIC_UMI_ANALYSIS_SAMPLE_TAGS = [
+BALSAMIC_UMI_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
     {"umi-cram"},
     {"umi-cram-index"},
 ]
@@ -69,8 +76,9 @@ BALSAMIC_UMI_ANALYSIS_SAMPLE_TAGS = [
 BALSAMIC_UMI_ANALYSIS_SAMPLE_TAGS.extend(BALSAMIC_ANALYSIS_SAMPLE_TAGS)
 
 
-MIP_DNA_ANALYSIS_CASE_TAGS = [
+MIP_DNA_ANALYSIS_CASE_TAGS: list[set[str]] = [
     {"delivery-report"},
+    {"multiqc-html"},
     {"vcf-clinical-sv-bin"},
     {"vcf-clinical-sv-bin-index"},
     {"vcf-research-sv-bin"},
@@ -93,9 +101,14 @@ MIP_DNA_ANALYSIS_CASE_TAGS = [
     {"vcf-sv-research-index"},
 ]
 
-MIP_DNA_ANALYSIS_SAMPLE_TAGS = [{"bam"}, {"bam-index"}, {"cram"}, {"cram-index"}]
+MIP_DNA_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
+    {AlignmentFileTag.BAM},
+    {AlignmentFileTag.BAM_BAI},
+    {AlignmentFileTag.CRAM},
+    {AlignmentFileTag.CRAM_INDEX},
+]
 
-MIP_RNA_ANALYSIS_CASE_TAGS = [
+MIP_RNA_ANALYSIS_CASE_TAGS: list[set[str]] = [
     {"fusion", "clinical", "pdf"},
     {"fusion", "research", "pdf"},
     {"fusion", "vcf"},
@@ -107,102 +120,90 @@ MIP_RNA_ANALYSIS_CASE_TAGS = [
     {"multiqc-html"},
 ]
 
-MIP_RNA_ANALYSIS_SAMPLE_TAGS = [
-    {"fusion", "star-fusion"},
-    {"fusion", "arriba"},
-    {"cram"},
-    {"cram-index"},
-    {"fusion", "vcf"},
-    {"fusion", "vcf-index"},
+MIP_RNA_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
+    {AnalysisTag.FUSION, AnalysisTag.STARFUSION},
+    {AnalysisTag.FUSION, AnalysisTag.ARRIBA},
+    {AlignmentFileTag.CRAM},
+    {AlignmentFileTag.CRAM_INDEX},
+    {AnalysisTag.FUSION, "vcf"},
+    {AnalysisTag.FUSION, "vcf-index"},
     {"salmon-quant"},
 ]
 
-MICROSALT_ANALYSIS_CASE_TAGS = [
-    {"microsalt-qc"},
-    {"microsalt-type"},
-    {"assembly"},
-    {"trimmed-forward-reads"},
-    {"trimmed-reverse-reads"},
-    {"reference-alignment-deduplicated"},
-]
+MICROSALT_ANALYSIS_CASE_TAGS = [{"qc-report"}, {"typing-report"}]
 
-MICROSALT_ANALYSIS_SAMPLE_TAGS = []
+MICROSALT_ANALYSIS_SAMPLE_TAGS: list[set[str]] = []
 
-FASTQ_ANALYSIS_CASE_TAGS = []
+FASTQ_ANALYSIS_CASE_TAGS: list[set[str]] = []
 
-FASTQ_ANALYSIS_SAMPLE_TAGS = [
+FASTQ_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
     {"fastq"},
 ]
 
-SARSCOV2_ANALYSIS_CASE_TAGS = [
+MUTANT_ANALYSIS_CASE_TAGS: list[set[str]] = [
     {"pangolin"},
     {"ks-delivery"},
 ]
 
-SARSCOV2_ANALYSIS_SAMPLE_TAGS = [
+MUTANT_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
     {"fastq"},
+    {"vcf", "vcf-report", "fohm-delivery"},
 ]
 
-RNAFUSION_ANALYSIS_CASE_TAGS = [
-    {"fusion", "arriba"},
-    {"fusion", "star-fusion"},
-    {"fusion", "fusioncatcher"},
-    {"cram"},
-    {"fusioncatcher-summary"},
-    {"fusioninspector"},
-    {"fusionreport", "research"},
-    {"fusioninspector-html", "research"},
-    {"arriba-visualisation", "research"},
-    {"multiqc-html", "rna"},
-    {"software-versions"},
-    {"qc-metrics"},
-    {"multiqc-json"},
-    {"delivery-report"},
-]
+CLINICAL_DELIVERY_TAGS: list[set[str]] = [{HermesFileTag.CLINICAL_DELIVERY}]
 
-RNAFUSION_ANALYSIS_SAMPLE_TAGS = []
-
-
-PIPELINE_ANALYSIS_TAG_MAP = {
-    Pipeline.BALSAMIC: {
+PIPELINE_ANALYSIS_TAG_MAP: dict[Workflow, dict] = {
+    Workflow.BALSAMIC: {
         "case_tags": BALSAMIC_ANALYSIS_CASE_TAGS,
         "sample_tags": BALSAMIC_ANALYSIS_SAMPLE_TAGS,
     },
-    Pipeline.BALSAMIC_QC: {
+    Workflow.BALSAMIC_QC: {
         "case_tags": BALSAMIC_QC_ANALYSIS_CASE_TAGS,
         "sample_tags": BALSAMIC_QC_ANALYSIS_SAMPLE_TAGS,
     },
-    Pipeline.BALSAMIC_UMI: {
+    Workflow.BALSAMIC_UMI: {
         "case_tags": BALSAMIC_UMI_ANALYSIS_CASE_TAGS,
         "sample_tags": BALSAMIC_UMI_ANALYSIS_SAMPLE_TAGS,
     },
-    Pipeline.MIP_DNA: {
+    Workflow.MIP_DNA: {
         "case_tags": MIP_DNA_ANALYSIS_CASE_TAGS,
         "sample_tags": MIP_DNA_ANALYSIS_SAMPLE_TAGS,
     },
-    Pipeline.MIP_RNA: {
+    Workflow.MIP_RNA: {
         "case_tags": MIP_RNA_ANALYSIS_CASE_TAGS,
         "sample_tags": MIP_RNA_ANALYSIS_SAMPLE_TAGS,
     },
-    Pipeline.MICROSALT: {
+    Workflow.MICROSALT: {
         "case_tags": MICROSALT_ANALYSIS_CASE_TAGS,
         "sample_tags": MICROSALT_ANALYSIS_SAMPLE_TAGS,
     },
-    Pipeline.FASTQ: {
+    Workflow.FASTQ: {
         "case_tags": FASTQ_ANALYSIS_CASE_TAGS,
         "sample_tags": FASTQ_ANALYSIS_SAMPLE_TAGS,
     },
-    Pipeline.SARS_COV_2: {
-        "case_tags": SARSCOV2_ANALYSIS_CASE_TAGS,
-        "sample_tags": SARSCOV2_ANALYSIS_SAMPLE_TAGS,
+    Workflow.MUTANT: {
+        "case_tags": MUTANT_ANALYSIS_CASE_TAGS,
+        "sample_tags": MUTANT_ANALYSIS_SAMPLE_TAGS,
     },
-    Pipeline.RNAFUSION: {
-        "case_tags": RNAFUSION_ANALYSIS_CASE_TAGS,
-        "sample_tags": RNAFUSION_ANALYSIS_SAMPLE_TAGS,
+    Workflow.RAREDISEASE: {
+        "case_tags": CLINICAL_DELIVERY_TAGS,
+        "sample_tags": CLINICAL_DELIVERY_TAGS,
+    },
+    Workflow.RNAFUSION: {
+        "case_tags": CLINICAL_DELIVERY_TAGS,
+        "sample_tags": CLINICAL_DELIVERY_TAGS,
+    },
+    Workflow.TAXPROFILER: {
+        "case_tags": CLINICAL_DELIVERY_TAGS,
+        "sample_tags": CLINICAL_DELIVERY_TAGS,
+    },
+    Workflow.TOMTE: {
+        "case_tags": CLINICAL_DELIVERY_TAGS,
+        "sample_tags": CLINICAL_DELIVERY_TAGS,
     },
 }
 
 PIPELINE_ANALYSIS_OPTIONS = PIPELINE_ANALYSIS_TAG_MAP.keys()
 
-INBOX_NAME = "inbox"
-OUTBOX_NAME = "outbox"
+INBOX_NAME: str = "inbox"
+OUTBOX_NAME: str = "outbox"
