@@ -1,7 +1,8 @@
 """File tags for files in Housekeeper."""
-from typing import List
 
-from cgmodels.cg.constants import Pipeline, StrEnum
+from enum import StrEnum
+
+from cg.constants.constants import Workflow
 
 
 class AlignmentFileTag(StrEnum):
@@ -14,8 +15,9 @@ class AlignmentFileTag(StrEnum):
     CRAM_CRAI: str = "crai"
     CRAM_INDEX: str = "cram-index"
 
-
-ALIGNMENT_FILE_TAGS: List[str] = [tag.value for tag in AlignmentFileTag]
+    @classmethod
+    def file_tags(cls) -> list[str]:
+        return list(map(lambda tag: tag.value, cls))
 
 
 class ArchiveTag(StrEnum):
@@ -34,9 +36,10 @@ class ScoutTag(StrEnum):
 class SequencingFileTag(StrEnum):
     """Tags for sequencing files."""
 
-    ARCHIVED_SAMPLE_SHEET: str = "archived_sample_sheet"
     CGSTATS_LOG: str = "log"
+    DEMUX_LOG: str = "log"
     FASTQ: str = "fastq"
+    RUN_PARAMETERS: str = "run-parameters"
     SAMPLE_SHEET: str = "samplesheet"
     SPRING: str = "spring"
     SPRING_METADATA: str = "spring-metadata"
@@ -49,26 +52,52 @@ HK_FASTQ_TAGS = [SequencingFileTag.FASTQ]
 HK_DELIVERY_REPORT_TAG = "delivery-report"
 
 
+class HermesFileTag(StrEnum):
+    """Tags for hermes."""
+
+    CLINICAL_DELIVERY: str = "clinical-delivery"
+    LONG_TERM_STORAGE: str = "long-term-storage"
+
+
+class AnalysisTag(StrEnum):
+    """Tags for analysis files."""
+
+    ARRIBA: str = "arriba"
+    ARRIBA_VISUALIZATION: str = "arriba-visualisation"
+    FUSION: str = "fusion"
+    FUSIONCATCHER: str = "fusioncatcher"
+    FUSIONCATCHER_SUMMARY: str = "fusioncatcher-summary"
+    FUSIONINSPECTOR: str = "fusioninspector"
+    FUSIONINSPECTOR_HTML: str = "fusioninspector-html"
+    FUSIONREPORT: str = "fusionreport"
+    GENE_COUNTS: str = "gene-counts"
+    MULTIQC_HTML: str = "multiqc-html"
+    RESEARCH: str = "research"
+    RNA: str = "rna"
+    STARFUSION: str = "star-fusion"
+    VCF_FUSION: str = "vcf-fusion"
+
+
 class HkMipAnalysisTag:
-    CONFIG: List[str] = ["mip-config"]
-    QC_METRICS: List[str] = ["qc-metrics", "deliverable"]
-    SAMPLE_INFO: List[str] = ["sample-info"]
+    CONFIG: list[str] = ["mip-config"]
+    QC_METRICS: list[str] = ["qc-metrics", "deliverable"]
+    SAMPLE_INFO: list[str] = ["sample-info"]
 
 
-class BalsamicAnalysisTag(StrEnum):
-    CONFIG: str = "balsamic-config"
-    QC_METRICS: str = "qc-metrics"
+class BalsamicAnalysisTag:
+    CONFIG: list[str] = ["balsamic-config"]
+    QC_METRICS: list[str] = ["qc-metrics", "deliverable"]
 
 
 class GensAnalysisTag:
-    COVERAGE: List[str] = ["gens", "coverage", "bed"]
-    FRACSNP: List[str] = ["gens", "fracsnp", "bed"]
+    COVERAGE: list[str] = ["gens", "coverage", "bed"]
+    FRACSNP: list[str] = ["gens", "fracsnp", "bed"]
 
 
 class BalsamicProtectedTags:
-    """Balsamic pipeline protected tags by type."""
+    """Balsamic workflow protected tags by type."""
 
-    QC: List[List[str]] = [
+    QC: list[list[str]] = [
         ["balsamic-config"],
         ["balsamic-dag"],
         ["balsamic-report"],
@@ -77,8 +106,9 @@ class BalsamicProtectedTags:
         ["multiqc-json"],
         ["qc-metrics"],
     ]
-    VARIANT_CALLERS: List[List[str]] = [
+    VARIANT_CALLERS: list[list[str]] = [
         ["ascatngs"],
+        ["visualization"],
         ["cnv-report"],
         ["cnvkit"],
         ["delly"],
@@ -92,13 +122,13 @@ class BalsamicProtectedTags:
 
 
 WORKFLOW_PROTECTED_TAGS = {
-    str(Pipeline.BALSAMIC): BalsamicProtectedTags.QC + BalsamicProtectedTags.VARIANT_CALLERS,
-    str(Pipeline.BALSAMIC_QC): BalsamicProtectedTags.QC,
-    str(Pipeline.BALSAMIC_PON): [],
-    str(Pipeline.BALSAMIC_UMI): BalsamicProtectedTags.QC + BalsamicProtectedTags.VARIANT_CALLERS,
-    str(Pipeline.FASTQ): [],
-    str(Pipeline.FLUFFY): ["NIPT_csv", "MultiQC"],
-    str(Pipeline.MICROSALT): [
+    Workflow.BALSAMIC: BalsamicProtectedTags.QC + BalsamicProtectedTags.VARIANT_CALLERS,
+    Workflow.BALSAMIC_QC: BalsamicProtectedTags.QC,
+    Workflow.BALSAMIC_PON: [],
+    Workflow.BALSAMIC_UMI: BalsamicProtectedTags.QC + BalsamicProtectedTags.VARIANT_CALLERS,
+    Workflow.FASTQ: [],
+    Workflow.FLUFFY: ["NIPT_csv", "MultiQC"],
+    Workflow.MICROSALT: [
         ["microsalt-log"],
         ["config"],
         ["qc-report", "visualization"],
@@ -107,7 +137,7 @@ WORKFLOW_PROTECTED_TAGS = {
         ["microsalt-config"],
         ["assembly"],
     ],
-    str(Pipeline.MIP_DNA): [
+    Workflow.MIP_DNA: [
         ["vcf-snv-clinical"],
         ["vcf-clinical"],  # legacy
         ["vcf-snv-research"],
@@ -143,7 +173,7 @@ WORKFLOW_PROTECTED_TAGS = {
         ["multiqc-html"],
         ["storage"],
     ],
-    str(Pipeline.MIP_RNA): [
+    Workflow.MIP_RNA: [
         ["vcf-snv-clinical"],
         ["vcf-snv-research"],
         ["mip-config"],
@@ -155,7 +185,7 @@ WORKFLOW_PROTECTED_TAGS = {
         ["fusion", "vcf"],
         ["salmon-quant"],
     ],
-    str(Pipeline.SARS_COV_2): [
+    Workflow.MUTANT: [
         ["fohm-delivery", "instrument-properties"],
         ["fohm-delivery", "pangolin-typing-fohm", "csv"],
         ["vcf", "vcf-report", "fohm-delivery"],
@@ -172,4 +202,46 @@ WORKFLOW_PROTECTED_TAGS = {
         ["gisaid-log"],
         ["gisaid-csv"],
     ],
+    Workflow.RAREDISEASE: [
+        [HermesFileTag.LONG_TERM_STORAGE],
+    ],
+    Workflow.RNAFUSION: [
+        [HermesFileTag.LONG_TERM_STORAGE],
+        [AnalysisTag.FUSION, AnalysisTag.ARRIBA],  # legacy
+        [AnalysisTag.FUSION, AnalysisTag.STARFUSION],  # legacy
+        [AnalysisTag.FUSION, AnalysisTag.FUSIONCATCHER],  # legacy
+        [AnalysisTag.FUSIONINSPECTOR],  # legacy
+        [AnalysisTag.FUSIONREPORT, AnalysisTag.RESEARCH],  # legacy
+        [AnalysisTag.FUSIONINSPECTOR_HTML, AnalysisTag.RESEARCH],  # legacy
+        [AnalysisTag.ARRIBA_VISUALIZATION, AnalysisTag.RESEARCH],  # legacy
+        [AnalysisTag.MULTIQC_HTML, AnalysisTag.RNA],  # legacy
+        [HK_DELIVERY_REPORT_TAG],  # legacy
+        [AnalysisTag.VCF_FUSION],  # legacy
+        [AnalysisTag.GENE_COUNTS],  # legacy
+    ],
+    Workflow.TAXPROFILER: [
+        [HermesFileTag.LONG_TERM_STORAGE],
+    ],
+    Workflow.TOMTE: [
+        [HermesFileTag.LONG_TERM_STORAGE],
+    ],
 }
+
+
+class JanusTags:
+    """Tags to communicate with the JanusAPI."""
+
+    tags_to_retrieve: list[str] = ["qc-metrics", "janus"]
+    multi_qc_file_tags: list[str] = [
+        "picard-alignment",
+        "picard-duplicates",
+        "picard-hs",
+        "picard-insert-size",
+        "picard-wgs",
+        "samtools-stats",
+        "somalier",
+        "picard-rnaseq",
+        "fastp",
+        "star",
+        "general-stats",
+    ]
