@@ -1,6 +1,6 @@
 # LIMS constants
 
-from cg.utils.enums import StrEnum
+from enum import StrEnum
 
 YES_NO_LIMS_BOOLEANS = ["require_qc_ok", "tumour", "verified_organism"]
 
@@ -10,12 +10,14 @@ PROP2UDF = {
     "capture_kit": "Capture Library version",
     "collection_date": "Collection Date",
     "comment": "Comment",
-    "control": "Control",
     "concentration": "Concentration (nM)",
+    "concentration_ng_ul": "Concentration (ng/ul)",
     "concentration_sample": "Sample Conc.",
+    "control": "Control",
     "customer": "customer",
     "data_analysis": "Data Analysis",
     "data_delivery": "Data Delivery",
+    "dv200": "DV200",
     "elution_buffer": "Sample Buffer",
     "extraction_method": "Extraction method",
     "family_name": "familyID",
@@ -59,6 +61,7 @@ MASTER_STEPS_UDFS = {
         "Hybridize Library TWIST v1": "Bait Set",
         "Hybridize Library TWIST v2": "Bait Set",
         "Target enrichment TWIST v1": "Bait Set",
+        "Library Prep (Dev) v3": "Bait Set",
     },
     "rna_prep_step": {
         "Aliquot Samples for Fragmentation (RNA) v1": "Amount needed (ng)",
@@ -86,7 +89,7 @@ MASTER_STEPS_UDFS = {
         },
         "obsolete_CG002 - Hybridize Library  (SS XT)": {
             "method_number": "Method document",
-            "method_version": "Method document versio",
+            "method_version": "Method document version",
         },
         "CG002 - Microbial Library Prep (Nextera)": {
             "method_number": "Method",
@@ -126,6 +129,10 @@ MASTER_STEPS_UDFS = {
             "atlas_document": "Sequencing Method",
             "atlas_version": "Atlas Version",
         },
+        "Define Run Format and Calculate Volumes (NovaSeq X)": {
+            "atlas_document": "Sequencing Method",
+            "atlas_version": "Atlas Version",
+        },
     },
     "delivery_method_step": {
         "CG002 - Delivery": {
@@ -141,8 +148,6 @@ MASTER_STEPS_UDFS = {
     },
 }
 
-PROCESSES = {"sequenced_date": "AUTOMATED - NovaSeq Run"}
-
 
 class DocumentationMethod(StrEnum):
     ATLAS: str = "Atlas"
