@@ -1,5 +1,7 @@
 """Nextflow related constants."""
+
 from enum import IntEnum
+from cg.constants import Workflow
 
 NFX_WORK_DIR = "work"
 NFX_SAMPLE_HEADER = "sample"
@@ -11,6 +13,12 @@ DELIVER_FILE_HEADERS = ["format", "id", "path", "path_index", "step", "tag"]
 NXF_PID_FILE_ENV = "NXF_PID_FILE"
 NXF_JVM_ARGS_ENV = "NXF_JVM_ARGS"
 JAVA_MEMORY_HEADJOB = "-Xmx5g"
+NEXTFLOW_WORKFLOWS: list = [
+    Workflow.RAREDISEASE,
+    Workflow.RNAFUSION,
+    Workflow.TAXPROFILER,
+    Workflow.TOMTE,
+]
 
 
 class SlurmHeadJobDefaults(IntEnum):
