@@ -6,17 +6,13 @@ The normal entry for information is through the REST API which will pass a JSON
 document with all information about samples in the submission. The input will
 be validated and if passing all checks be accepted as new samples.
 """
+
 import logging
-from typing import Optional
 
 from cg.apps.lims import LimsAPI
 from cg.apps.osticket import OsTicket
-from cg.meta.orders.rnafusion_submitter import RnafusionSubmitter
-from cg.models.orders.order import OrderIn, OrderType
-from cg.store import Store
-
-from cg.meta.orders.balsamic_submitter import BalsamicSubmitter
 from cg.meta.orders.balsamic_qc_submitter import BalsamicQCSubmitter
+from cg.meta.orders.balsamic_submitter import BalsamicSubmitter
 from cg.meta.orders.balsamic_umi_submitter import BalsamicUmiSubmitter
 from cg.meta.orders.fastq_submitter import FastqSubmitter
 from cg.meta.orders.fluffy_submitter import FluffySubmitter
@@ -25,9 +21,13 @@ from cg.meta.orders.microsalt_submitter import MicrosaltSubmitter
 from cg.meta.orders.mip_dna_submitter import MipDnaSubmitter
 from cg.meta.orders.mip_rna_submitter import MipRnaSubmitter
 from cg.meta.orders.rml_submitter import RmlSubmitter
+from cg.meta.orders.rnafusion_submitter import RnafusionSubmitter
 from cg.meta.orders.sars_cov_2_submitter import SarsCov2Submitter
 from cg.meta.orders.submitter import Submitter
 from cg.meta.orders.ticket_handler import TicketHandler
+from cg.meta.orders.tomte_submitter import TomteSubmitter
+from cg.models.orders.order import OrderIn, OrderType
+from cg.store.store import Store
 
 LOG = logging.getLogger(__name__)
 
@@ -48,6 +48,7 @@ def _get_submit_handler(project: OrderType, lims: LimsAPI, status: Store) -> Sub
         OrderType.RML: RmlSubmitter,
         OrderType.RNAFUSION: RnafusionSubmitter,
         OrderType.SARS_COV_2: SarsCov2Submitter,
+        OrderType.TOMTE: TomteSubmitter,
     }
     if project in submitters:
         return submitters[project](lims=lims, status=status)
@@ -71,7 +72,7 @@ class OrdersAPI:
         submit_handler.validate_order(order=order_in)
 
         # detect manual ticket assignment
-        ticket_number: Optional[str] = TicketHandler.parse_ticket_number(order_in.name)
+        ticket_number: str | None = TicketHandler.parse_ticket_number(order_in.name)
         if not ticket_number:
             ticket_number = self.ticket_handler.create_ticket(
                 order=order_in, user_name=user_name, user_mail=user_mail, project=project
