@@ -1,10 +1,11 @@
 """Upload coverage API"""
+
 import logging
 
 from cg.apps.coverage import ChanjoAPI
 from cg.apps.housekeeper.hk import HousekeeperAPI
-from cg.store import Store
 from cg.store.models import Analysis
+from cg.store.store import Store
 
 LOG = logging.getLogger(__name__)
 
@@ -19,9 +20,9 @@ class UploadCoverageApi:
 
     def data(self, analysis_obj: Analysis) -> dict:
         """Get data for uploading coverage."""
-        family_id = analysis_obj.family.internal_id
-        data = {"family": family_id, "family_name": analysis_obj.family.name, "samples": []}
-        for link_obj in analysis_obj.family.links:
+        family_id = analysis_obj.case.internal_id
+        data = {"family": family_id, "family_name": analysis_obj.case.name, "samples": []}
+        for link_obj in analysis_obj.case.links:
             analysis_date = analysis_obj.started_at or analysis_obj.completed_at
             hk_version = self.hk_api.version(family_id, analysis_date)
             hk_coverage = self.hk_api.files(
@@ -36,17 +37,20 @@ class UploadCoverageApi:
             )
         return data
 
-    def upload(self, data: dict, replace: bool = False):
-        """Upload coverage to Chanjo from an analysis."""
+    def upload(self, data: dict):
+        """
+        Upload coverage to Chanjo from an analysis.
+        If a previous coverage exists for a sample, it will be deleted before re-uploading.
+        """
         for sample_data in data["samples"]:
             chanjo_sample = self.chanjo_api.sample(sample_data["sample"])
-            if chanjo_sample and replace:
+            if chanjo_sample:
+                LOG.warning(
+                    f"Sample already loaded, deleting previous entry and re-uploading: {sample_data['sample']}"
+                )
                 self.chanjo_api.delete_sample(sample_data["sample"])
-            elif chanjo_sample:
-                LOG.warning("sample already loaded, skipping: %s", sample_data["sample"])
-                continue
 
-            LOG.debug("upload coverage for sample: %s", sample_data["sample"])
+            LOG.debug(f"upload coverage for sample: {sample_data['sample']}")
             self.chanjo_api.upload(
                 sample_id=sample_data["sample"],
                 sample_name=sample_data["sample_name"],
