@@ -1,18 +1,16 @@
 import logging
 from pathlib import Path
-from typing import List
 
-from cgmodels.cg.constants import Pipeline
+from housekeeper.store.models import File, Version
 
 from cg.apps.gt import GenotypeAPI
 from cg.apps.housekeeper.hk import HousekeeperAPI
-from cg.apps.housekeeper.hk import models as housekeeper_models
-from cg.constants.constants import FileFormat, PrepCategory
+from cg.constants.constants import FileFormat, PrepCategory, Workflow
 from cg.constants.housekeeper_tags import HkMipAnalysisTag
-from cg.constants.subject import Gender
+from cg.constants.subject import Sex
 from cg.io.controller import ReadFile
 from cg.models.mip.mip_metrics_deliverables import MIPMetricsDeliverables
-from cg.store.models import Analysis, Family, Sample
+from cg.store.models import Analysis, Case, Sample
 
 LOG = logging.getLogger(__name__)
 
@@ -27,7 +25,7 @@ class UploadGenotypesAPI(object):
         self.hk = hk_api
         self.gt = gt_api
 
-    def data(self, analysis_obj: Analysis) -> dict:
+    def data(self, analysis: Analysis) -> dict:
         """Fetch data about an analysis to load genotypes.
 
         Returns: dict on form
@@ -43,24 +41,22 @@ class UploadGenotypesAPI(object):
         }
 
         """
-        case_id = analysis_obj.family.internal_id
-        LOG.info("Fetching upload genotype data for %s", case_id)
+        case_id = analysis.case.internal_id
+        LOG.info(f"Fetching upload genotype data for {case_id}")
         hk_version = self.hk.last_version(case_id)
         hk_bcf = self.get_bcf_file(hk_version)
         data = {"bcf": hk_bcf.full_path}
-        if analysis_obj.pipeline in [Pipeline.BALSAMIC, Pipeline.BALSAMIC_UMI]:
-            data["samples_sex"] = self._get_samples_sex_balsamic(case_obj=analysis_obj.family)
-        elif analysis_obj.pipeline == Pipeline.MIP_DNA:
+        if analysis.workflow in [Workflow.BALSAMIC, Workflow.BALSAMIC_UMI]:
+            data["samples_sex"] = self._get_samples_sex_balsamic(case_obj=analysis.case)
+        elif analysis.workflow == Workflow.MIP_DNA:
             data["samples_sex"] = self._get_samples_sex_mip(
-                case_obj=analysis_obj.family, hk_version=hk_version
+                case_obj=analysis.case, hk_version=hk_version
             )
         else:
-            raise ValueError(f"Pipeline {analysis_obj.pipeline} does not support Genotype upload")
+            raise ValueError(f"Workflow {analysis.workflow} does not support Genotype upload")
         return data
 
-    def _get_samples_sex_mip(
-        self, case_obj: Family, hk_version: housekeeper_models.Version
-    ) -> dict:
+    def _get_samples_sex_mip(self, case_obj: Case, hk_version: Version) -> dict:
         qc_metrics_file = self.get_qcmetrics_file(hk_version)
         analysis_sexes = self.analysis_sex(qc_metrics_file)
         samples_sex = {}
@@ -72,7 +68,7 @@ class UploadGenotypesAPI(object):
             }
         return samples_sex
 
-    def _get_samples_sex_balsamic(self, case_obj: Family) -> dict:
+    def _get_samples_sex_balsamic(self, case_obj: Case) -> dict:
         samples_sex = {}
         for link_obj in case_obj.links:
             if link_obj.sample.is_tumour:
@@ -80,7 +76,7 @@ class UploadGenotypesAPI(object):
             sample_id = link_obj.sample.internal_id
             samples_sex[sample_id] = {
                 "pedigree": link_obj.sample.sex,
-                "analysis": Gender.UNKNOWN,
+                "analysis": Sex.UNKNOWN,
             }
         return samples_sex
 
@@ -92,21 +88,21 @@ class UploadGenotypesAPI(object):
             for sample_id_metric in qc_metrics.sample_id_metrics
         }
 
-    def get_bcf_file(self, hk_version_obj: housekeeper_models.Version) -> housekeeper_models.File:
+    def get_bcf_file(self, hk_version_obj: Version) -> File:
         """Fetch a bcf file and return the file object"""
         genotype_files: list = self._get_genotype_files(version_id=hk_version_obj.id)
         for genotype_file in genotype_files:
             if self._is_variant_file(genotype_file=genotype_file):
-                LOG.debug("Found bcf file %s", genotype_file.full_path)
+                LOG.debug(f"Found bcf file {genotype_file.full_path}")
                 return genotype_file
         raise FileNotFoundError(f"No vcf or bcf file found for bundle {hk_version_obj.bundle_id}")
 
-    def get_qcmetrics_file(self, hk_version_obj: housekeeper_models.Version) -> Path:
+    def get_qcmetrics_file(self, hk_version_obj: Version) -> Path:
         """Fetch a qc_metrics file and return the path"""
         hk_qcmetrics = self.hk.files(
             version=hk_version_obj.id, tags=HkMipAnalysisTag.QC_METRICS
         ).first()
-        LOG.debug("Found qc metrics file %s", hk_qcmetrics.full_path)
+        LOG.debug(f"Found qc metrics file {hk_qcmetrics.full_path}")
         return Path(hk_qcmetrics.full_path)
 
     @staticmethod
@@ -122,17 +118,17 @@ class UploadGenotypesAPI(object):
         self.gt.upload(str(data["bcf"]), data["samples_sex"], force=replace)
 
     @staticmethod
-    def _is_variant_file(genotype_file: housekeeper_models.File):
+    def _is_variant_file(genotype_file: File):
         return genotype_file.full_path.endswith("vcf.gz") or genotype_file.full_path.endswith("bcf")
 
     def _get_genotype_files(self, version_id: int) -> list:
         return self.hk.files(version=version_id, tags=["genotype"]).all()
 
     @staticmethod
-    def is_suitable_for_genotype_upload(case_obj: Family) -> bool:
+    def is_suitable_for_genotype_upload(case_obj: Case) -> bool:
         """Check if a cancer case is contains WGS and normal sample."""
 
-        samples: List[Sample] = case_obj.samples
+        samples: list[Sample] = case_obj.samples
         return any(
             (not sample.is_tumour and PrepCategory.WHOLE_GENOME_SEQUENCING == sample.prep_category)
             for sample in samples
