@@ -1,4 +1,5 @@
 """MIP-RNA upload API."""
+
 import logging
 from subprocess import CalledProcessError
 
@@ -10,7 +11,7 @@ from cg.constants import DataDelivery
 from cg.meta.upload.upload_api import UploadAPI
 from cg.meta.workflow.mip_rna import MipRNAAnalysisAPI
 from cg.models.cg_config import CGConfig
-from cg.store.models import Analysis, Family
+from cg.store.models import Analysis, Case
 
 LOG = logging.getLogger(__name__)
 
@@ -22,7 +23,7 @@ class MipRNAUploadAPI(UploadAPI):
         self.analysis_api: MipRNAAnalysisAPI = MipRNAAnalysisAPI(config)
         super().__init__(config=config, analysis_api=self.analysis_api)
 
-    def upload(self, ctx: click.Context, case: Family, restart: bool) -> None:
+    def upload(self, ctx: click.Context, case: Case, restart: bool) -> None:
         """Uploads MIP-RNA analysis data and files."""
         analysis: Analysis = case.analyses[0]
         self.update_upload_started_at(analysis=analysis)
@@ -34,11 +35,7 @@ class MipRNAUploadAPI(UploadAPI):
         if DataDelivery.SCOUT in case.data_delivery:
             try:
                 ctx.invoke(upload_rna_to_scout, case_id=case.internal_id)
-                self.update_uploaded_at(analysis)
             except CalledProcessError as error:
                 LOG.error(error)
-        else:
-            LOG.warning(
-                f"There is nothing to upload to Scout for case {case.internal_id} and "
-                f"the specified data delivery ({case.data_delivery})"
-            )
+                return
+        self.update_uploaded_at(analysis)
