@@ -1,36 +1,39 @@
-"""Module for Balsamic Analysis API"""
+"""Module for Balsamic Analysis API."""
 
 import logging
 from pathlib import Path
-from typing import Dict, List, Optional, Union
 
-from housekeeper.store.models import Version, File
-from pydantic import ValidationError
+from housekeeper.store.models import File, Version
+from pydantic.v1 import EmailStr, ValidationError
 
-from cg.constants import Pipeline
-from cg.constants.constants import FileFormat, SampleType, AnalysisType
+from cg.constants import Workflow
+from cg.constants.constants import FileFormat, SampleType
 from cg.constants.housekeeper_tags import BalsamicAnalysisTag
-from cg.constants.indexes import ListIndexes
 from cg.constants.observations import ObservationsFileWildcards
+from cg.constants.priority import SlurmQos
+from cg.constants.scout import BALSAMIC_CASE_TAGS
 from cg.constants.sequencing import Variants
-from cg.constants.subject import Gender
+from cg.constants.subject import Sex
 from cg.exc import BalsamicStartError, CgError
 from cg.io.controller import ReadFile
 from cg.meta.workflow.analysis import AnalysisAPI
 from cg.meta.workflow.fastq import BalsamicFastqHandler
 from cg.models.balsamic.analysis import BalsamicAnalysis
+from cg.models.balsamic.config import BalsamicVarCaller
 from cg.models.balsamic.metrics import (
     BalsamicMetricsBase,
     BalsamicTargetedQCMetrics,
     BalsamicWGSQCMetrics,
 )
 from cg.models.cg_config import CGConfig
-from cg.store.models import Family, FamilySample, Sample
+from cg.store.models import Case, CaseSample, Sample
 from cg.utils import Process
 from cg.utils.utils import build_command_from_dict, get_string_from_list_by_pattern
 
 LOG = logging.getLogger(__name__)
 
+MAX_CASES_TO_START_IN_50_MINUTES = 21
+
 
 class BalsamicAnalysisAPI(AnalysisAPI):
     """Handles communication between BALSAMIC processes
@@ -42,27 +45,31 @@ class BalsamicAnalysisAPI(AnalysisAPI):
     def __init__(
         self,
         config: CGConfig,
-        pipeline: Pipeline = Pipeline.BALSAMIC,
+        workflow: Workflow = Workflow.BALSAMIC,
     ):
-        super().__init__(config=config, pipeline=pipeline)
-        self.root_dir = config.balsamic.root
-        self.account = config.balsamic.slurm.account
-        self.balsamic_cache = config.balsamic.balsamic_cache
-        self.email = config.balsamic.slurm.mail_user
-        self.qos = config.balsamic.slurm.qos
-        self.bed_path = config.balsamic.bed_path
-        self.pon_path = config.balsamic.pon_path
-        self.loqusdb_path = config.balsamic.loqusdb_path
-        self.swegen_path = config.balsamic.swegen_path
+        super().__init__(workflow=workflow, config=config)
+        self.account: str = config.balsamic.slurm.account
+        self.binary_path: str = config.balsamic.binary_path
+        self.balsamic_cache: str = config.balsamic.balsamic_cache
+        self.conda_binary: str = config.balsamic.conda_binary
+        self.conda_env: str = config.balsamic.conda_env
+        self.bed_path: str = config.balsamic.bed_path
+        self.cadd_path: str = config.balsamic.cadd_path
+        self.genome_interval_path: str = config.balsamic.genome_interval_path
+        self.gnomad_af5_path: str = config.balsamic.gnomad_af5_path
+        self.gens_coverage_female_path: str = config.balsamic.gens_coverage_female_path
+        self.gens_coverage_male_path: str = config.balsamic.gens_coverage_male_path
+        self.email: EmailStr = config.balsamic.slurm.mail_user
+        self.loqusdb_path: str = config.balsamic.loqusdb_path
+        self.pon_path: str = config.balsamic.pon_path
+        self.qos: SlurmQos = config.balsamic.slurm.qos
+        self.root_dir: str = config.balsamic.root
+        self.swegen_path: str = config.balsamic.swegen_path
 
     @property
     def root(self) -> str:
         return self.root_dir
 
-    @property
-    def threshold_reads(self):
-        return True
-
     @property
     def fastq_handler(self):
         return BalsamicFastqHandler
@@ -70,7 +77,9 @@ class BalsamicAnalysisAPI(AnalysisAPI):
     @property
     def process(self):
         if not self._process:
-            self._process = Process(self.config.balsamic.binary_path)
+            self._process = Process(
+                binary=self.binary_path, conda_binary=self.conda_binary, environment=self.conda_env
+            )
         return self._process
 
     @property
@@ -83,20 +92,13 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         """Returns a path where the Balsamic case for the case_id should be located"""
         return Path(self.root_dir, case_id)
 
-    def get_cases_to_analyze(self) -> List[Family]:
-        cases_query: List[Family] = self.status_db.cases_to_analyze(
-            pipeline=self.pipeline, threshold=self.threshold_reads
-        )
-        cases_to_analyze = []
-        for case_obj in cases_query:
-            if case_obj.action == "analyze" or not case_obj.latest_analyzed:
-                cases_to_analyze.append(case_obj)
-            elif (
-                self.trailblazer_api.get_latest_analysis_status(case_id=case_obj.internal_id)
-                == "failed"
-            ):
-                cases_to_analyze.append(case_obj)
-        return cases_to_analyze
+    def get_cases_ready_for_analysis(self) -> list[Case]:
+        """Returns a list of cases that are ready for analysis."""
+        cases_to_analyse: list[Case] = self.get_cases_to_analyse()
+        cases_ready_for_analysis: list[Case] = [
+            case for case in cases_to_analyse if self.is_case_ready_for_analysis(case)
+        ]
+        return cases_ready_for_analysis[:MAX_CASES_TO_START_IN_50_MINUTES]
 
     def get_deliverables_file_path(self, case_id: str) -> Path:
         """Returns a path where the Balsamic deliverables file for the case_id should be located.
@@ -118,7 +120,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         """
         return Path(self.root_dir, case_id, case_id + ".json")
 
-    def get_trailblazer_config_path(self, case_id: str) -> Path:
+    def get_job_ids_path(self, case_id: str) -> Path:
         return Path(self.root_dir, case_id, "analysis", "slurm_jobids.yaml")
 
     def get_bundle_deliverables_type(self, case_id: str) -> str:
@@ -126,7 +128,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
 
         Analysis types are any of ["tumor_wgs", "tumor_normal_wgs", "tumor_panel", "tumor_normal_panel"]
         """
-        LOG.debug("Fetch analysis type for %s", case_id)
+        LOG.debug(f"Fetch analysis type for {case_id}")
         number_of_samples: int = len(
             self.status_db.get_case_by_internal_id(internal_id=case_id).links
         )
@@ -140,44 +142,18 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         if application_type != "wgs":
             application_type = "panel"
         analysis_type = "_".join([sample_type, application_type])
-        LOG.info("Found analysis type %s", analysis_type)
+        LOG.debug(f"Found analysis type {analysis_type}")
         return analysis_type
 
-    def get_sample_fastq_destination_dir(self, case: Family, sample: Sample = None) -> Path:
+    def get_sample_fastq_destination_dir(self, case: Case, sample: Sample = None) -> Path:
         """Return the path to the FASTQ destination directory."""
         return Path(self.get_case_path(case.internal_id), FileFormat.FASTQ)
 
     def link_fastq_files(self, case_id: str, dry_run: bool = False) -> None:
-        case_obj = self.status_db.get_case_by_internal_id(internal_id=case_id)
-        for link in case_obj.links:
-            self.link_fastq_files_for_sample(
-                case_obj=case_obj, sample_obj=link.sample, concatenate=True
-            )
-
-    def get_concatenated_fastq_path(self, link_object: FamilySample) -> Path:
-        """Returns path to the concatenated FASTQ file of a sample"""
-        file_collection: List[dict] = self.gather_file_metadata_for_sample(link_object.sample)
-        fastq_data = file_collection[0]
-        linked_fastq_name = self.fastq_handler.create_fastq_name(
-            lane=fastq_data["lane"],
-            flowcell=fastq_data["flowcell"],
-            sample=link_object.sample.internal_id,
-            read=fastq_data["read"],
-            undetermined=fastq_data["undetermined"],
-        )
-        concatenated_fastq_name: str = self.fastq_handler.get_concatenated_name(linked_fastq_name)
-        return Path(
-            self.root_dir,
-            link_object.family.internal_id,
-            "fastq",
-            concatenated_fastq_name,
-        )
-
-    @staticmethod
-    def get_gender(sample_obj: Sample) -> str:
-        """Returns the gender associated to a specific sample"""
-
-        return sample_obj.sex
+        """Link fastq files from Housekeeper to Balsamic case working directory."""
+        case: Case = self.status_db.get_case_by_internal_id(internal_id=case_id)
+        for link in case.links:
+            self.link_fastq_files_for_sample(case=case, sample=link.sample)
 
     @staticmethod
     def get_sample_type(sample_obj: Sample) -> SampleType:
@@ -186,7 +162,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
             return SampleType.TUMOR
         return SampleType.NORMAL
 
-    def get_derived_bed(self, panel_bed: str) -> Optional[Path]:
+    def get_derived_bed(self, panel_bed: str) -> Path | None:
         """Returns the verified capture kit path or the derived panel BED path."""
         if not panel_bed:
             return None
@@ -206,7 +182,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
             )
         return derived_panel_bed
 
-    def get_verified_bed(self, panel_bed: str, sample_data: dict) -> Optional[str]:
+    def get_verified_bed(self, panel_bed: str, sample_data: dict) -> str | None:
         """Takes a dict with samples and attributes.
         Retrieves unique attributes for application type and target_bed.
         Verifies that those attributes are the same across multiple samples,
@@ -220,7 +196,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         - When bed file required for analysis, but is not set or cannot be retrieved.
         """
 
-        panel_bed: Optional[Path] = self.get_derived_bed(panel_bed)
+        panel_bed: Path | None = self.get_derived_bed(panel_bed)
         application_types = {v["application_type"].lower() for k, v in sample_data.items()}
         target_beds: set = {v["target_bed"] for k, v in sample_data.items()}
 
@@ -242,7 +218,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
                 )
             return Path(self.bed_path, target_bed).as_posix()
 
-    def get_verified_pon(self, panel_bed: str, pon_cnn: str) -> Optional[str]:
+    def get_verified_pon(self, panel_bed: str, pon_cnn: str) -> str | None:
         """Returns the validated PON or extracts the latest one available if it is not provided
 
         Raises BalsamicStartError:
@@ -264,7 +240,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
 
         return latest_pon
 
-    def get_latest_pon_file(self, panel_bed: str) -> Optional[str]:
+    def get_latest_pon_file(self, panel_bed: str) -> str | None:
         """Returns the latest PON cnn file associated to a specific capture bed"""
 
         if not panel_bed:
@@ -273,41 +249,34 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         pon_list = Path(self.pon_path).glob(f"*{Path(panel_bed).stem}_{self.PON_file_suffix}")
         sorted_pon_files = sorted(
             pon_list,
-            key=lambda file: int(file.stem.split("_v")[ListIndexes.LAST.value]),
+            key=lambda file: int(file.stem.split("_v")[-1]),
             reverse=True,
         )
 
         return sorted_pon_files[0].as_posix() if sorted_pon_files else None
 
     @staticmethod
-    def get_verified_gender(sample_data: dict) -> Union[Gender.FEMALE, Gender.MALE]:
-        """Takes a dict with samples and attributes, and returns a verified case gender provided by the customer"""
-
-        gender = next(iter(sample_data.values()))["gender"]
-
-        if all(val["gender"] == gender for val in sample_data.values()) and gender in set(
-            value for value in Gender
+    def get_verified_sex(sample_data: dict) -> Sex:
+        """Takes a dict with samples and attributes, and returns a verified case sex provided by the customer."""
+        sex: Sex = next(iter(sample_data.values()))["sex"]
+        if all(val["sex"] == sex for val in sample_data.values()) and sex in set(
+            value for value in Sex
         ):
-            if gender not in [Gender.FEMALE, Gender.MALE]:
-                LOG.warning(
-                    f"The provided gender is unknown, setting {Gender.FEMALE.value} as the default"
-                )
-                gender = Gender.FEMALE.value
+            if sex not in [Sex.FEMALE, Sex.MALE]:
+                LOG.warning(f"The provided sex is unknown, setting {Sex.FEMALE} as the default")
+                sex = Sex.FEMALE
 
-            return gender
+            return sex
         else:
-            LOG.error(f"Unable to retrieve a valid gender from samples: {sample_data.keys()}")
+            LOG.error(f"Unable to retrieve a valid sex from samples: {sample_data.keys()}")
             raise BalsamicStartError
 
-    def get_verified_samples(
-        self, case_id: str, sample_data: dict, force_normal: bool
-    ) -> Dict[str, str]:
+    def get_verified_samples(self, case_id: str) -> dict[str, str]:
         """Return a verified tumor and normal sample dictionary."""
-
-        tumor_samples: List[Sample] = self.status_db.get_samples_by_type(
+        tumor_samples: list[Sample] = self.status_db.get_samples_by_type(
             case_id=case_id, sample_type=SampleType.TUMOR
         )
-        normal_samples: List[Sample] = self.status_db.get_samples_by_type(
+        normal_samples: list[Sample] = self.status_db.get_samples_by_type(
             case_id=case_id, sample_type=SampleType.NORMAL
         )
         if (
@@ -321,34 +290,15 @@ class BalsamicAnalysisAPI(AnalysisAPI):
 
         tumor_sample_id: str = tumor_samples[0].internal_id if tumor_samples else None
         normal_sample_id: str = normal_samples[0].internal_id if normal_samples else None
-        tumor_sample_path: str = (
-            sample_data.get(tumor_sample_id).get("concatenated_path") if tumor_sample_id else None
-        )
-        normal_sample_path: str = (
-            sample_data.get(normal_sample_id).get("concatenated_path") if normal_sample_id else None
-        )
         if normal_sample_id and not tumor_sample_id:
-            if force_normal:
-                LOG.warning(
-                    f"Only a normal sample was found for case {case_id}. "
-                    f"Balsamic analysis will treat it as a tumor sample."
-                )
-                tumor_sample_id, tumor_sample_path = normal_sample_id, normal_sample_path
-                normal_sample_id, normal_sample_path = None, None
-            else:
-                LOG.error(
-                    f"Case {case_id} only has a normal sample. Use the --force-normal flag to treat it as a tumor."
-                )
-                raise BalsamicStartError
+            LOG.warning(
+                f"Only a normal sample was found for case {case_id}. "
+                f"Balsamic analysis will treat it as a tumor sample."
+            )
+            tumor_sample_id, normal_sample_id = normal_sample_id, None
+        return {"tumor_sample_name": tumor_sample_id, "normal_sample_name": normal_sample_id}
 
-        return {
-            "tumor_sample_name": tumor_sample_id,
-            "tumor": tumor_sample_path,
-            "normal_sample_name": normal_sample_id,
-            "normal": normal_sample_path,
-        }
-
-    def get_latest_raw_file_data(self, case_id: str, tags: list) -> Union[dict, list]:
+    def get_latest_raw_file_data(self, case_id: str, tags: list) -> dict | list:
         """Retrieves the data of the latest file associated to a specific case ID and a list of tags."""
 
         version: Version = self.housekeeper_api.last_version(bundle=case_id)
@@ -365,10 +315,10 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         )
 
     def get_latest_metadata(self, case_id: str) -> BalsamicAnalysis:
-        """Get the latest metadata of a specific BALSAMIC case"""
+        """Return the latest metadata of a specific BALSAMIC case."""
 
-        config_raw_data = self.get_latest_raw_file_data(case_id, [BalsamicAnalysisTag.CONFIG])
-        metrics_raw_data = self.get_latest_raw_file_data(case_id, [BalsamicAnalysisTag.QC_METRICS])
+        config_raw_data = self.get_latest_raw_file_data(case_id, BalsamicAnalysisTag.CONFIG)
+        metrics_raw_data = self.get_latest_raw_file_data(case_id, BalsamicAnalysisTag.QC_METRICS)
 
         if config_raw_data and metrics_raw_data:
             try:
@@ -377,11 +327,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
                 )
                 return balsamic_analysis
             except ValidationError as error:
-                LOG.error(
-                    "get_latest_metadata failed for '%s', missing attribute: %s",
-                    case_id,
-                    error,
-                )
+                LOG.error(f"get_latest_metadata failed for '{case_id}', missing attribute: {error}")
                 raise error
         else:
             LOG.error(f"Unable to retrieve the latest metadata for {case_id}")
@@ -410,7 +356,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
     @staticmethod
     def cast_metrics_type(
         sequencing_type: str, metrics: dict
-    ) -> Union[BalsamicTargetedQCMetrics, BalsamicWGSQCMetrics]:
+    ) -> BalsamicTargetedQCMetrics | BalsamicWGSQCMetrics:
         """Cast metrics model type according to the sequencing type"""
 
         if metrics:
@@ -424,7 +370,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         return metrics
 
     @staticmethod
-    def get_latest_file_by_pattern(directory: Path, pattern: str) -> Optional[str]:
+    def get_latest_file_by_pattern(directory: Path, pattern: str) -> str | None:
         """Returns the latest file (<file_name>-<date>-.vcf.gz) matching a pattern from a specific directory."""
         available_files: iter = sorted(
             Path(directory).glob(f"*{pattern}*.vcf.gz"),
@@ -433,24 +379,38 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         )
         return str(available_files[0]) if available_files else None
 
-    def get_parsed_observation_file_paths(self, observations: List[str]) -> dict:
+    def get_parsed_observation_file_paths(self, observations: list[str]) -> dict:
         """Returns a verified {option: path} observations dictionary."""
-        verified_observations: Dict[str, str] = {}
+        verified_observations: dict[str, str] = {}
         for wildcard in list(ObservationsFileWildcards):
             file_path: str = get_string_from_list_by_pattern(observations, wildcard)
             verified_observations.update(
                 {
-                    wildcard: file_path
-                    if file_path
-                    else self.get_latest_file_by_pattern(
-                        directory=self.loqusdb_path, pattern=wildcard
+                    wildcard: (
+                        file_path
+                        if file_path
+                        else self.get_latest_file_by_pattern(
+                            directory=self.loqusdb_path, pattern=wildcard
+                        )
                     )
                 }
             )
 
         return verified_observations
 
-    def get_swegen_verified_path(self, variants: Variants) -> Optional[str]:
+    def get_verified_gens_file_paths(self, sex: Sex) -> dict[str, str] | None:
+        """Return a list of file path arguments for Gens."""
+        return {
+            "genome_interval": self.genome_interval_path,
+            "gnomad_min_af5": self.gnomad_af5_path,
+            "gens_coverage_pon": (
+                self.gens_coverage_female_path
+                if sex == Sex.FEMALE
+                else self.gens_coverage_male_path
+            ),
+        }
+
+    def get_swegen_verified_path(self, variants: Variants) -> str | None:
         """Return verified SweGen path."""
         swegen_file: str = self.get_latest_file_by_pattern(
             directory=self.swegen_path, pattern=variants
@@ -463,9 +423,8 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         genome_version: str,
         panel_bed: str,
         pon_cnn: str,
-        force_normal: bool = False,
-        observations: List[str] = None,
-        gender: Optional[str] = None,
+        observations: list[str] = None,
+        sex: str | None = None,
     ) -> dict:
         """Takes a dictionary with per-sample parameters,
         validates them, and transforms into command line arguments
@@ -482,23 +441,29 @@ class BalsamicAnalysisAPI(AnalysisAPI):
             if verified_panel_bed
             else None
         )
+        verified_sex: Sex = sex or self.get_verified_sex(sample_data=sample_data)
 
-        config_case: Dict[str, str] = {
+        verified_exome_argument: bool = self.has_case_only_exome_samples(case_id=case_id)
+
+        config_case: dict[str, str] = {
             "case_id": case_id,
-            "analysis_workflow": self.pipeline,
+            "analysis_workflow": self.workflow,
             "genome_version": genome_version,
-            "gender": gender or self.get_verified_gender(sample_data=sample_data),
+            "sex": verified_sex,
             "panel_bed": verified_panel_bed,
             "pon_cnn": verified_pon,
             "swegen_snv": self.get_swegen_verified_path(Variants.SNV),
             "swegen_sv": self.get_swegen_verified_path(Variants.SV),
+            "exome": verified_exome_argument,
         }
-        config_case.update(
-            self.get_verified_samples(
-                case_id=case_id, sample_data=sample_data, force_normal=force_normal
-            )
-        )
+
+        config_case.update(self.get_verified_samples(case_id=case_id))
         config_case.update(self.get_parsed_observation_file_paths(observations))
+        (
+            config_case.update(self.get_verified_gens_file_paths(sex=verified_sex))
+            if not verified_panel_bed
+            else None
+        )
 
         return config_case
 
@@ -523,15 +488,14 @@ class BalsamicAnalysisAPI(AnalysisAPI):
             )
         LOG.info("")
 
-    def get_sample_params(self, case_id: str, panel_bed: Optional[str]) -> dict:
+    def get_sample_params(self, case_id: str, panel_bed: str | None) -> dict:
         """Returns a dictionary of attributes for each sample in given family,
         where SAMPLE ID is used as key"""
 
         sample_data = {
             link_object.sample.internal_id: {
-                "gender": self.get_gender(link_object.sample),
+                "sex": link_object.sample.sex,
                 "tissue_type": self.get_sample_type(link_object.sample).value,
-                "concatenated_path": self.get_concatenated_fastq_path(link_object).as_posix(),
                 "application_type": self.get_application_type(link_object.sample),
                 "target_bed": self.resolve_target_bed(panel_bed=panel_bed, link_object=link_object),
             }
@@ -541,26 +505,15 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         self.print_sample_params(case_id=case_id, sample_data=sample_data)
         return sample_data
 
-    def get_case_application_type(self, case_id: str) -> str:
-        application_types = {
-            self.get_application_type(link_object.sample)
-            for link_object in self.status_db.get_case_by_internal_id(internal_id=case_id).links
-        }
-
-        if application_types:
-            return application_types.pop().lower()
-
-    def resolve_target_bed(
-        self, panel_bed: Optional[str], link_object: FamilySample
-    ) -> Optional[str]:
+    def resolve_target_bed(self, panel_bed: str | None, link_object: CaseSample) -> str | None:
         if panel_bed:
             return panel_bed
         if self.get_application_type(link_object.sample) not in self.__BALSAMIC_BED_APPLICATIONS:
             return None
-        return self.get_target_bed_from_lims(link_object.family.internal_id)
+        return self.get_target_bed_from_lims(link_object.case.internal_id)
 
-    def get_pipeline_version(self, case_id: str) -> str:
-        LOG.debug("Fetch pipeline version")
+    def get_workflow_version(self, case_id: str) -> str:
+        LOG.debug("Fetch workflow version")
         config_data: dict = ReadFile.get_content_from_file(
             file_format=FileFormat.JSON, file_path=self.get_case_config_path(case_id=case_id)
         )
@@ -573,44 +526,52 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         genome_version: str,
         panel_bed: str,
         pon_cnn: str,
-        observations: List[str],
-        force_normal: bool,
+        observations: list[str],
+        cache_version: str,
         dry_run: bool = False,
     ) -> None:
         """Create config file for BALSAMIC analysis"""
         arguments = self.get_verified_config_case_arguments(
             case_id=case_id,
-            gender=gender,
+            sex=gender,
             genome_version=genome_version,
             panel_bed=panel_bed,
             pon_cnn=pon_cnn,
             observations=observations,
-            force_normal=force_normal,
         )
         command = ["config", "case"]
         options = build_command_from_dict(
             {
                 "--analysis-dir": self.root_dir,
-                "--balsamic-cache": self.balsamic_cache,
-                "--case-id": arguments.get("case_id"),
-                "--gender": arguments.get("gender"),
                 "--analysis-workflow": arguments.get("analysis_workflow"),
-                "--genome-version": arguments.get("genome_version"),
-                "--normal": arguments.get(SampleType.NORMAL.value),
-                "--tumor": arguments.get(SampleType.TUMOR.value),
-                "--panel-bed": arguments.get("panel_bed"),
-                "--pon-cnn": arguments.get("pon_cnn"),
-                "--umi-trim-length": arguments.get("umi_trim_length"),
-                "--tumor-sample-name": arguments.get("tumor_sample_name"),
-                "--normal-sample-name": arguments.get("normal_sample_name"),
-                "--swegen-snv": arguments.get("swegen_snv"),
-                "--swegen-sv": arguments.get("swegen_sv"),
-                "--clinical-snv-observations": arguments.get("clinical_snv"),
-                "--clinical-sv-observations": arguments.get("clinical_sv"),
-                "--cancer-all-snv-observations": arguments.get("cancer_all_snv"),
+                "--balsamic-cache": self.balsamic_cache,
+                "--cache-version": cache_version,
+                "--cadd-annotations": self.cadd_path,
+                "--cancer-germline-snv-observations": arguments.get("cancer_germline_snv"),
+                "--cancer-germline-sv-observations": arguments.get("cancer_germline_sv"),
                 "--cancer-somatic-snv-observations": arguments.get("cancer_somatic_snv"),
                 "--cancer-somatic-sv-observations": arguments.get("cancer_somatic_sv"),
-            }
+                "--case-id": arguments.get("case_id"),
+                "--clinical-snv-observations": arguments.get("clinical_snv"),
+                "--clinical-sv-observations": arguments.get("clinical_sv"),
+                "--fastq-path": self.get_sample_fastq_destination_dir(
+                    self.status_db.get_case_by_internal_id(case_id)
+                ),
+                "--gender": arguments.get("sex"),
+                "--genome-interval": arguments.get("genome_interval"),
+                "--genome-version": arguments.get("genome_version"),
+                "--gens-coverage-pon": arguments.get("gens_coverage_pon"),
+                "--gnomad-min-af5": arguments.get("gnomad_min_af5"),
+                "--normal-sample-name": arguments.get("normal_sample_name"),
+                "--panel-bed": arguments.get("panel_bed"),
+                "--exome": arguments.get("exome"),
+                "--pon-cnn": arguments.get("pon_cnn"),
+                "--swegen-snv": arguments.get("swegen_snv"),
+                "--swegen-sv": arguments.get("swegen_sv"),
+                "--tumor-sample-name": arguments.get("tumor_sample_name"),
+                "--umi-trim-length": arguments.get("umi_trim_length"),
+            },
+            exclude_true=True,
         )
         parameters = command + options
         self.process.run_command(parameters=parameters, dry_run=dry_run)
@@ -618,14 +579,14 @@ class BalsamicAnalysisAPI(AnalysisAPI):
     def run_analysis(
         self,
         case_id: str,
-        run_analysis: bool = True,
-        slurm_quality_of_service: Optional[str] = None,
+        cluster_config: Path | None = None,
+        slurm_quality_of_service: str | None = None,
         dry_run: bool = False,
     ) -> None:
         """Execute BALSAMIC run analysis with given options"""
 
         command = ["run", "analysis"]
-        run_analysis = ["--run-analysis"] if run_analysis else []
+        run_analysis = ["--run-analysis"] if not dry_run else []
         benchmark = ["--benchmark"]
         options = build_command_from_dict(
             {
@@ -633,6 +594,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
                 "--mail-user": self.email,
                 "--qos": slurm_quality_of_service or self.get_slurm_qos_for_case(case_id=case_id),
                 "--sample-config": self.get_case_config_path(case_id=case_id),
+                "--cluster-config": cluster_config,
             }
         )
         parameters = command + options + run_analysis + benchmark
@@ -649,3 +611,64 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         )
         parameters = command + options
         self.process.run_command(parameters=parameters, dry_run=dry_run)
+
+    def get_genome_build(self, case_id: str) -> str:
+        """Returns the reference genome build version of a Balsamic analysis."""
+        analysis_metadata: BalsamicAnalysis = self.get_latest_metadata(case_id)
+        return analysis_metadata.config.reference.reference_genome_version
+
+    @staticmethod
+    def get_variant_caller_version(var_caller_name: str, var_caller_versions: dict) -> str | None:
+        """Return the version of a specific Balsamic bioinformatic tool."""
+        for tool_name, versions in var_caller_versions.items():
+            if tool_name in var_caller_name:
+                return versions[0]
+        return None
+
+    def get_variant_callers(self, case_id: str) -> list[str]:
+        """
+        Return list of Balsamic variant-calling filters and their versions (if available) from the
+        config.json file.
+        """
+        analysis_metadata: BalsamicAnalysis = self.get_latest_metadata(case_id)
+        sequencing_type: str = analysis_metadata.config.analysis.sequencing_type
+        analysis_type: str = analysis_metadata.config.analysis.analysis_type
+        var_callers: dict[str, BalsamicVarCaller] = analysis_metadata.config.vcf
+        tool_versions: dict[str, list] = analysis_metadata.config.bioinfo_tools_version
+        analysis_var_callers = []
+        for var_caller_name, var_caller_attributes in var_callers.items():
+            if (
+                sequencing_type in var_caller_attributes.sequencing_type
+                and analysis_type in var_caller_attributes.analysis_type
+            ):
+                version: str = self.get_variant_caller_version(
+                    var_caller_name=var_caller_name, var_caller_versions=tool_versions
+                )
+                analysis_var_callers.append(
+                    f"{var_caller_name} (v{version})" if version else var_caller_name
+                )
+        return analysis_var_callers
+
+    def get_pons(self, case_id: str) -> list[str]:
+        """Return list of panel of normals used for analysis."""
+        pons: list[str] = []
+        analysis_metadata: BalsamicAnalysis = self.get_latest_metadata(case_id)
+        if analysis_metadata.config.panel:
+            if pon_cnn := analysis_metadata.config.panel.pon_cnn:
+                pons.append(pon_cnn)
+        return pons
+
+    def get_data_analysis_type(self, case_id: str) -> str | None:
+        """Return data analysis type carried out."""
+        return self.get_bundle_deliverables_type(case_id)
+
+    def is_analysis_normal_only(self, case_id: str) -> bool:
+        """Return whether the analysis is normal only."""
+        case: Case = self.status_db.get_case_by_internal_id(internal_id=case_id)
+        if case.non_tumour_samples and not case.tumour_samples:
+            return True
+        return False
+
+    def get_scout_upload_case_tags(self) -> dict:
+        """Return Balsamic Scout upload case tags."""
+        return BALSAMIC_CASE_TAGS
