@@ -1,18 +1,15 @@
 """Module for Flask-Admin views"""
-from datetime import datetime
-from gettext import gettext
-from typing import List, Union
 
-from cgmodels.cg.constants import Pipeline
-from flask import redirect, request, session, url_for, flash
+from gettext import gettext
+
+from flask import flash, redirect, request, session, url_for
 from flask_admin.actions import action
 from flask_admin.contrib.sqla import ModelView
 from flask_dance.contrib.google import google
 from markupsafe import Markup
 
-from cg.constants.constants import DataDelivery, CaseActions
-from cg.server.ext import db
-from cg.store.models import Sample
+from cg.constants.constants import NG_UL_SUFFIX, CaseActions, DataDelivery, Workflow
+from cg.server.ext import db, sample_service
 from cg.utils.flask.enum import SelectEnumField
 
 
@@ -34,14 +31,26 @@ def view_priority(unused1, unused2, model, unused3):
     return Markup("%s" % model.priority.name) if model else ""
 
 
-def view_family_sample_link(unused1, unused2, model, unused3):
-    """column formatter to open the family-sample view"""
+def view_flow_cell_internal_id(unused1, unused2, model, unused3):
+    """column formatter for priority"""
+    del unused1, unused2, unused3
+    return Markup("%s" % model.device.internal_id)
+
+
+def view_flow_cell_model(unused1, unused2, model, unused3):
+    """column formatter for priority"""
+    del unused1, unused2, unused3
+    return Markup("%s" % model.device.model)
+
+
+def view_case_sample_link(unused1, unused2, model, unused3):
+    """column formatter to open the case-sample view"""
 
     del unused1, unused2, unused3
 
     return Markup(
         "<a href='%s'>%s</a>"
-        % (url_for("familysample.index_view", search=model.internal_id), model.internal_id)
+        % (url_for("casesample.index_view", search=model.internal_id), model.internal_id)
     )
 
 
@@ -51,6 +60,46 @@ def is_external_application(unused1, unused2, model, unused3):
     return model.application_version.application.is_external if model.application_version else ""
 
 
+def view_sample_concentration_minimum(unused1, unused2, model, unused3):
+    """Column formatter to append unit"""
+    del unused1, unused2, unused3
+    return (
+        str(model.sample_concentration_minimum) + NG_UL_SUFFIX
+        if model.sample_concentration_minimum
+        else None
+    )
+
+
+def view_sample_concentration_maximum(unused1, unused2, model, unused3):
+    """Column formatter to append unit"""
+    del unused1, unused2, unused3
+    return (
+        str(model.sample_concentration_maximum) + NG_UL_SUFFIX
+        if model.sample_concentration_maximum
+        else None
+    )
+
+
+def view_sample_concentration_minimum_cfdna(unused1, unused2, model, unused3):
+    """Column formatter to append unit"""
+    del unused1, unused2, unused3
+    return (
+        str(model.sample_concentration_minimum_cfdna) + NG_UL_SUFFIX
+        if model.sample_concentration_minimum_cfdna
+        else None
+    )
+
+
+def view_sample_concentration_maximum_cfdna(unused1, unused2, model, unused3):
+    """Column formatter to append unit"""
+    del unused1, unused2, unused3
+    return (
+        str(model.sample_concentration_maximum_cfdna) + NG_UL_SUFFIX
+        if model.sample_concentration_maximum_cfdna
+        else None
+    )
+
+
 class ApplicationView(BaseView):
     """Admin view for Model.Application"""
 
@@ -66,6 +115,10 @@ class ApplicationView(BaseView):
         "is_external",
         "turnaround_time",
         "sample_concentration",
+        "sample_concentration_minimum",
+        "sample_concentration_maximum",
+        "sample_concentration_minimum_cfdna",
+        "sample_concentration_maximum_cfdna",
         "priority_processing",
         "is_archived",
     ]
@@ -79,6 +132,12 @@ class ApplicationView(BaseView):
         "updated_at",
         "category",
     ]
+    column_formatters = {
+        "sample_concentration_minimum": view_sample_concentration_minimum,
+        "sample_concentration_maximum": view_sample_concentration_maximum,
+        "sample_concentration_minimum_cfdna": view_sample_concentration_minimum_cfdna,
+        "sample_concentration_maximum_cfdna": view_sample_concentration_maximum_cfdna,
+    }
     column_filters = ["prep_category", "is_accredited"]
     column_searchable_list = ["tag", "prep_category"]
     form_excluded_columns = ["category", "versions"]
@@ -112,14 +171,47 @@ class ApplicationVersionView(BaseView):
         "price_clinical_trials",
         "price_research",
     ]
+    column_list = (
+        "application",
+        "version",
+        "valid_from",
+        "price_standard",
+        "price_priority",
+        "price_express",
+        "price_clinical_trials",
+        "price_research",
+        "comment",
+    )
     column_exclude_list = ["created_at", "updated_at"]
     column_filters = ["version", "application.tag"]
     column_formatters = {"application": ApplicationView.view_application_link}
     column_searchable_list = ["application.tag"]
     edit_modal = True
+    create_modal = True
     form_excluded_columns = ["samples", "pools", "microbial_samples"]
 
 
+class ApplicationLimitationsView(BaseView):
+    """Admin view for Model.ApplicationLimitations."""
+
+    column_list = (
+        "application",
+        "workflow",
+        "limitations",
+        "comment",
+        "created_at",
+        "updated_at",
+    )
+    column_formatters = {"application": ApplicationView.view_application_link}
+    column_filters = ["application.tag", "workflow"]
+    column_searchable_list = ["application.tag"]
+    column_editable_list = ["comment"]
+    form_excluded_columns = ["created_at", "updated_at"]
+    form_extra_fields = {"workflow": SelectEnumField(enum_class=Workflow)}
+    create_modal = True
+    edit_modal = True
+
+
 class BedView(BaseView):
     """Admin view for Model.Bed"""
 
@@ -164,6 +256,7 @@ class CustomerView(BaseView):
         "collaborations",
         "comment",
         "delivery_contact",
+        "lab_contact",
         "loqus_upload",
         "primary_contact",
         "priority",
@@ -171,18 +264,20 @@ class CustomerView(BaseView):
         "scout_access",
     ]
     column_list = [
-        "comment",
-        "delivery_contact",
         "internal_id",
         "name",
+        "data_archive_location",
+        "comment",
         "primary_contact",
+        "delivery_contact",
+        "lab_contact",
         "priority",
         "project_account_KI",
         "project_account_kth",
         "return_samples",
         "scout_access",
     ]
-    column_filters = ["priority", "scout_access"]
+    column_filters = ["priority", "scout_access", "data_archive_location"]
     column_searchable_list = ["internal_id", "name"]
     form_excluded_columns = ["families", "samples", "pools", "orders", "invoices"]
 
@@ -197,8 +292,8 @@ class CollaborationView(BaseView):
     column_searchable_list = ["internal_id", "name"]
 
 
-class FamilyView(BaseView):
-    """Admin view for Model.Family"""
+class CaseView(BaseView):
+    """Admin view for Model.Case"""
 
     column_default_sort = ("created_at", True)
     column_editable_list = ["action", "comment"]
@@ -212,7 +307,7 @@ class FamilyView(BaseView):
         "tickets",
     ]
     column_formatters = {
-        "internal_id": view_family_sample_link,
+        "internal_id": view_case_sample_link,
         "priority": view_priority,
     }
     column_searchable_list = [
@@ -228,19 +323,19 @@ class FamilyView(BaseView):
         "synopsis",
     ]
     form_extra_fields = {
-        "data_analysis": SelectEnumField(enum_class=Pipeline),
+        "data_analysis": SelectEnumField(enum_class=Workflow),
         "data_delivery": SelectEnumField(enum_class=DataDelivery),
     }
 
     @staticmethod
-    def view_family_link(unused1, unused2, model, unused3):
+    def view_case_link(unused1, unused2, model, unused3):
         """column formatter to open this view"""
         del unused1, unused2, unused3
         markup = ""
-        if model.family:
+        if model.case:
             markup += Markup(
                 " <a href='%s'>%s</a>"
-                % (url_for("family.index_view", search=model.family.internal_id), model.family)
+                % (url_for("case.index_view", search=model.case.internal_id), model.case)
             )
 
         return markup
@@ -250,7 +345,7 @@ class FamilyView(BaseView):
         "Set action to hold",
         "Are you sure you want to set the action for selected families to hold?",
     )
-    def action_set_hold(self, ids: List[str]):
+    def action_set_hold(self, ids: list[str]):
         self.set_action_for_cases(action=CaseActions.HOLD, case_entry_ids=ids)
 
     @action(
@@ -258,15 +353,15 @@ class FamilyView(BaseView):
         "Set action to Empty",
         "Are you sure you want to set the action for selected families to Empty?",
     )
-    def action_set_empty(self, ids: List[str]):
+    def action_set_empty(self, ids: list[str]):
         self.set_action_for_cases(action=None, case_entry_ids=ids)
 
-    def set_action_for_cases(self, action: Union[CaseActions, None], case_entry_ids: List[str]):
+    def set_action_for_cases(self, action: CaseActions | None, case_entry_ids: list[str]):
         try:
             for entry_id in case_entry_ids:
-                family = self.get_case_by_entry_id(entry_id=entry_id)
-                if family:
-                    family.action = action
+                case = db.get_case_by_entry_id(entry_id=entry_id)
+                if case:
+                    case.action = action
 
             db.session.commit()
 
@@ -282,17 +377,7 @@ class FamilyView(BaseView):
             if not self.handle_view_exception(ex):
                 raise
 
-            flash(gettext(f"Failed to set family action. {str(ex)}"))
-
-
-class FlowcellView(BaseView):
-    """Admin view for Model.Flowcell"""
-
-    column_default_sort = ("sequenced_at", True)
-    column_editable_list = ["status"]
-    column_exclude_list = ["archived_at"]
-    column_filters = ["sequencer_type", "sequencer_name", "status"]
-    column_searchable_list = ["name"]
+            flash(gettext(f"Failed to set case action. {str(ex)}"))
 
 
 class InvoiceView(BaseView):
@@ -321,9 +406,11 @@ class InvoiceView(BaseView):
                 "<a href='%s'>%s</a>"
                 % (
                     url_for("invoice.index_view", search=model.invoice.id),
-                    model.invoice.invoiced_at.date()
-                    if model.invoice.invoiced_at
-                    else "In progress",
+                    (
+                        model.invoice.invoiced_at.date()
+                        if model.invoice.invoiced_at
+                        else "In progress"
+                    ),
                 )
             )
             if model.invoice
@@ -335,14 +422,78 @@ class AnalysisView(BaseView):
     """Admin view for Model.Analysis"""
 
     column_default_sort = ("created_at", True)
-    column_editable_list = ["is_primary"]
-    column_filters = ["pipeline", "pipeline_version", "is_primary"]
-    column_formatters = {"family": FamilyView.view_family_link}
+    column_editable_list = ["is_primary", "comment"]
+    column_filters = ["workflow", "workflow_version", "is_primary"]
+    column_formatters = {"case": CaseView.view_case_link}
     column_searchable_list = [
-        "family.internal_id",
-        "family.name",
+        "case.internal_id",
+        "case.name",
     ]
-    form_extra_fields = {"pipeline": SelectEnumField(enum_class=Pipeline)}
+    form_extra_fields = {"workflow": SelectEnumField(enum_class=Workflow)}
+
+
+class IlluminaFlowCellView(BaseView):
+    """Admin view for Model.IlluminaSequencingRun"""
+
+    column_list = (
+        "internal_id",
+        "model",
+        "sequencer_type",
+        "sequencer_name",
+        "data_availability",
+        "has_backup",
+        "total_reads",
+        "total_undetermined_reads",
+        "percent_undetermined_reads",
+        "percent_q30",
+        "mean_quality_score",
+        "total_yield",
+        "yield_q30",
+        "cycles",
+        "demultiplexing_software",
+        "demultiplexing_software_version",
+        "sequencing_started_at",
+        "sequencing_completed_at",
+        "demultiplexing_started_at",
+        "demultiplexing_completed_at",
+        "archived_at",
+    )
+    column_formatters = {"internal_id": view_flow_cell_internal_id, "model": view_flow_cell_model}
+    column_default_sort = ("sequencing_completed_at", True)
+    column_filters = ["sequencer_type", "sequencer_name", "data_availability"]
+    column_editable_list = ["data_availability"]
+    column_searchable_list = ["sequencer_type", "sequencer_name", "device.internal_id"]
+    column_sortable_list = [
+        ("internal_id", "device.internal_id"),
+        "sequencer_type",
+        "sequencer_name",
+        "data_availability",
+        "has_backup",
+        "sequencing_started_at",
+        "sequencing_completed_at",
+        "demultiplexing_started_at",
+        "demultiplexing_completed_at",
+        "archived_at",
+    ]
+
+    @staticmethod
+    def view_flow_cell_link(unused1, unused2, model, unused3):
+        """column formatter to open this view"""
+        del unused1, unused2, unused3
+        return (
+            Markup(
+                "<a href='%s'>%s</a>"
+                % (
+                    url_for(
+                        "illuminasequencingrun.index_view",
+                        search=model.instrument_run.device.internal_id,
+                    ),
+                    model.instrument_run.device.internal_id,
+                )
+            )
+            if model.instrument_run.device
+            else ""
+        )
 
 
 class OrganismView(BaseView):
@@ -353,6 +504,17 @@ class OrganismView(BaseView):
     column_searchable_list = ["internal_id", "name", "reference_genome"]
 
 
+class OrderView(BaseView):
+    """Admin view for Model.Order"""
+
+    column_default_sort = ("order_date", True)
+    column_editable_list = ["is_delivered"]
+    column_searchable_list = ["id", "ticket_id"]
+    column_display_pk = True
+    create_modal = True
+    edit_modal = True
+
+
 class PanelView(BaseView):
     """Admin view for Model.Panel"""
 
@@ -378,7 +540,6 @@ class SampleView(BaseView):
 
     column_exclude_list = [
         "age_at_sampling",
-        "invoiced_at",
         "_phenotype_groups",
         "_phenotype_terms",
     ]
@@ -387,13 +548,13 @@ class SampleView(BaseView):
         "comment",
         "downsampled_to",
         "is_tumour",
-        "sequenced_at",
+        "last_sequenced_at",
         "sex",
     ]
     column_filters = ["customer.internal_id", "priority", "sex", "application_version.application"]
     column_formatters = {
         "is_external": is_external_application,
-        "internal_id": view_family_sample_link,
+        "internal_id": view_case_sample_link,
         "invoice": InvoiceView.view_invoice_link,
         "priority": view_priority,
     }
@@ -409,9 +570,7 @@ class SampleView(BaseView):
         "deliveries",
         "father_links",
         "flowcells",
-        "invoiced_at",
         "invoice",
-        "is_external",
         "_phenotype_groups",
         "_phenotype_terms",
         "links",
@@ -436,65 +595,13 @@ class SampleView(BaseView):
         "Cancel samples",
         "Are you sure you want to cancel the selected samples?",
     )
-    def cancel_samples(self, entry_ids: List[str]) -> None:
-        """
-        Action for cancelling samples:
-            - Comments each sample being cancelled with date and user.
-            - Deletes any relationship between the cancelled samples and cases.
-            - Deletes any cases that only contain samples being cancelled.
-        """
-        all_associated_case_ids: set = set()
-
-        for entry_id in entry_ids:
-            sample: Sample = db.get_sample_by_entry_id(entry_id=int(entry_id))
-
-            sample_case_ids: List[str] = [
-                case_sample.family.internal_id for case_sample in sample.links
-            ]
-            all_associated_case_ids.update(sample_case_ids)
-
-            db.delete_relationships_sample(sample=sample)
-            self.write_cancel_comment(sample=sample)
-
-        case_ids: List[str] = list(all_associated_case_ids)
-        db.delete_cases_without_samples(case_internal_ids=case_ids)
-        cases_with_remaining_samples: List[str] = db.filter_cases_with_samples(case_ids=case_ids)
-
-        self.display_cancel_confirmation(
-            sample_entry_ids=entry_ids, remaining_cases=cases_with_remaining_samples
+    def cancel_samples(self, entry_ids: list[str]) -> None:
+        user_email: str | None = session.get("user_email")
+        message: str = sample_service.cancel_samples(
+            sample_ids=entry_ids,
+            user_email=user_email,
         )
-
-    def write_cancel_comment(self, sample: Sample) -> None:
-        """Add comment to sample with date and user cancelling the sample."""
-        user_name: str = db.get_user_by_email(session.get("user_email")).name
-        date: str = datetime.now().strftime("%Y-%m-%d")
-        comment: str = f"Cancelled {date} by {user_name}"
-
-        db.add_sample_comment(sample=sample, comment=comment)
-
-    def display_cancel_confirmation(
-        self, sample_entry_ids: List[str], remaining_cases: List[str]
-    ) -> None:
-        """Show a summary of the cancelled samples and any cases in which other samples were present."""
-        samples: str = "sample" if len(sample_entry_ids) == 1 else "samples"
-        cases: str = "case" if len(remaining_cases) == 1 else "cases"
-
-        message: str = f"Cancelled {len(sample_entry_ids)} {samples}. "
-        case_message: str = ""
-
-        for case_id in remaining_cases:
-            case_message = f"{case_message} {case_id},"
-
-        case_message = case_message.strip(",")
-
-        if remaining_cases:
-            message += (
-                f"Found {len(remaining_cases)} {cases} with additional samples: {case_message}."
-            )
-        else:
-            message += "No case contained additional samples."
-
-        flash(message=message)
+        flash(message)
 
 
 class DeliveryView(BaseView):
@@ -508,17 +615,17 @@ class DeliveryView(BaseView):
     edit_modal = True
 
 
-class FamilySampleView(BaseView):
-    """Admin view for Model.FamilySample"""
+class CaseSampleView(BaseView):
+    """Admin view for Model.caseSample"""
 
     column_default_sort = ("created_at", True)
     column_editable_list = ["status"]
     column_filters = ["status"]
     column_formatters = {
-        "family": FamilyView.view_family_link,
+        "case": CaseView.view_case_link,
         "sample": SampleView.view_sample_link,
     }
-    column_searchable_list = ["family.internal_id", "family.name", "sample.internal_id"]
+    column_searchable_list = ["case.internal_id", "case.name", "sample.internal_id"]
     create_modal = True
     edit_modal = True
 
@@ -536,10 +643,20 @@ class UserView(BaseView):
     edit_modal = True
 
 
-class SampleLaneSequencingMetricsView(BaseView):
-    """Admin view for the Model.SampleLaneSequencingMetrics."""
-
-    column_filters = ["sample_internal_id", "flow_cell_name"]
-    column_searchable_list = ["sample_internal_id", "flow_cell_name"]
-    create_modal = True
-    edit_modal = True
+class IlluminaSampleSequencingMetricsView(BaseView):
+    column_list = [
+        "flow_cell",
+        "sample",
+        "flow_cell_lane",
+        "total_reads_in_lane",
+        "base_passing_q30_percent",
+        "base_mean_quality_score",
+        "yield_",
+        "yield_q30",
+        "created_at",
+    ]
+    column_formatters = {
+        "flow_cell": IlluminaFlowCellView.view_flow_cell_link,
+        "sample": SampleView.view_sample_link,
+    }
+    column_searchable_list = ["sample.internal_id", "instrument_run.device.internal_id"]
