@@ -1,127 +1,67 @@
-import http
 import json
 import logging
 import tempfile
-from datetime import datetime
-from functools import wraps
+from http import HTTPStatus
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Any
 
-import requests
-from cachetools import TTLCache
-from cg.apps.orderform.excel_orderform_parser import ExcelOrderformParser
-from cg.apps.orderform.json_orderform_parser import JsonOrderformParser
-from cg.constants import ANALYSIS_SOURCES, METAGENOME_SOURCES
-from cg.constants.constants import FileFormat
-from cg.exc import OrderError, OrderFormError, TicketCreationError
-from cg.io.controller import WriteStream
-from cg.meta.orders import OrdersAPI
-from cg.models.orders.order import OrderIn, OrderType
-from cg.models.orders.orderform_schema import Orderform
-from cg.server.ext import db, lims, osticket
-from cg.store.models import Analysis, Application, Customer, Family, Flowcell, Pool, Sample, User
-from flask import Blueprint, abort, current_app, g, jsonify, make_response, request
-from google.auth import jwt
-from pydantic import ValidationError
+from flask import Blueprint, abort, g, jsonify, make_response, request
+from google.oauth2 import id_token
+from pydantic.v1 import ValidationError
 from requests.exceptions import HTTPError
 from sqlalchemy.exc import IntegrityError
 from urllib3.exceptions import MaxRetryError, NewConnectionError
 from werkzeug.utils import secure_filename
 
+from cg.apps.orderform.excel_orderform_parser import ExcelOrderformParser
+from cg.apps.orderform.json_orderform_parser import JsonOrderformParser
+from cg.constants import ANALYSIS_SOURCES, METAGENOME_SOURCES
+from cg.constants.constants import FileFormat
+from cg.exc import (
+    CaseNotFoundError,
+    OrderError,
+    OrderExistsError,
+    OrderFormError,
+    OrderMismatchError,
+    OrderNotDeliverableError,
+    OrderNotFoundError,
+    TicketCreationError,
+)
+from cg.io.controller import WriteStream
+from cg.meta.orders import OrdersAPI
+from cg.meta.orders.ticket_handler import TicketHandler
+from cg.models.orders.order import OrderIn, OrderType
+from cg.models.orders.orderform_schema import Orderform
+from cg.server.dto.delivery_message.delivery_message_request import DeliveryMessageRequest
+from cg.server.dto.delivery_message.delivery_message_response import DeliveryMessageResponse
+from cg.server.dto.orders.order_delivery_update_request import OrderDeliveredUpdateRequest
+from cg.server.dto.orders.order_patch_request import OrderDeliveredPatch
+from cg.server.dto.orders.orders_request import OrdersRequest
+from cg.server.dto.orders.orders_response import Order, OrdersResponse
+from cg.server.dto.sequencing_metrics.sequencing_metrics_request import SequencingMetricsRequest
+from cg.server.endpoints.utils import before_request, is_public
+from cg.server.ext import (
+    db,
+    delivery_message_service,
+    lims,
+    order_service,
+    osticket,
+)
+from cg.server.utils import parse_metrics_into_request
+from cg.store.models import (
+    Analysis,
+    Application,
+    ApplicationLimitations,
+    Case,
+    Customer,
+    IlluminaSampleSequencingMetrics,
+    Pool,
+    Sample,
+)
+
 LOG = logging.getLogger(__name__)
 BLUEPRINT = Blueprint("api", __name__, url_prefix="/api/v1")
-
-cache = TTLCache(maxsize=1, ttl=3600)
-cache_certificates_key = "certs"
-cache[cache_certificates_key] = None
-
-
-def get_certificate_ttl(response_data) -> int:
-    """Extract time to live in seconds for certificate from response headers."""
-    expires_header = response_data.headers.get("Expires")
-    expires = datetime.strptime(expires_header, "%a, %d %b %Y %H:%M:%S %Z")
-    return int((expires - datetime.utcnow()).total_seconds())
-
-
-def fetch_and_cache_google_oauth2_certificates():
-    """Fetch and cache Google OAuth2 certificates."""
-    global cache
-
-    url = "https://www.googleapis.com/oauth2/v1/certs"
-    response = requests.get(url)
-    response.raise_for_status()
-
-    certs = response.json()
-    ttl = get_certificate_ttl(response_data=response)
-
-    cache = TTLCache(maxsize=1, ttl=ttl)
-    cache[cache_certificates_key] = certs
-
-    return certs
-
-
-def get_google_oauth2_certificates():
-    """Get Google OAuth2 certificates from cache or fetch and cache them."""
-    certs = cache.get(cache_certificates_key)
-
-    if not certs:
-        certs = fetch_and_cache_google_oauth2_certificates()
-
-    return certs
-
-
-def is_public(route_function):
-    @wraps(route_function)
-    def public_endpoint(*args, **kwargs):
-        return route_function(*args, **kwargs)
-
-    public_endpoint.is_public = True
-    return public_endpoint
-
-
-@BLUEPRINT.before_request
-def before_request():
-    """Authorize API routes with JSON Web Tokens."""
-    if not request.is_secure:
-        return abort(
-            make_response(
-                jsonify(message="Only https requests accepted"), http.HTTPStatus.FORBIDDEN
-            )
-        )
-
-    if request.method == "OPTIONS":
-        return make_response(jsonify(ok=True), http.HTTPStatus.NO_CONTENT)
-
-    endpoint_func = current_app.view_functions[request.endpoint]
-    if getattr(endpoint_func, "is_public", None):
-        return
-
-    auth_header = request.headers.get("Authorization")
-    if not auth_header:
-        return abort(
-            make_response(
-                jsonify(message="no JWT token found on request"), http.HTTPStatus.UNAUTHORIZED
-            )
-        )
-
-    jwt_token = auth_header.split("Bearer ")[-1]
-    try:
-        user_data = jwt.decode(jwt_token, certs=get_google_oauth2_certificates())
-    except ValueError as e:
-        LOG.error(f"Error occurred while decoding JWT token: {e}")
-        return abort(
-            make_response(
-                jsonify(message="outdated login certificate"), http.HTTPStatus.UNAUTHORIZED
-            )
-        )
-
-    user: User = db.get_user_by_email(user_data["email"])
-    if user is None or not user.order_portal_login:
-        message = f"{user_data['email']} doesn't have access"
-        LOG.error(message)
-        return abort(make_response(jsonify(message=message), http.HTTPStatus.FORBIDDEN))
-
-    g.current_user = user
+BLUEPRINT.before_request(before_request)
 
 
 @BLUEPRINT.route("/submit_order/<order_type>", methods=["POST"])
@@ -137,23 +77,29 @@ def submit_order(order_type):
                 content=request_json, file_format=FileFormat.JSON
             ),
         )
-        project: OrderType = OrderType(order_type)
-        order_in: OrderIn = OrderIn.parse_obj(request_json, project=project)
+        project = OrderType(order_type)
+        order_in = OrderIn.parse_obj(request_json, project=project)
+        existing_ticket: str | None = TicketHandler.parse_ticket_number(order_in.name)
+        if existing_ticket and order_service.store.get_order_by_ticket_id(existing_ticket):
+            raise OrderExistsError(f"Order with ticket id {existing_ticket} already exists.")
 
-        result = api.submit(
+        result: dict = api.submit(
             project=project,
             order_in=order_in,
             user_name=g.current_user.name,
             user_mail=g.current_user.email,
         )
+        order_service.create_order(order_in)
+
     except (  # user misbehaviour
         OrderError,
+        OrderExistsError,
         OrderFormError,
         ValidationError,
         ValueError,
     ) as error:
         error_message = error.message if hasattr(error, "message") else str(error)
-        http_error_response = http.HTTPStatus.BAD_REQUEST
+        http_error_response = HTTPStatus.BAD_REQUEST
         LOG.error(error_message)
     except (  # system misbehaviour
         AttributeError,
@@ -169,7 +115,7 @@ def submit_order(order_type):
     ) as error:
         LOG.exception(error)
         error_message = error.message if hasattr(error, "message") else str(error)
-        http_error_response = http.HTTPStatus.INTERNAL_SERVER_ERROR
+        http_error_response = HTTPStatus.INTERNAL_SERVER_ERROR
     else:
         return jsonify(
             project=result["project"], records=[record.to_dict() for record in result["records"]]
@@ -185,22 +131,22 @@ def get_cases():
     enquiry: str = request.args.get("enquiry")
     action: str = request.args.get("action")
 
-    customers: List[Customer] = _get_current_customers()
-    cases: List[Family] = _get_cases(enquiry=enquiry, action=action, customers=customers)
+    customers: list[Customer] = _get_current_customers()
+    cases: list[Case] = _get_cases(enquiry=enquiry, action=action, customers=customers)
 
     nr_cases: int = len(cases)
-    cases_with_links: List[dict] = [case.to_dict(links=True) for case in cases]
+    cases_with_links: list[dict] = [case.to_dict(links=True) for case in cases]
     return jsonify(families=cases_with_links, total=nr_cases)
 
 
-def _get_current_customers() -> Optional[List[Customer]]:
+def _get_current_customers() -> list[Customer] | None:
     """Return customers if the current user is not an admin."""
     return g.current_user.customers if not g.current_user.is_admin else None
 
 
 def _get_cases(
-    enquiry: Optional[str], action: Optional[str], customers: Optional[List[Customer]]
-) -> List[Family]:
+    enquiry: str | None, action: str | None, customers: list[Customer] | None
+) -> list[Case]:
     """Get cases based on the provided filters."""
     return db.get_cases_by_customers_action_and_case_search(
         case_search=enquiry,
@@ -212,28 +158,50 @@ def _get_cases(
 @BLUEPRINT.route("/cases/<case_id>")
 def parse_case(case_id):
     """Return a case with links."""
-    case: Family = db.get_case_by_internal_id(internal_id=case_id)
+    case: Case = db.get_case_by_internal_id(internal_id=case_id)
     if case is None:
-        return abort(http.HTTPStatus.NOT_FOUND)
+        return abort(HTTPStatus.NOT_FOUND)
     if not g.current_user.is_admin and (case.customer not in g.current_user.customers):
-        return abort(http.HTTPStatus.FORBIDDEN)
+        return abort(HTTPStatus.FORBIDDEN)
     return jsonify(**case.to_dict(links=True, analyses=True))
 
 
+@BLUEPRINT.route("/cases/delivery_message", methods=["GET"])
+def get_cases_delivery_message():
+    delivery_message_request = DeliveryMessageRequest.model_validate(request.args)
+    try:
+        response: DeliveryMessageResponse = delivery_message_service.get_cases_message(
+            delivery_message_request
+        )
+        return jsonify(response.model_dump()), HTTPStatus.OK
+    except (CaseNotFoundError, OrderMismatchError) as error:
+        return jsonify({"error": str(error)}), HTTPStatus.BAD_REQUEST
+
+
+@BLUEPRINT.route("/cases/<case_id>/delivery_message", methods=["GET"])
+def get_case_delivery_message(case_id: str):
+    delivery_message_request = DeliveryMessageRequest(case_ids=[case_id])
+    try:
+        response: DeliveryMessageResponse = delivery_message_service.get_cases_message(
+            delivery_message_request
+        )
+        return jsonify(response.model_dump()), HTTPStatus.OK
+    except CaseNotFoundError as error:
+        return jsonify({"error": str(error)}), HTTPStatus.BAD_REQUEST
+
+
 @BLUEPRINT.route("/families_in_collaboration")
 def parse_families_in_collaboration():
     """Return cases in collaboration."""
 
     customer_internal_id = request.args.get("customer")
-    pipeline = request.args.get("data_analysis")
+    workflow = request.args.get("data_analysis")
     case_search_pattern = request.args.get("enquiry")
 
     customer = db.get_customer_by_internal_id(customer_internal_id=customer_internal_id)
 
-    cases = db.get_cases_by_customer_pipeline_and_case_search(
-        case_search=case_search_pattern,
-        customer=customer,
-        pipeline=pipeline,
+    cases = db.get_cases_by_customer_workflow_and_case_search(
+        customer=customer, workflow=workflow, case_search=case_search_pattern
     )
 
     case_dicts = [case.to_dict(links=True) for case in cases]
@@ -243,12 +211,12 @@ def parse_families_in_collaboration():
 @BLUEPRINT.route("/families_in_collaboration/<family_id>")
 def parse_family_in_collaboration(family_id):
     """Return a family with links."""
-    case: Family = db.get_case_by_internal_id(internal_id=family_id)
+    case: Case = db.get_case_by_internal_id(internal_id=family_id)
     customer: Customer = db.get_customer_by_internal_id(
         customer_internal_id=request.args.get("customer")
     )
     if case.customer not in customer.collaborators:
-        return abort(http.HTTPStatus.FORBIDDEN)
+        return abort(HTTPStatus.FORBIDDEN)
     return jsonify(**case.to_dict(links=True, analyses=True))
 
 
@@ -256,36 +224,22 @@ def parse_family_in_collaboration(family_id):
 def parse_samples():
     """Return samples."""
     if request.args.get("status") and not g.current_user.is_admin:
-        return abort(http.HTTPStatus.FORBIDDEN)
+        return abort(HTTPStatus.FORBIDDEN)
     if request.args.get("status") == "incoming":
-        samples: List[Sample] = db.get_samples_to_receive()
+        samples: list[Sample] = db.get_samples_to_receive()
     elif request.args.get("status") == "labprep":
-        samples: List[Sample] = db.get_samples_to_prepare()
+        samples: list[Sample] = db.get_samples_to_prepare()
     elif request.args.get("status") == "sequencing":
-        samples: List[Sample] = db.get_samples_to_sequence()
+        samples: list[Sample] = db.get_samples_to_sequence()
     else:
-        customers: Optional[List[Customer]] = (
+        customers: list[Customer] | None = (
             None if g.current_user.is_admin else g.current_user.customers
         )
-        samples: List[Sample] = db.get_samples_by_customer_id_and_pattern(
+        samples: list[Sample] = db.get_samples_by_customer_id_and_pattern(
             pattern=request.args.get("enquiry"), customers=customers
         )
     limit = int(request.args.get("limit", 50))
-    parsed_samples: List[Dict] = [sample.to_dict() for sample in samples[:limit]]
-    return jsonify(samples=parsed_samples, total=len(samples))
-
-
-@BLUEPRINT.route("/samples_in_collaboration")
-def parse_samples_in_collaboration():
-    """Return samples in a customer group."""
-    customer: Customer = db.get_customer_by_internal_id(
-        customer_internal_id=request.args.get("customer")
-    )
-    samples: List[Sample] = db.get_samples_by_customer_id_and_pattern(
-        pattern=request.args.get("enquiry"), customers=customer.collaborators
-    )
-    limit = int(request.args.get("limit", 50))
-    parsed_samples: List[Dict] = [sample.to_dict() for sample in samples[:limit]]
+    parsed_samples: list[dict] = [sample.to_dict() for sample in samples[:limit]]
     return jsonify(samples=parsed_samples, total=len(samples))
 
 
@@ -294,9 +248,9 @@ def parse_sample(sample_id):
     """Return a single sample."""
     sample: Sample = db.get_sample_by_internal_id(sample_id)
     if sample is None:
-        return abort(http.HTTPStatus.NOT_FOUND)
+        return abort(HTTPStatus.NOT_FOUND)
     if not g.current_user.is_admin and (sample.customer not in g.current_user.customers):
-        return abort(http.HTTPStatus.FORBIDDEN)
+        return abort(HTTPStatus.FORBIDDEN)
     return jsonify(**sample.to_dict(links=True, flowcells=True))
 
 
@@ -308,20 +262,20 @@ def parse_sample_in_collaboration(sample_id):
         customer_internal_id=request.args.get("customer")
     )
     if sample.customer not in customer.collaborators:
-        return abort(http.HTTPStatus.FORBIDDEN)
+        return abort(HTTPStatus.FORBIDDEN)
     return jsonify(**sample.to_dict(links=True, flowcells=True))
 
 
 @BLUEPRINT.route("/pools")
 def parse_pools():
     """Return pools."""
-    customers: Optional[List[Customer]] = (
+    customers: list[Customer] | None = (
         g.current_user.customers if not g.current_user.is_admin else None
     )
-    pools: List[Pool] = db.get_pools_to_render(
+    pools: list[Pool] = db.get_pools_to_render(
         customers=customers, enquiry=request.args.get("enquiry")
     )
-    parsed_pools: List[Dict] = [pool_obj.to_dict() for pool_obj in pools[:30]]
+    parsed_pools: list[dict] = [pool_obj.to_dict() for pool_obj in pools[:30]]
     return jsonify(pools=parsed_pools, total=len(pools))
 
 
@@ -330,54 +284,51 @@ def parse_pool(pool_id):
     """Return a single pool."""
     pool: Pool = db.get_pool_by_entry_id(entry_id=pool_id)
     if pool is None:
-        return abort(http.HTTPStatus.NOT_FOUND)
+        return abort(HTTPStatus.NOT_FOUND)
     if not g.current_user.is_admin and (pool.customer not in g.current_user.customers):
-        return abort(http.HTTPStatus.FORBIDDEN)
+        return abort(HTTPStatus.FORBIDDEN)
     return jsonify(**pool.to_dict())
 
 
-@BLUEPRINT.route("/flowcells")
-def parse_flow_cells() -> Any:
-    """Return flow cells."""
-    flow_cells: List[Flowcell] = db.get_flow_cell_by_name_pattern_and_status(
-        flow_cell_statuses=[request.args.get("status")],
-        name_pattern=request.args.get("enquiry"),
+@BLUEPRINT.route("/flowcells/<flow_cell_name>/sequencing_metrics", methods=["GET"])
+def get_sequencing_metrics(flow_cell_name: str):
+    """Return sample lane sequencing metrics for a flow cell."""
+    if not flow_cell_name:
+        return jsonify({"error": "Invalid or missing flow cell id"}), HTTPStatus.BAD_REQUEST
+    sequencing_metrics: list[IlluminaSampleSequencingMetrics] = (
+        db.get_illumina_sequencing_run_by_device_internal_id(flow_cell_name).sample_metrics
     )
-    parsed_flow_cells: List[Dict] = [flow_cell.to_dict() for flow_cell in flow_cells[:50]]
-    return jsonify(flowcells=parsed_flow_cells, total=len(flow_cells))
-
-
-@BLUEPRINT.route("/flowcells/<flowcell_id>")
-def parse_flow_cell(flowcell_id):
-    """Return a single flowcell."""
-    flow_cell: Flowcell = db.get_flow_cell_by_name(flow_cell_name=flowcell_id)
-    if flow_cell is None:
-        return abort(http.HTTPStatus.NOT_FOUND)
-    return jsonify(**flow_cell.to_dict(samples=True))
+    if not sequencing_metrics:
+        return (
+            jsonify({"error": f"Sequencing metrics not found for flow cell {flow_cell_name}."}),
+            HTTPStatus.NOT_FOUND,
+        )
+    metrics_dtos: list[SequencingMetricsRequest] = parse_metrics_into_request(sequencing_metrics)
+    return jsonify([metric.model_dump() for metric in metrics_dtos])
 
 
 @BLUEPRINT.route("/analyses")
 def parse_analyses():
     """Return analyses."""
     if request.args.get("status") == "delivery":
-        analyses: List[Analysis] = db.get_analyses_to_deliver_for_pipeline()
+        analyses: list[Analysis] = db.get_analyses_to_deliver_for_pipeline()
     elif request.args.get("status") == "upload":
-        analyses: List[Analysis] = db.get_analyses_to_upload()
+        analyses: list[Analysis] = db.get_analyses_to_upload()
     else:
-        analyses: List[Analysis] = db.get_analyses()
-    parsed_analysis: List[Dict] = [analysis_obj.to_dict() for analysis_obj in analyses[:30]]
+        analyses: list[Analysis] = db.get_analyses()
+    parsed_analysis: list[dict] = [analysis_obj.to_dict() for analysis_obj in analyses[:30]]
     return jsonify(analyses=parsed_analysis, total=len(analyses))
 
 
 @BLUEPRINT.route("/options")
 def parse_options():
     """Return various options."""
-    customers: List[Optional[Customer]] = (
+    customers: list[Customer | None] = (
         db.get_customers() if g.current_user.is_admin else g.current_user.customers
     )
 
-    app_tag_groups: Dict[str, List[str]] = {"ext": []}
-    applications: List[Application] = db.get_applications_is_not_archived()
+    app_tag_groups: dict[str, list[str]] = {"ext": []}
+    applications: list[Application] = db.get_applications_is_not_archived()
     for application in applications:
         if not application.versions:
             LOG.debug(f"Skipping application {application} that doesn't have a price")
@@ -385,7 +336,7 @@ def parse_options():
         if application.is_external:
             app_tag_groups["ext"].append(application.tag)
         if application.prep_category not in app_tag_groups:
-            app_tag_groups[application.prep_category]: List[str] = []
+            app_tag_groups[application.prep_category]: list[str] = []
         app_tag_groups[application.prep_category].append(application.tag)
 
     source_groups = {"metagenome": METAGENOME_SOURCES, "analysis": ANALYSIS_SOURCES}
@@ -422,7 +373,7 @@ def parse_current_user_information():
         LOG.error(
             "%s is not admin and is not connected to any customers, aborting", g.current_user.email
         )
-        return abort(http.HTTPStatus.FORBIDDEN)
+        return abort(HTTPStatus.FORBIDDEN)
 
     return jsonify(user=g.current_user.to_dict())
 
@@ -431,21 +382,91 @@ def parse_current_user_information():
 @is_public
 def parse_applications():
     """Return application tags."""
-    applications: List[Application] = db.get_applications_is_not_archived()
-    parsed_applications: List[Dict] = [application.to_dict() for application in applications]
+    applications: list[Application] = db.get_applications_is_not_archived()
+    parsed_applications: list[dict] = [application.to_dict() for application in applications]
     return jsonify(applications=parsed_applications)
 
 
 @BLUEPRINT.route("/applications/<tag>")
 @is_public
-def parse_application(tag):
+def parse_application(tag: str):
     """Return an application tag."""
     application: Application = db.get_application_by_tag(tag=tag)
-    if application is None:
-        return abort(
-            make_response(jsonify(message="application not found"), http.HTTPStatus.NOT_FOUND)
-        )
-    return jsonify(**application.to_dict())
+    if not application:
+        return abort(make_response(jsonify(message="Application not found"), HTTPStatus.NOT_FOUND))
+
+    application_limitations: list[ApplicationLimitations] = db.get_application_limitations_by_tag(
+        tag
+    )
+    application_dict: dict[str, Any] = application.to_dict()
+    application_dict["workflow_limitations"] = [
+        limitation.to_dict() for limitation in application_limitations
+    ]
+    return jsonify(**application_dict)
+
+
+@BLUEPRINT.route("/applications/<tag>/workflow_limitations")
+@is_public
+def get_application_workflow_limitations(tag: str):
+    """Return application workflow specific limitations."""
+    if application_limitations := db.get_application_limitations_by_tag(tag):
+        return jsonify([limitation.to_dict() for limitation in application_limitations])
+    else:
+        return jsonify(message="Application limitations not found"), HTTPStatus.NOT_FOUND
+
+
+@BLUEPRINT.route("/orders")
+def get_orders():
+    """Return the latest orders."""
+    data = OrdersRequest.model_validate(request.args.to_dict())
+    response: OrdersResponse = order_service.get_orders(data)
+    return make_response(response.model_dump())
+
+
+@BLUEPRINT.route("/orders/<order_id>")
+def get_order(order_id: int):
+    """Return an order."""
+    try:
+        response: Order = order_service.get_order(order_id)
+        response_dict: dict = response.model_dump()
+        return make_response(response_dict)
+    except OrderNotFoundError as error:
+        return make_response(jsonify(error=str(error)), HTTPStatus.NOT_FOUND)
+
+
+@BLUEPRINT.route("/orders/<order_id>/delivered", methods=["PATCH"])
+def set_order_delivered(order_id: int):
+    try:
+        request_data = OrderDeliveredPatch.model_validate(request.json)
+        delivered: bool = request_data.delivered
+        response_data: Order = order_service.set_delivery(order_id=order_id, delivered=delivered)
+        return jsonify(response_data.model_dump()), HTTPStatus.OK
+    except OrderNotFoundError as error:
+        return jsonify(error=str(error)), HTTPStatus.NOT_FOUND
+
+
+@BLUEPRINT.route("/orders/<order_id>/update-delivery-status", methods=["POST"])
+def update_order_delivered(order_id: int):
+    """Update the delivery status of an order based on the number of delivered analyses."""
+    try:
+        request_data = OrderDeliveredUpdateRequest.model_validate(request.json)
+        delivered_analyses: int = request_data.delivered_analyses_count
+        order_service.update_delivered(order_id=order_id, delivered_analyses=delivered_analyses)
+    except OrderNotFoundError as error:
+        return jsonify(error=str(error)), HTTPStatus.NOT_FOUND
+
+
+@BLUEPRINT.route("/orders/<order_id>/delivery_message")
+def get_delivery_message_for_order(order_id: int):
+    """Return the delivery message for an order."""
+    try:
+        response: DeliveryMessageResponse = delivery_message_service.get_order_message(order_id)
+        response_dict: dict = response.model_dump()
+        return make_response(response_dict)
+    except OrderNotDeliverableError as error:
+        return make_response(jsonify(error=str(error)), HTTPStatus.PRECONDITION_FAILED)
+    except OrderNotFoundError as error:
+        return make_response(jsonify(error=str(error))), HTTPStatus.NOT_FOUND
 
 
 @BLUEPRINT.route("/orderform", methods=["POST"])
@@ -476,7 +497,7 @@ def parse_orderform():
     ) as error:
         error_message = error.message if hasattr(error, "message") else str(error)
         LOG.error(error_message)
-        http_error_response = http.HTTPStatus.BAD_REQUEST
+        http_error_response = HTTPStatus.BAD_REQUEST
     except (  # system misbehaviour
         NewConnectionError,
         MaxRetryError,
@@ -485,9 +506,9 @@ def parse_orderform():
     ) as error:
         LOG.exception(error)
         error_message = error.message if hasattr(error, "message") else str(error)
-        http_error_response = http.HTTPStatus.INTERNAL_SERVER_ERROR
+        http_error_response = HTTPStatus.INTERNAL_SERVER_ERROR
     else:
-        return jsonify(**parsed_order.dict())
+        return jsonify(**parsed_order.model_dump())
 
     if error_message:
         return abort(make_response(jsonify(message=error_message), http_error_response))
