@@ -4,30 +4,34 @@ from flask import Flask, redirect, session, url_for
 from flask_admin.base import AdminIndexView
 from flask_dance.consumer import oauth_authorized
 from flask_dance.contrib.google import google, make_google_blueprint
+from sqlalchemy.orm import scoped_session
 
+from cg.server import admin, api, ext, invoices
+from cg.server.app_config import app_config
+from cg.server.endpoints.samples import SAMPLES_BLUEPRINT
+from cg.store.database import get_scoped_session_registry
 from cg.store.models import (
     Analysis,
     Application,
+    ApplicationLimitations,
     ApplicationVersion,
     Bed,
     BedVersion,
+    Case,
+    CaseSample,
     Collaboration,
     Customer,
-    Delivery,
-    Family,
-    FamilySample,
-    Flowcell,
+    IlluminaSequencingRun,
     Invoice,
+    Order,
     Organism,
     Panel,
     Pool,
     Sample,
     User,
-    SampleLaneSequencingMetrics,
+    IlluminaSampleSequencingMetrics,
 )
 
-from . import admin, api, ext, invoices
-
 
 def create_app():
     """Generate a flask application."""
@@ -40,8 +44,9 @@ def create_app():
     return app
 
 
-def _load_config(app):
-    app.config.from_object(__name__.replace("app", "config"))
+def _load_config(app: Flask):
+    app.config.update(app_config.dict())
+    app.secret_key = app.config["cg_secret_key"]
 
 
 def _configure_extensions(app: Flask):
@@ -53,9 +58,11 @@ def _configure_extensions(app: Flask):
     ext.csrf.init_app(app)
     ext.db.init_app(app)
     ext.lims.init_app(app)
-    if app.config["OSTICKET_API_KEY"]:
+    ext.analysis_client.init_app(app)
+    if app.config["osticket_api_key"]:
         ext.osticket.init_app(app)
     ext.admin.init_app(app, index_view=AdminIndexView(endpoint="admin"))
+    app.json_provider_class = ext.CustomJSONEncoder
 
 
 def _initialize_logging(app):
@@ -63,12 +70,9 @@ def _initialize_logging(app):
 
 
 def _register_blueprints(app: Flask):
-    if not app.config["CG_ENABLE_ADMIN"]:
-        return
-
     oauth_bp = make_google_blueprint(
-        client_id=app.config["GOOGLE_OAUTH_CLIENT_ID"],
-        client_secret=app.config["GOOGLE_OAUTH_CLIENT_SECRET"],
+        client_id=app.config["google_oauth_client_id"],
+        client_secret=app.config["google_oauth_client_secret"],
         scope=["openid", "https://www.googleapis.com/auth/userinfo.email"],
     )
 
@@ -83,6 +87,7 @@ def _register_blueprints(app: Flask):
     app.register_blueprint(api.BLUEPRINT)
     app.register_blueprint(invoices.BLUEPRINT, url_prefix="/invoices")
     app.register_blueprint(oauth_bp, url_prefix="/login")
+    app.register_blueprint(SAMPLES_BLUEPRINT)
     _register_admin_views()
 
     ext.csrf.exempt(api.BLUEPRINT)  # Protected with Auth header already
@@ -102,26 +107,29 @@ def _register_admin_views():
     # Base data views
     ext.admin.add_view(admin.ApplicationView(Application, ext.db.session))
     ext.admin.add_view(admin.ApplicationVersionView(ApplicationVersion, ext.db.session))
+    ext.admin.add_view(admin.ApplicationLimitationsView(ApplicationLimitations, ext.db.session))
     ext.admin.add_view(admin.BedView(Bed, ext.db.session))
     ext.admin.add_view(admin.BedVersionView(BedVersion, ext.db.session))
     ext.admin.add_view(admin.CustomerView(Customer, ext.db.session))
     ext.admin.add_view(admin.CollaborationView(Collaboration, ext.db.session))
     ext.admin.add_view(admin.OrganismView(Organism, ext.db.session))
+    ext.admin.add_view(admin.OrderView(Order, ext.db.session))
     ext.admin.add_view(admin.PanelView(Panel, ext.db.session))
     ext.admin.add_view(admin.UserView(User, ext.db.session))
-    ext.admin.add_view(
-        admin.SampleLaneSequencingMetricsView(SampleLaneSequencingMetrics, ext.db.session)
-    )
 
     # Business data views
-    ext.admin.add_view(admin.FamilyView(Family, ext.db.session))
-    ext.admin.add_view(admin.FamilySampleView(FamilySample, ext.db.session))
+    ext.admin.add_view(admin.CaseView(Case, ext.db.session))
+    ext.admin.add_view(admin.CaseSampleView(CaseSample, ext.db.session))
     ext.admin.add_view(admin.SampleView(Sample, ext.db.session))
     ext.admin.add_view(admin.PoolView(Pool, ext.db.session))
-    ext.admin.add_view(admin.FlowcellView(Flowcell, ext.db.session))
     ext.admin.add_view(admin.AnalysisView(Analysis, ext.db.session))
-    ext.admin.add_view(admin.DeliveryView(Delivery, ext.db.session))
     ext.admin.add_view(admin.InvoiceView(Invoice, ext.db.session))
+    ext.admin.add_view(
+        admin.IlluminaFlowCellView(IlluminaSequencingRun, ext.db.session, name="Illumina Flow Cell")
+    )
+    ext.admin.add_view(
+        admin.IlluminaSampleSequencingMetricsView(IlluminaSampleSequencingMetrics, ext.db.session)
+    )
 
 
 def _register_teardowns(app: Flask):
@@ -129,4 +137,10 @@ def _register_teardowns(app: Flask):
 
     @app.teardown_appcontext
     def remove_database_session(exception=None):
-        ext.db.session.remove()
+        """
+        Remove the database session to ensure database resources are
+        released when a request has been processed.
+        """
+        scoped_session_registry: scoped_session | None = get_scoped_session_registry()
+        if scoped_session_registry:
+            scoped_session_registry.remove()
