@@ -1,5 +1,6 @@
 from enum import Enum
-from typing import Callable, List, Optional
+from typing import Callable
+
 from sqlalchemy.orm import Query
 
 from cg.store.models import Organism
@@ -13,13 +14,13 @@ def filter_organism_by_internal_id(organisms: Query, internal_id: str, **kwargs)
 class OrganismFilter(Enum):
     """Define Organism filter functions."""
 
-    FILTER_BY_INTERNAL_ID: Callable = filter_organism_by_internal_id
+    BY_INTERNAL_ID: Callable = filter_organism_by_internal_id
 
 
 def apply_organism_filter(
     organisms: Query,
-    filter_functions: List[Callable],
-    internal_id: Optional[str] = None,
+    filter_functions: list[Callable],
+    internal_id: str | None = None,
 ) -> Query:
     """Apply filtering functions and return filtered results."""
     for filter_function in filter_functions:
