@@ -1,6 +1,8 @@
 from enum import Enum
-from typing import Callable, List, Optional
+from typing import Callable
+
 from sqlalchemy.orm import Query
+
 from cg.store.models import User
 
 
@@ -12,13 +14,13 @@ def filter_user_by_email(users: Query, email: str, **kwargs) -> Query:
 class UserFilter(Enum):
     """Define User filter functions."""
 
-    FILTER_BY_EMAIL: Callable = filter_user_by_email
+    BY_EMAIL: Callable = filter_user_by_email
 
 
 def apply_user_filter(
     users: Query,
-    filter_functions: List[Callable],
-    email: Optional[str] = None,
+    filter_functions: list[Callable],
+    email: str | None = None,
 ) -> Query:
     """Apply filtering functions and return filtered results."""
     for filter_function in filter_functions:
