@@ -2,10 +2,11 @@
 
 import logging
 
-from cg.cli.store.fastq import store_case
-from cg.models.cg_config import CGConfig
 from click.testing import CliRunner
 
+from cg.cli.store.store import store_case
+from cg.models.cg_config import CGConfig
+
 
 def test_store_fastq_cli_no_family(compress_context: CGConfig, cli_runner: CliRunner, caplog):
     """Test to run the compress command without providing any case id"""
