@@ -1,13 +1,15 @@
 """This script tests the cli methods to set values of several cases in status-db."""
+
 import logging
-from click.testing import CliRunner
+
 import pytest
 from _pytest.logging import LogCaptureFixture
+from click.testing import CliRunner
 
 from cg.cli.set.cases import set_cases
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from cg.store.models import Family, Sample
+from cg.store.models import Case, Sample
+from cg.store.store import Store
 from tests.store_helpers import StoreHelpers
 
 
@@ -25,7 +27,7 @@ def test_set_cases_by_sample_identifiers(
     new_sample: Sample = helpers.add_sample(base_store)
     new_sample.original_ticket: str = ticket_id
     new_sample.order: str = "An order"
-    case: Family = helpers.add_case(base_store)
+    case: Case = helpers.add_case(base_store)
     helpers.add_relationship(base_store, sample=new_sample, case=case)
     identifier_value = getattr(new_sample, identifier_key)
 
