@@ -1,21 +1,24 @@
 """Fixtures for cli balsamic tests."""
 
-from typing import Union
-
 import logging
 from datetime import datetime
 from pathlib import Path
 from tempfile import tempdir
 
 import pytest
-from cgmodels.cg.constants import Pipeline
+
 from cg.apps.gens import GensAPI
 from cg.apps.housekeeper.hk import HousekeeperAPI
 from cg.apps.scout.scoutapi import ScoutAPI
 from cg.apps.tb import TrailblazerAPI
-from cg.constants.constants import FileFormat
+from cg.constants import DELIVERY_REPORT_FILE_NAME
+from cg.constants.constants import FileFormat, Workflow
 from cg.constants.delivery import PIPELINE_ANALYSIS_TAG_MAP
-from cg.constants.housekeeper_tags import HkMipAnalysisTag, GensAnalysisTag, HK_DELIVERY_REPORT_TAG
+from cg.constants.housekeeper_tags import (
+    HK_DELIVERY_REPORT_TAG,
+    GensAnalysisTag,
+    HkMipAnalysisTag,
+)
 from cg.io.controller import ReadFile
 from cg.meta.deliver import DeliverAPI
 from cg.meta.rsync import RsyncAPI
@@ -24,26 +27,22 @@ from cg.meta.workflow.mip import MipAnalysisAPI
 from cg.meta.workflow.mip_dna import MipDNAAnalysisAPI
 from cg.models.cg_config import CGConfig
 from cg.models.scout.scout_load_config import ScoutLoadConfig
-from cg.store import Store
+from cg.services.fastq_concatenation_service.fastq_concatenation_service import (
+    FastqConcatenationService,
+)
 from cg.store.models import Analysis
+from cg.store.store import Store
+from tests.meta.upload.scout.conftest import mip_load_config
 from tests.mocks.hk_mock import MockHousekeeperAPI
 from tests.mocks.madeline import MockMadelineAPI
 from tests.mocks.report import MockMipDNAReportAPI
 from tests.store_helpers import StoreHelpers
 
-from tests.meta.upload.scout.conftest import fixture_mip_load_config
-from tests.cli.workflow.mip.conftest import (
-    fixture_mip_rna_context,
-    fixture_mip_dna_context,
-    fixture_mip_case_ids,
-    fixture_mip_case_id,
-)
-
 LOG = logging.getLogger(__name__)
 
 
-@pytest.fixture(name="upload_genotypes_hk_bundle")
-def fixture_upload_genotypes_hk_bundle(
+@pytest.fixture
+def upload_genotypes_hk_bundle(
     case_id: str, timestamp, case_qc_metrics_deliverables: Path, bcf_file: Path
 ) -> dict:
     """Returns a dictionary in hk format with files used in upload gt process"""
@@ -62,16 +61,16 @@ def fixture_upload_genotypes_hk_bundle(
     }
 
 
-@pytest.fixture(name="analysis_obj")
-def fixture_analysis_obj(
+@pytest.fixture
+def analysis_obj(
     analysis_store_trio: Store, case_id: str, timestamp: datetime, helpers
 ) -> Analysis:
     """Return a analysis object with a trio"""
     return analysis_store_trio.get_case_by_internal_id(internal_id=case_id).analyses[0]
 
 
-@pytest.fixture(name="upload_genotypes_hk_api")
-def fixture_upload_genotypes_hk_api(
+@pytest.fixture
+def upload_genotypes_hk_api(
     real_housekeeper_api: HousekeeperAPI,
     upload_genotypes_hk_bundle: dict,
     analysis_obj: Analysis,
@@ -79,13 +78,13 @@ def fixture_upload_genotypes_hk_api(
 ) -> HousekeeperAPI:
     """Add and include files from upload genotypes hk bundle"""
     helpers.ensure_hk_bundle(real_housekeeper_api, upload_genotypes_hk_bundle)
-    hk_version = real_housekeeper_api.last_version(analysis_obj.family.internal_id)
+    hk_version = real_housekeeper_api.last_version(analysis_obj.case.internal_id)
     real_housekeeper_api.include(hk_version)
     return real_housekeeper_api
 
 
-@pytest.fixture(name="upload_gens_hk_bundle")
-def fixture_upload_gens_hk_bundle(
+@pytest.fixture
+def upload_gens_hk_bundle(
     case_id: str,
     gens_coverage_path: Path,
     gens_fracsnp_path: Path,
@@ -113,8 +112,8 @@ def fixture_upload_gens_hk_bundle(
     }
 
 
-@pytest.fixture(name="upload_gens_hk_api")
-def fixture_upload_gens_hk_api(
+@pytest.fixture
+def upload_gens_hk_api(
     case_id: str,
     helpers: StoreHelpers,
     real_housekeeper_api: HousekeeperAPI,
@@ -127,8 +126,8 @@ def fixture_upload_gens_hk_api(
     return real_housekeeper_api
 
 
-@pytest.fixture(name="upload_gens_context")
-def fixture_upload_gens_context(
+@pytest.fixture
+def upload_gens_context(
     analysis_store_trio: Store,
     base_context: CGConfig,
     gens_api: GensAPI,
@@ -141,8 +140,8 @@ def fixture_upload_gens_context(
     return base_context
 
 
-@pytest.fixture(name="upload_report_hk_bundle")
-def fixture_upload_report_hk_bundle(case_id: str, delivery_report_html: Path, timestamp) -> dict:
+@pytest.fixture
+def upload_report_hk_bundle(case_id: str, delivery_report_html: Path, timestamp) -> dict:
     """Returns a dictionary including the delivery report html file"""
 
     return {
@@ -154,8 +153,8 @@ def fixture_upload_report_hk_bundle(case_id: str, delivery_report_html: Path, ti
     }
 
 
-@pytest.fixture(name="upload_report_hk_api")
-def fixture_upload_report_hk_api(
+@pytest.fixture
+def upload_report_hk_api(
     real_housekeeper_api: HousekeeperAPI,
     upload_report_hk_bundle: dict,
     analysis_obj: Analysis,
@@ -164,13 +163,13 @@ def fixture_upload_report_hk_api(
     """Add and include files from upload reports hk bundle"""
 
     helpers.ensure_hk_bundle(real_housekeeper_api, upload_report_hk_bundle)
-    hk_version = real_housekeeper_api.last_version(analysis_obj.family.internal_id)
+    hk_version = real_housekeeper_api.last_version(analysis_obj.case.internal_id)
     real_housekeeper_api.include(hk_version)
     return real_housekeeper_api
 
 
-@pytest.fixture(name="base_context")
-def fixture_base_context(
+@pytest.fixture
+def base_context(
     analysis_store: Store,
     housekeeper_api: HousekeeperAPI,
     upload_scout_api: UploadScoutAPI,
@@ -188,8 +187,8 @@ def fixture_base_context(
     return cg_context
 
 
-@pytest.fixture(name="fastq_context")
-def fixture_fastq_context(
+@pytest.fixture
+def fastq_context(
     base_context,
     analysis_store: Store,
     housekeeper_api: HousekeeperAPI,
@@ -202,18 +201,19 @@ def fixture_fastq_context(
     base_context.meta_apis["delivery_api"] = DeliverAPI(
         store=base_context.status_db,
         hk_api=base_context.housekeeper_api,
-        case_tags=PIPELINE_ANALYSIS_TAG_MAP[Pipeline.FASTQ]["case_tags"],
-        sample_tags=PIPELINE_ANALYSIS_TAG_MAP[Pipeline.FASTQ]["sample_tags"],
+        case_tags=PIPELINE_ANALYSIS_TAG_MAP[Workflow.FASTQ]["case_tags"],
+        sample_tags=PIPELINE_ANALYSIS_TAG_MAP[Workflow.FASTQ]["sample_tags"],
         delivery_type="fastq",
         project_base_path=Path(base_context.delivery_path),
+        fastq_file_service=FastqConcatenationService(),
     )
     base_context.meta_apis["rsync_api"] = RsyncAPI(cg_context)
     base_context.trailblazer_api_ = trailblazer_api
     return base_context
 
 
-@pytest.fixture(scope="function", name="upload_scout_api")
-def fixture_upload_scout_api(housekeeper_api: MockHousekeeperAPI, mip_load_config: ScoutLoadConfig):
+@pytest.fixture(scope="function")
+def upload_scout_api(housekeeper_api: MockHousekeeperAPI, mip_load_config: ScoutLoadConfig):
     """Return a upload scout api"""
     api = MockScoutUploadApi()
     api.housekeeper = housekeeper_api
@@ -247,7 +247,9 @@ class MockScoutUploadApi(UploadScoutAPI):
         self.housekeeper = None
         self.madeline_api = MockMadelineAPI()
         self.analysis = MockAnalysisApi()
-        self.config = ScoutLoadConfig()
+        self.config = ScoutLoadConfig(
+            delivery_report=Path("path", "to", DELIVERY_REPORT_FILE_NAME).as_posix()
+        )
         self.file_exists = False
         self.lims = MockLims()
         self.missing_mandatory_field = False
@@ -256,7 +258,7 @@ class MockScoutUploadApi(UploadScoutAPI):
     def _request_analysis(self, analysis_store_single_case):
         self.analysis = analysis_store_single_case
 
-    def generate_config(self, analysis_obj, **kwargs):
+    def generate_config(self, analysis, **kwargs):
         """Mock the generate config"""
         if self.missing_mandatory_field:
             self.config.vcf_snv = None
@@ -291,7 +293,7 @@ class MockLims:
         )
         return lims_case["samples"]
 
-    def sample(self, sample_id) -> Union[str, None]:
+    def sample(self, sample_id) -> str | None:
         """Returns a lims sample matching the provided sample_id"""
         for sample in self.lims_samples():
             if sample["id"] == sample_id:
@@ -299,7 +301,7 @@ class MockLims:
         return None
 
 
-@pytest.fixture(name="upload_context")
+@pytest.fixture
 def upload_context(cg_context: CGConfig) -> CGConfig:
     analysis_api = MipDNAAnalysisAPI(config=cg_context)
     cg_context.meta_apis["analysis_api"] = analysis_api
