@@ -1,9 +1,8 @@
 import logging
 
-from cgmodels.cg.constants import Pipeline
-
 from cg.cli.upload.clinical_delivery import auto_fastq
 from cg.constants import DataDelivery
+from cg.constants.constants import Workflow
 from cg.store.models import Analysis
 
 
@@ -13,8 +12,8 @@ def test_auto_fastq_not_started(
     """Tests if the command finds a non-uploaded analysis and attempts to start it"""
     caplog.set_level(logging.INFO)
     # GIVEN a case to be delivered
-    analysis_obj.pipeline = Pipeline.FASTQ
-    analysis_obj.family.data_delivery = DataDelivery.FASTQ
+    analysis_obj.workflow = Workflow.FASTQ
+    analysis_obj.case.data_delivery = DataDelivery.FASTQ
     base_context.status_db.session.commit()
     base_context.status_db.session.close()
     # WHEN the upload command is invoked with dry run
