@@ -1,12 +1,16 @@
 """Fixtures for cli analysis tests"""
+
 from datetime import datetime
 from pathlib import Path
+from unittest.mock import Mock
 
 import pytest
-from cg.constants import Pipeline, DataDelivery
+
+from cg.constants import DataDelivery, FileExtensions, SequencingRunDataAvailability, Workflow
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from cg.store.models import Family
+from cg.store.crud.read import ReadHandler
+from cg.store.models import Case
+from cg.store.store import Store
 from tests.store_helpers import StoreHelpers
 
 
@@ -17,41 +21,39 @@ def base_context(cg_context: CGConfig, analysis_store: Store) -> CGConfig:
     return cg_context
 
 
-@pytest.fixture(name="workflow_case_id")
-def fixture_workflow_case_id() -> str:
+@pytest.fixture
+def workflow_case_id() -> str:
     """Return a special case id"""
     return "dna_case"
 
 
-@pytest.fixture(scope="function", name="analysis_store")
-def fixture_analysis_store(
-    base_store: Store, workflow_case_id: str, helpers: StoreHelpers
-) -> Store:
+@pytest.fixture(scope="function")
+def analysis_store(base_store: Store, workflow_case_id: str, helpers: StoreHelpers) -> Store:
     """Store to be used in tests"""
     _store = base_store
 
-    case = helpers.add_case(_store, workflow_case_id, data_analysis=Pipeline.MIP_DNA)
+    case = helpers.add_case(_store, workflow_case_id, data_analysis=Workflow.MIP_DNA)
 
     dna_sample = helpers.add_sample(
-        _store, "dna_sample", is_rna=False, sequenced_at=datetime.now(), reads=10000000
+        _store, "dna_sample", is_rna=False, reads=10000000, last_sequenced_at=datetime.now()
     )
     helpers.add_relationship(_store, sample=dna_sample, case=case)
 
-    case = helpers.add_case(_store, "rna_case", data_analysis=Pipeline.MIP_RNA)
+    case = helpers.add_case(_store, "rna_case", data_analysis=Workflow.MIP_RNA)
     rna_sample = helpers.add_sample(
-        _store, "rna_sample", is_rna=True, sequenced_at=datetime.now(), reads=10000000
+        _store, "rna_sample", is_rna=True, reads=10000000, last_sequenced_at=datetime.now()
     )
     helpers.add_relationship(_store, sample=rna_sample, case=case)
 
-    case = helpers.add_case(_store, "dna_rna_mix_case", data_analysis=Pipeline.MIP_DNA)
+    case = helpers.add_case(_store, "dna_rna_mix_case", data_analysis=Workflow.MIP_DNA)
     helpers.add_relationship(_store, sample=rna_sample, case=case)
     helpers.add_relationship(_store, sample=dna_sample, case=case)
 
     return _store
 
 
-@pytest.fixture(name="fastq_context")
-def fixture_fastq_context(
+@pytest.fixture
+def fastq_context(
     base_context,
     cg_context: CGConfig,
     fastq_case,
@@ -62,19 +64,19 @@ def fixture_fastq_context(
     containing a fastq case"""
     _store = cg_context.status_db
     # Add fastq case to db
-    fastq_case["samples"][0]["sequenced_at"] = datetime.now()
+    fastq_case["samples"][0]["last_sequenced_at"] = datetime.now()
     helpers.ensure_case_from_dict(store=_store, case_info=fastq_case)
     return cg_context
 
 
-@pytest.fixture(name="fastq_case")
-def fixture_fastq_case(case_id, family_name, sample_id, cust_sample_id, ticket_id: str) -> dict:
+@pytest.fixture
+def fastq_case(case_id, family_name, sample_id, cust_sample_id, ticket_id: str) -> dict:
     """Returns a dict describing a fastq case"""
     return {
         "name": family_name,
         "panels": None,
         "internal_id": case_id,
-        "data_analysis": Pipeline.FASTQ,
+        "data_analysis": Workflow.FASTQ,
         "data_delivery": DataDelivery.FASTQ,
         "completed_at": None,
         "action": None,
@@ -93,36 +95,29 @@ def fixture_fastq_case(case_id, family_name, sample_id, cust_sample_id, ticket_i
 
 
 @pytest.fixture(scope="function")
-def dna_case(analysis_store, helpers) -> Family:
-    """Case with DNA application"""
-    cust = helpers.ensure_customer(analysis_store)
-    return analysis_store.get_case_by_name_and_customer(customer=cust, case_name="dna_case")
-
-
-@pytest.fixture(scope="function")
-def rna_case(analysis_store, helpers) -> Family:
+def rna_case(analysis_store, helpers) -> Case:
     """Case with RNA application"""
     cust = helpers.ensure_customer(analysis_store)
     return analysis_store.get_case_by_name_and_customer(customer=cust, case_name="rna_case")
 
 
 @pytest.fixture(scope="function")
-def dna_rna_mix_case(analysis_store, helpers) -> Family:
+def dna_rna_mix_case(analysis_store, helpers) -> Case:
     """Case with MIP analysis type DNA and RNA application"""
     cust = helpers.ensure_customer(analysis_store)
     return analysis_store.get_case_by_name_and_customer(customer=cust, case_name="dna_rna_mix_case")
 
 
-@pytest.fixture(name="create_multiqc_html_file")
-def fixture_create_multiqc_html_file(tmpdir_factory) -> Path:
+@pytest.fixture
+def create_multiqc_html_file(tmpdir_factory) -> Path:
     output_dir = tmpdir_factory.mktemp("output")
     file_path = Path(output_dir, "multiqc_report.html")
     file_path.touch(exist_ok=True)
     return file_path
 
 
-@pytest.fixture(name="create_multiqc_json_file")
-def fixture_create_multiqc_json_file(tmpdir_factory) -> Path:
+@pytest.fixture
+def create_multiqc_json_file(tmpdir_factory) -> Path:
     output_dir = tmpdir_factory.mktemp("output")
     file_path = Path(output_dir, "multiqc_report.json")
     file_path.touch(exist_ok=True)
@@ -134,7 +129,6 @@ class MockTB:
 
     def __init__(self):
         self._link_was_called = False
-        self._mark_analyses_deleted_called = False
         self._add_pending_was_called = False
         self._add_pending_analysis_was_called = False
         self._family = None
@@ -186,11 +180,6 @@ class MockTB:
 
         return Row()
 
-    def mark_analyses_deleted(self, case_id: str):
-        """Mock this function"""
-        self._case_id = case_id
-        self._mark_analyses_deleted_called = True
-
     def add_pending(self, case_id: str, email: str):
         """Mock this function"""
         self._case_id = case_id
@@ -203,10 +192,6 @@ class MockTB:
         self._email = email
         self._add_pending_analysis_was_called = True
 
-    def mark_analyses_deleted_called(self):
-        """check if mark_analyses_deleted was called"""
-        return self._mark_analyses_deleted_called
-
     def add_pending_was_called(self):
         """check if add_pending was called"""
         return self._add_pending_was_called
@@ -240,3 +225,36 @@ def tb_api():
     """Trailblazer API fixture"""
 
     return MockTB()
+
+
+@pytest.fixture
+def mock_analysis_illumina_run(mocker) -> None:
+    """Mocks the get_flow_cells_by_case method to return a list containing an "ondisk" flow cell."""
+    sequencing_run = Mock()
+    sequencing_run.data_availability = SequencingRunDataAvailability.ON_DISK
+    mocker.patch.object(ReadHandler, "get_illumina_sequencing_runs_by_case")
+    ReadHandler.get_illumina_sequencing_runs_by_case.return_value = [sequencing_run]
+
+
+@pytest.fixture(scope="session")
+def deliverables_template_content() -> list[dict]:
+    return [
+        {
+            "format": "yml",
+            "id": "CASEID",
+            "path": Path("PATHTOCASE", "pipeline_info", "software_versions.yml").as_posix(),
+            "path_index": None,
+            "step": "software-versions",
+            "tag": "software-versions",
+        },
+        {
+            "format": "json",
+            "id": "CASEID",
+            "path": Path("PATHTOCASE", "multiqc", "multiqc_data", "multiqc_data")
+            .with_suffix(FileExtensions.JSON)
+            .as_posix(),
+            "path_index": None,
+            "step": "multiqc-json",
+            "tag": "multiqc-json",
+        },
+    ]
