@@ -1,13 +1,19 @@
+import datetime as dt
+
+import pytest
+from click.testing import CliRunner
+
 from cg.cli.workflow.fluffy.base import start_available
 from cg.constants import EXIT_SUCCESS
 from cg.meta.workflow.fluffy import FluffyAnalysisAPI
 from cg.models.cg_config import CGConfig
-from click.testing import CliRunner
-import datetime as dt
+from cg.store.crud.read import ReadHandler
+from cg.store.models import Sample
 
 
+@pytest.mark.xfail(reason="flow cell on-disk check is yet to be refactored")
 def test_start_available_dry(
-    cli_runner: CliRunner, fluffy_case_id_existing: str, fluffy_context: CGConfig, caplog
+    cli_runner: CliRunner, fluffy_case_id_existing: str, fluffy_context: CGConfig, caplog, mocker
 ):
     caplog.set_level("INFO")
 
@@ -38,7 +44,7 @@ def test_start_available(
     fluffy_context: CGConfig,
     caplog,
     mocker,
-    samplesheet_fixture_path: str,
+    sample: Sample,
 ):
     caplog.set_level("INFO")
 
@@ -56,11 +62,7 @@ def test_start_available(
     mocker.patch.object(FluffyAnalysisAPI, "get_sample_name_from_lims_id")
     FluffyAnalysisAPI.get_sample_name_from_lims_id.return_value = "CustName"
 
-    # GIVEN every sample in SampleSheet has valid order field in StatusDB
-    mocker.patch.object(FluffyAnalysisAPI, "get_sample_starlims_id")
-    FluffyAnalysisAPI.get_sample_starlims_id.return_value = 12345678
-
-    # GIVEN every sample in SampleSheet sequenced_at set in StatusDB
+    # GIVEN every sample in SampleSheet last_sequenced_at set in StatusDB
     mocker.patch.object(FluffyAnalysisAPI, "get_sample_sequenced_date")
     FluffyAnalysisAPI.get_sample_sequenced_date.return_value = dt.datetime.now().date()
 
@@ -68,6 +70,10 @@ def test_start_available(
     mocker.patch.object(FluffyAnalysisAPI, "get_sample_control_status")
     FluffyAnalysisAPI.get_sample_control_status.return_value = False
 
+    # GIVEN a mocked response from status_db.get_sample_by_internal_id
+    mocker.patch.object(fluffy_context.status_db, "get_sample_by_internal_id")
+    fluffy_context.status_db.get_sample_by_internal_id.return_value = sample
+
     # WHEN running command
     result = cli_runner.invoke(start_available, [], obj=fluffy_context)
 
