@@ -1,7 +1,7 @@
 """ Fixtures for microsalt CLI test """
 
-
 import pytest
+
 from cg.meta.workflow.microsalt import MicrosaltAnalysisAPI
 from cg.models.cg_config import CGConfig
 from tests.store_helpers import StoreHelpers
@@ -84,8 +84,8 @@ def base_context(cg_context: CGConfig, helpers: StoreHelpers, lims_api):
     return cg_context
 
 
-@pytest.fixture(name="microbial_sample_id")
-def fixture_microbial_sample_id():
+@pytest.fixture
+def microbial_sample_id():
     """Define a name for a microbial sample"""
     return "microbial_sample_id"
 
