@@ -1,9 +1,10 @@
 """This script tests the CLI method enable workflows."""
 
+from click.testing import CliRunner
+
 from cg.cli.workflow.base import workflow as workflow_cmd
 from cg.constants import EXIT_SUCCESS
 from cg.models.cg_config import CGConfig
-from click.testing import CliRunner
 
 
 def test_no_options(cli_runner: CliRunner, base_context: CGConfig):
@@ -20,4 +21,6 @@ def test_no_options(cli_runner: CliRunner, base_context: CGConfig):
     assert "microsalt" in result.output
     assert "mip-dna" in result.output
     assert "mip-rna" in result.output
+    assert "raredisease" in result.output
     assert "rnafusion" in result.output
+    assert "taxprofiler" in result.output
