@@ -1,14 +1,15 @@
 """Tests for cleaning FASTQ files."""
+
 import logging
 from pathlib import Path
-from typing import Generator, Dict, List
+from typing import Generator
 
 from _pytest.logging import LogCaptureFixture
-
-from housekeeper.store.models import Version, File
+from housekeeper.store.models import File, Version
 
 from cg.apps.housekeeper.hk import HousekeeperAPI
 from cg.constants import SequencingFileTag
+from cg.constants.archiving import PDC_ARCHIVE_LOCATION
 from cg.meta.compress import files
 from cg.models import CompressionData
 from tests.cli.compress.conftest import MockCompressAPI
@@ -42,7 +43,8 @@ def test_remove_fastqs(
     assert compression_object.spring_metadata_path.exists()
     expected_output: str = f"Will remove {fastq_first} and {fastq_second}"
     assert expected_output in caplog.text
-    assert "FASTQ files removed" in caplog.text
+    assert f"FASTQ file {fastq_first} removed" in caplog.text
+    assert f"FASTQ file {fastq_second} removed" in caplog.text
 
 
 def test_update_hk_fastq(
@@ -75,7 +77,7 @@ def test_update_hk_fastq(
 
     # GIVEN a Housekeeper version and a compression object
     hk_version: Version = compress_api.hk_api.get_latest_bundle_version(bundle_name=sample_id)
-    fastq: Dict[str, dict] = files.get_fastq_files(sample_id=sample_id, version_obj=hk_version)
+    fastq: dict[str, dict] = files.get_fastq_files(sample_id=sample_id, version_obj=hk_version)
     run: str = list(fastq.keys())[0]
     compression: CompressionData = fastq[run]["compression_data"]
 
@@ -85,22 +87,32 @@ def test_update_hk_fastq(
         compression_obj=compression,
         hk_fastq_first=fastq[run]["hk_first"],
         hk_fastq_second=fastq[run]["hk_second"],
+        archive_location=PDC_ARCHIVE_LOCATION,
     )
 
     # THEN assert that the SPRING files have been added to Housekeeper
-    hk_spring_files: List[File] = list(real_housekeeper_api.files(tags=[SequencingFileTag.SPRING]))
-    hk_spring_metadata_files: List[File] = list(
+    hk_spring_files: list[File] = list(real_housekeeper_api.files(tags=[SequencingFileTag.SPRING]))
+    hk_spring_metadata_files: list[File] = list(
         real_housekeeper_api.files(tags=[SequencingFileTag.SPRING_METADATA])
     )
+
+    # THEN assert that the Spring files and Spring metadata files have had the fastq file tags transferred
     for spring_file in [hk_spring_files, hk_spring_metadata_files]:
         assert spring_file
+        for tag_name in [tag.name for tag in fastq[run]["hk_first"].tags]:
+            if tag_name != SequencingFileTag.FASTQ:
+                assert tag_name in spring_file.tags
+
+    # THEN assert that the spring files have been tagged with the archive location
+    for spring_file in hk_spring_files:
+        assert PDC_ARCHIVE_LOCATION in [tag.name for tag in spring_file.tags]
 
     # THEN assert that the SPRING files have been added to bundles directory
     for spring_file in [hk_spring_files[0].path, hk_spring_metadata_files[0].path]:
         assert Path(root_path, spring_file).exists()
 
     # THEN assert that the FASTQ files are removed from Housekeeper
-    hk_fastq_files: List[File] = list(hk_api.files(tags=[SequencingFileTag.FASTQ]))
+    hk_fastq_files: list[File] = list(hk_api.files(tags=[SequencingFileTag.FASTQ]))
     assert not hk_fastq_files
 
 
@@ -124,7 +136,9 @@ def test_cli_clean_fastqs_removed(
     assert fastq_second.exists()
 
     # WHEN running the clean command
-    populated_compress_fastq_api.clean_fastq(sample)
+    populated_compress_fastq_api.clean_fastq(
+        sample_id=sample, archive_location=PDC_ARCHIVE_LOCATION
+    )
 
     # THEN assert SPRING files exists
     assert spring_file.exists()
@@ -153,7 +167,9 @@ def test_cli_clean_fastqs_no_spring_metadata(
     assert not spring_metadata_file.exists()
 
     # WHEN running the clean command
-    populated_compress_fastq_api.clean_fastq(sample)
+    populated_compress_fastq_api.clean_fastq(
+        sample_id=sample, archive_location=PDC_ARCHIVE_LOCATION
+    )
 
     # THEN assert SPRING file exists
     assert spring_file.exists()
@@ -179,7 +195,9 @@ def test_cli_clean_fastqs_pending_compression_metadata(
     assert crunchy_flag_file.exists()
 
     # WHEN running the clean command
-    populated_compress_fastq_api.clean_fastq(sample)
+    populated_compress_fastq_api.clean_fastq(
+        sample_id=sample, archive_location=PDC_ARCHIVE_LOCATION
+    )
 
     # THEN assert SPRING file exists
     assert spring_file.exists()
