@@ -1,18 +1,23 @@
 """Fixtures for backup tests."""
+
 from pathlib import Path
 
 import pytest
+
 from cg.apps.housekeeper.hk import HousekeeperAPI
 from cg.constants.delivery import INBOX_NAME
 from cg.constants.housekeeper_tags import AlignmentFileTag
 from cg.meta.deliver import DeliverAPI
-from cg.store import Store
-from cg.store.models import Family
+from cg.services.fastq_concatenation_service.fastq_concatenation_service import (
+    FastqConcatenationService,
+)
+from cg.store.models import Case
+from cg.store.store import Store
 from tests.store_helpers import StoreHelpers
 
 
-@pytest.fixture(scope="function", name="deliver_api")
-def fixture_deliver_api(
+@pytest.fixture(scope="function")
+def deliver_api(
     analysis_store: Store, real_housekeeper_api: HousekeeperAPI, project_dir: Path
 ) -> DeliverAPI:
     """Fixture for deliver_api
@@ -27,12 +32,13 @@ def fixture_deliver_api(
         sample_tags=[{AlignmentFileTag.CRAM}],
         project_base_path=project_dir,
         delivery_type="balsamic",
+        fastq_file_service=FastqConcatenationService(),
     )
     yield _deliver_api
 
 
 @pytest.fixture(name="delivery_hk_api")
-def fixture_delivery_hk_api(
+def delivery_hk_api(
     mip_delivery_bundle,
     real_housekeeper_api: HousekeeperAPI,
     helpers=StoreHelpers,
@@ -44,7 +50,7 @@ def fixture_delivery_hk_api(
 
 
 @pytest.fixture(name="populated_deliver_api")
-def fixture_populated_deliver_api(
+def populated_deliver_api(
     analysis_store: Store, delivery_hk_api: HousekeeperAPI, project_dir: Path
 ) -> DeliverAPI:
     """Return a delivery api where housekeeper is populated with some files"""
@@ -55,18 +61,19 @@ def fixture_populated_deliver_api(
         sample_tags=[{AlignmentFileTag.CRAM}],
         project_base_path=project_dir,
         delivery_type="balsamic",
+        fastq_file_service=FastqConcatenationService(),
     )
     return _deliver_api
 
 
 @pytest.fixture(name="dummy_file_name")
-def fixture_dummy_file_name() -> str:
+def dummy_file_name() -> str:
     """Returns a dummy file name."""
     return "dummy_file_name"
 
 
 @pytest.fixture(name="all_samples_in_inbox")
-def fixture_all_samples_in_inbox(analysis_family, dummy_file_name: str, tmpdir_factory) -> Path:
+def all_samples_in_inbox(analysis_family, dummy_file_name: str, tmpdir_factory) -> Path:
     """Fixture that returns a customer inbox path with all samples delivered."""
     inbox = tmpdir_factory.mktemp(INBOX_NAME)
     for index in range(3):
@@ -78,7 +85,7 @@ def fixture_all_samples_in_inbox(analysis_family, dummy_file_name: str, tmpdir_f
 
 
 @pytest.fixture(name="samples_missing_in_inbox")
-def fixture_samples_missing_in_inbox(
+def samples_missing_in_inbox(
     all_samples_in_inbox: Path,
     analysis_family: dict,
     dummy_file_name: str,
@@ -89,5 +96,5 @@ def fixture_samples_missing_in_inbox(
 
 
 @pytest.fixture(name="deliver_api_destination_path")
-def fixture_deliver_api_destination_path(customer_id: str, case: Family, ticket_id: str) -> Path:
+def deliver_api_destination_path(customer_id: str, case: Case, ticket_id: str) -> Path:
     return Path(customer_id, INBOX_NAME, ticket_id, case.name)
