@@ -1,8 +1,6 @@
 from pathlib import Path
 
 import pytest
-from tests.mocks.limsmock import MockLimsAPI
-from tests.mocks.osticket import MockOsTicket
 
 from cg.meta.orders import OrdersAPI
 from cg.meta.orders.api import FastqSubmitter
@@ -13,8 +11,9 @@ from cg.meta.orders.mip_dna_submitter import MipDnaSubmitter
 from cg.meta.orders.mip_rna_submitter import MipRnaSubmitter
 from cg.meta.orders.rml_submitter import RmlSubmitter
 from cg.meta.orders.ticket_handler import TicketHandler
+from cg.meta.orders.tomte_submitter import TomteSubmitter
 from cg.models.orders.order import OrderIn, OrderType
-from cg.store import Store
+from cg.store.store import Store
 from tests.apps.orderform.conftest import (
     balsamic_order_to_submit,
     fastq_order_to_submit,
@@ -23,13 +22,16 @@ from tests.apps.orderform.conftest import (
     mip_order_to_submit,
     mip_rna_order_to_submit,
     rml_order_to_submit,
-    fixture_rnafusion_order_to_submit,
+    rnafusion_order_to_submit,
     sarscov2_order_to_submit,
+    tomte_order_to_submit,
 )
+from tests.mocks.limsmock import MockLimsAPI
+from tests.mocks.osticket import MockOsTicket
 
 
-@pytest.fixture(scope="session", name="all_orders_to_submit")
-def fixture_all_orders_to_submit(
+@pytest.fixture(scope="session")
+def all_orders_to_submit(
     balsamic_order_to_submit: dict,
     fastq_order_to_submit: dict,
     metagenome_order_to_submit: dict,
@@ -120,11 +122,19 @@ def rml_status_data(rml_order_to_submit):
     return RmlSubmitter.order_to_status(order=order)
 
 
+@pytest.fixture
+def tomte_status_data(tomte_order_to_submit: dict):
+    """Parse TOMTE order example."""
+    project: OrderType = OrderType.TOMTE
+    order: OrderIn = OrderIn.parse_obj(obj=tomte_order_to_submit, project=project)
+    return TomteSubmitter.order_to_status(order=order)
+
+
 @pytest.fixture(scope="function")
 def orders_api(base_store, osticket: MockOsTicket, lims_api: MockLimsAPI):
     return OrdersAPI(lims=lims_api, status=base_store, osticket=osticket)
 
 
-@pytest.fixture(name="ticket_handler")
-def fixture_ticket_handler(store: Store, osticket: MockOsTicket) -> TicketHandler:
+@pytest.fixture
+def ticket_handler(store: Store, osticket: MockOsTicket) -> TicketHandler:
     return TicketHandler(status_db=store, osticket_api=osticket)
