@@ -1,8 +1,6 @@
-from typing import List
-
 import pytest
 
-from cg.constants import Pipeline
+from cg.constants import Workflow
 from cg.meta.orders.lims import build_lims_sample
 from cg.models.lims.sample import LimsSample
 from cg.models.orders.constants import OrderType
@@ -13,7 +11,7 @@ def test_to_lims_mip(mip_order_to_submit):
     # GIVEN a scout order for a trio
     order_data = OrderIn.parse_obj(obj=mip_order_to_submit, project=OrderType.MIP_DNA)
     # WHEN parsing the order to format for LIMS import
-    samples: List[LimsSample] = build_lims_sample(customer="cust003", samples=order_data.samples)
+    samples: list[LimsSample] = build_lims_sample(customer="cust003", samples=order_data.samples)
 
     # THEN it should list all samples
     assert len(samples) == 4
@@ -45,7 +43,7 @@ def test_to_lims_fastq(fastq_order_to_submit):
     order_data = OrderIn.parse_obj(obj=fastq_order_to_submit, project=OrderType.FASTQ)
 
     # WHEN parsing the order to format for LIMS
-    samples: List[LimsSample] = build_lims_sample(customer="dummyCust", samples=order_data.samples)
+    samples: list[LimsSample] = build_lims_sample(customer="dummyCust", samples=order_data.samples)
 
     # THEN should "work"
     assert len(samples) == 2
@@ -62,7 +60,7 @@ def test_to_lims_rml(rml_order_to_submit):
     order_data = OrderIn.parse_obj(obj=rml_order_to_submit, project=OrderType.RML)
 
     # WHEN parsing for LIMS
-    samples: List[LimsSample] = build_lims_sample(customer="dummyCust", samples=order_data.samples)
+    samples: list[LimsSample] = build_lims_sample(customer="dummyCust", samples=order_data.samples)
 
     # THEN it should have found the same number of samples
     assert len(samples) == 4
@@ -80,7 +78,7 @@ def test_to_lims_microbial(microbial_order_to_submit):
     order_data = OrderIn.parse_obj(obj=microbial_order_to_submit, project=OrderType.MICROSALT)
 
     # WHEN parsing for LIMS
-    samples: List[LimsSample] = build_lims_sample(customer="cust000", samples=order_data.samples)
+    samples: list[LimsSample] = build_lims_sample(customer="cust000", samples=order_data.samples)
     # THEN it should "work"
 
     assert len(samples) == 5
@@ -101,15 +99,15 @@ def test_to_lims_sarscov2(sarscov2_order_to_submit):
     order_data = OrderIn.parse_obj(obj=sarscov2_order_to_submit, project=OrderType.SARS_COV_2)
 
     # WHEN parsing for LIMS
-    samples: List[LimsSample] = build_lims_sample(customer="cust000", samples=order_data.samples)
+    samples: list[LimsSample] = build_lims_sample(customer="cust000", samples=order_data.samples)
 
     # THEN it should have found the same number of samples
-    assert len(samples) == 5
+    assert len(samples) == 6
     # ... and pick out relevant UDFs
     first_sample = samples[0].dict()
     assert first_sample["udfs"]["collection_date"] == "2021-05-05"
     assert first_sample["udfs"]["extraction_method"] == "MagNaPure 96"
-    assert first_sample["udfs"]["lab_code"] == "SE110 Växjö"
+    assert first_sample["udfs"]["lab_code"] == "SE100 Karolinska"
     assert first_sample["udfs"]["organism"] == "SARS CoV-2"
     assert first_sample["udfs"]["original_lab"] == "Karolinska University Hospital Solna"
     assert first_sample["udfs"]["original_lab_address"] == "171 76 Stockholm"
@@ -130,7 +128,7 @@ def test_to_lims_balsamic(balsamic_order_to_submit, project):
     order_data = OrderIn.parse_obj(obj=balsamic_order_to_submit, project=project)
 
     # WHEN parsing the order to format for LIMS import
-    samples: List[LimsSample] = build_lims_sample(customer="cust000", samples=order_data.samples)
+    samples: list[LimsSample] = build_lims_sample(customer="cust000", samples=order_data.samples)
     # THEN it should list all samples
 
     assert len(samples) == 1
@@ -143,9 +141,9 @@ def test_to_lims_balsamic(balsamic_order_to_submit, project):
     assert first_sample["name"] == "s1"
     assert {sample.container for sample in samples} == set(["96 well plate"])
     assert first_sample["udfs"]["data_analysis"] in [
-        str(Pipeline.BALSAMIC),
-        str(Pipeline.BALSAMIC_QC),
-        str(Pipeline.BALSAMIC_UMI),
+        Workflow.BALSAMIC,
+        Workflow.BALSAMIC_QC,
+        Workflow.BALSAMIC_UMI,
     ]
     assert first_sample["udfs"]["application"] == "WGSPCFC030"
     assert first_sample["udfs"]["sex"] == "M"
