@@ -1,15 +1,15 @@
 import datetime as dt
 from copy import deepcopy
-from typing import List
 
 import pytest
 
-from cg.constants import DataDelivery, Pipeline
+from cg.constants import DataDelivery, Priority, Workflow
 from cg.constants.constants import CaseActions, PrepCategory
 from cg.exc import OrderError
+from cg.meta.orders import OrdersAPI
 from cg.meta.orders.api import FastqSubmitter
-from cg.meta.orders.balsamic_submitter import BalsamicSubmitter
 from cg.meta.orders.balsamic_qc_submitter import BalsamicQCSubmitter
+from cg.meta.orders.balsamic_submitter import BalsamicSubmitter
 from cg.meta.orders.balsamic_umi_submitter import BalsamicUmiSubmitter
 from cg.meta.orders.metagenome_submitter import MetagenomeSubmitter
 from cg.meta.orders.microbial_submitter import MicrobialSubmitter
@@ -19,10 +19,8 @@ from cg.meta.orders.rml_submitter import RmlSubmitter
 from cg.meta.orders.sars_cov_2_submitter import SarsCov2Submitter
 from cg.meta.orders.submitter import Submitter
 from cg.models.orders.order import OrderIn, OrderType
-from cg.meta.orders import OrdersAPI
-from cg.store import Store
-from cg.store.models import Application, Delivery, Family, Pool, Sample
-from cg.constants import Priority
+from cg.store.models import Application, Case, Pool, Sample
+from cg.store.store import Store
 
 
 def test_pools_to_status(rml_order_to_submit):
@@ -42,7 +40,7 @@ def test_pools_to_status(rml_order_to_submit):
     pool = data["pools"][0]
     assert pool["name"] == "pool-1"
     assert pool["application"] == "RMLP05R800"
-    assert pool["data_analysis"] == str(Pipeline.FASTQ)
+    assert pool["data_analysis"] == Workflow.FASTQ
     assert pool["data_delivery"] == str(DataDelivery.FASTQ)
     assert len(pool["samples"]) == 2
     sample = pool["samples"][0]
@@ -85,7 +83,7 @@ def test_metagenome_to_status(metagenome_order_to_submit):
     assert first_sample["name"] == "Bristol"
     assert first_sample["application"] == "METLIFR020"
     assert first_sample["priority"] == "standard"
-    assert first_sample["volume"] == "1"
+    assert first_sample["volume"] == "1.0"
 
 
 def test_microbial_samples_to_status(microbial_order_to_submit):
@@ -100,7 +98,7 @@ def test_microbial_samples_to_status(microbial_order_to_submit):
     assert data["customer"] == "cust002"
     assert data["order"] == "Microbial samples"
     assert data["comment"] == "Order comment"
-    assert data["data_analysis"] == str(Pipeline.MICROSALT)
+    assert data["data_analysis"] == Workflow.MICROSALT
     assert data["data_delivery"] == str(DataDelivery.FASTQ)
 
     # THEN first sample should contain all the relevant data from the microbial order
@@ -123,11 +121,11 @@ def test_sarscov2_samples_to_status(sarscov2_order_to_submit):
     data = SarsCov2Submitter.order_to_status(order=order)
 
     # THEN it should pick out samples and relevant information
-    assert len(data["samples"]) == 5
+    assert len(data["samples"]) == 6
     assert data["customer"] == "cust002"
     assert data["order"] == "Sars-CoV-2 samples"
     assert data["comment"] == "Order comment"
-    assert data["data_analysis"] == str(Pipeline.SARS_COV_2)
+    assert data["data_analysis"] == Workflow.MUTANT
     assert data["data_delivery"] == str(DataDelivery.FASTQ)
 
     # THEN first sample should contain all the relevant data from the microbial order
@@ -154,7 +152,7 @@ def test_cases_to_status(mip_order_to_submit):
     assert len(data["families"]) == 2
     family = data["families"][0]
     assert family["name"] == "family1"
-    assert family["data_analysis"] == str(Pipeline.MIP_DNA)
+    assert family["data_analysis"] == Workflow.MIP_DNA
     assert family["data_delivery"] == str(DataDelivery.SCOUT)
     assert family["priority"] == Priority.standard.name
     assert family["cohorts"] == ["Other"]
@@ -199,7 +197,7 @@ def test_cases_to_status_synopsis(mip_order_to_submit):
 def test_store_rml(orders_api, base_store, rml_status_data, ticket_id: str):
     # GIVEN a basic store with no samples and a rml order
     assert base_store._get_query(table=Pool).count() == 0
-    assert base_store._get_query(table=Family).count() == 0
+    assert base_store._get_query(table=Case).count() == 0
     assert not base_store._get_query(table=Sample).first()
 
     submitter: RmlSubmitter = RmlSubmitter(lims=orders_api.lims, status=orders_api.status)
@@ -216,7 +214,7 @@ def test_store_rml(orders_api, base_store, rml_status_data, ticket_id: str):
     # THEN it should update the database with new pools
     assert len(new_pools) == 2
 
-    assert base_store._get_query(table=Pool).count() == base_store._get_query(table=Family).count()
+    assert base_store._get_query(table=Pool).count() == base_store._get_query(table=Case).count()
     assert len(base_store._get_query(table=Sample).all()) == 4
 
     # ASSERT that there is one negative sample
@@ -233,12 +231,8 @@ def test_store_rml(orders_api, base_store, rml_status_data, ticket_id: str):
     assert new_pool.application_version.application.tag == "RMLP05R800"
     assert not hasattr(new_pool, "data_analysis")
 
-    # ... and add a delivery
-    assert len(new_pool.deliveries) == 1
-    assert new_pool.deliveries[0].destination == "caesar"
-
     new_case = base_store.get_cases()[0]
-    assert new_case.data_analysis == str(Pipeline.FASTQ)
+    assert new_case.data_analysis == Workflow.FASTQ
     assert new_case.data_delivery == str(DataDelivery.FASTQ)
 
     # and that the pool is set for invoicing but not the samples of the pool
@@ -250,7 +244,7 @@ def test_store_rml(orders_api, base_store, rml_status_data, ticket_id: str):
 def test_store_samples(orders_api, base_store, fastq_status_data, ticket_id: str):
     # GIVEN a basic store with no samples and a fastq order
     assert not base_store._get_query(table=Sample).first()
-    assert base_store._get_query(table=Family).count() == 0
+    assert base_store._get_query(table=Case).count() == 0
 
     submitter: FastqSubmitter = FastqSubmitter(lims=orders_api.lims, status=orders_api.status)
 
@@ -266,21 +260,19 @@ def test_store_samples(orders_api, base_store, fastq_status_data, ticket_id: str
     # THEN it should store the samples and create a case for each sample
     assert len(new_samples) == 2
     assert len(base_store._get_query(table=Sample).all()) == 2
-    assert base_store._get_query(table=Family).count() == 2
+    assert base_store._get_query(table=Case).count() == 2
     first_sample = new_samples[0]
     assert len(first_sample.links) == 2
     family_link = first_sample.links[0]
-    assert family_link.family in base_store.get_cases()
-    for sample in new_samples:
-        assert len(sample.deliveries) == 1
-    assert family_link.family.data_analysis
-    assert family_link.family.data_delivery in [DataDelivery.FASTQ, DataDelivery.NO_DELIVERY]
+    assert family_link.case in base_store.get_cases()
+    assert family_link.case.data_analysis
+    assert family_link.case.data_delivery in [DataDelivery.FASTQ, DataDelivery.NO_DELIVERY]
 
 
 def test_store_samples_sex_stored(orders_api, base_store, fastq_status_data, ticket_id: str):
     # GIVEN a basic store with no samples and a fastq order
     assert not base_store._get_query(table=Sample).first()
-    assert base_store._get_query(table=Family).count() == 0
+    assert base_store._get_query(table=Case).count() == 0
 
     submitter = FastqSubmitter(lims=orders_api.lims, status=orders_api.status)
 
@@ -300,7 +292,7 @@ def test_store_samples_sex_stored(orders_api, base_store, fastq_status_data, tic
 def test_store_fastq_samples_non_tumour_wgs_to_mip(orders_api, base_store, fastq_status_data):
     # GIVEN a basic store with no samples and a non-tumour fastq order as wgs
     assert not base_store._get_query(table=Sample).first()
-    assert base_store._get_query(table=Family).count() == 0
+    assert base_store._get_query(table=Case).count() == 0
     base_store.get_application_by_tag(
         fastq_status_data["samples"][0]["application"]
     ).prep_category = PrepCategory.WHOLE_GENOME_SEQUENCING
@@ -318,7 +310,7 @@ def test_store_fastq_samples_non_tumour_wgs_to_mip(orders_api, base_store, fastq
     )
 
     # THEN the analysis for the case should be MAF
-    assert new_samples[0].links[0].family.data_analysis == Pipeline.MIP_DNA
+    assert new_samples[0].links[0].case.data_analysis == Workflow.MIP_DNA
 
 
 def test_store_fastq_samples_tumour_wgs_to_fastq(
@@ -326,7 +318,7 @@ def test_store_fastq_samples_tumour_wgs_to_fastq(
 ):
     # GIVEN a basic store with no samples and a tumour fastq order as wgs
     assert not base_store._get_query(table=Sample).first()
-    assert base_store._get_query(table=Family).count() == 0
+    assert base_store._get_query(table=Case).count() == 0
     base_store.get_application_by_tag(
         fastq_status_data["samples"][0]["application"]
     ).prep_category = PrepCategory.WHOLE_GENOME_SEQUENCING
@@ -344,7 +336,7 @@ def test_store_fastq_samples_tumour_wgs_to_fastq(
     )
 
     # THEN the analysis for the case should be FASTQ
-    assert new_samples[0].links[0].family.data_analysis == Pipeline.FASTQ
+    assert new_samples[0].links[0].case.data_analysis == Workflow.FASTQ
 
 
 def test_store_fastq_samples_non_wgs_as_fastq(
@@ -352,7 +344,7 @@ def test_store_fastq_samples_non_wgs_as_fastq(
 ):
     # GIVEN a basic store with no samples and a fastq order as non wgs
     assert not base_store._get_query(table=Sample).first()
-    assert base_store._get_query(table=Family).count() == 0
+    assert base_store._get_query(table=Case).count() == 0
     non_wgs_prep_category = PrepCategory.WHOLE_EXOME_SEQUENCING
 
     non_wgs_applications = base_store._get_query(table=Application).filter(
@@ -376,13 +368,13 @@ def test_store_fastq_samples_non_wgs_as_fastq(
     )
 
     # THEN the analysis for the case should be fastq (none)
-    assert new_samples[0].links[0].family.data_analysis == Pipeline.FASTQ
+    assert new_samples[0].links[0].case.data_analysis == Workflow.FASTQ
 
 
 def test_store_samples_bad_apptag(orders_api, base_store, fastq_status_data, ticket_id: str):
     # GIVEN a basic store with no samples and a fastq order
     assert not base_store._get_query(table=Sample).first()
-    assert base_store._get_query(table=Family).count() == 0
+    assert base_store._get_query(table=Case).count() == 0
 
     for sample in fastq_status_data["samples"]:
         sample["application"] = "nonexistingtag"
@@ -404,7 +396,7 @@ def test_store_samples_bad_apptag(orders_api, base_store, fastq_status_data, tic
 def test_store_microbial_samples(orders_api, base_store, microbial_status_data, ticket_id: str):
     # GIVEN a basic store with no samples and a microbial order and one Organism
     assert not base_store._get_query(table=Sample).first()
-    assert base_store._get_query(table=Family).count() == 0
+    assert base_store._get_query(table=Case).count() == 0
     assert base_store.get_all_organisms().count() == 1
 
     submitter = MicrobialSubmitter(lims=orders_api.lims, status=orders_api.status)
@@ -417,14 +409,14 @@ def test_store_microbial_samples(orders_api, base_store, microbial_status_data,
         ticket_id=ticket_id,
         items=microbial_status_data["samples"],
         comment="",
-        data_analysis=Pipeline.MICROSALT,
+        data_analysis=Workflow.MICROSALT,
         data_delivery=DataDelivery.FASTQ_QC,
     )
 
     # THEN it should store the samples under a case (case) and the used previously unknown
     # organisms
     assert new_samples
-    assert base_store._get_query(table=Family).count() == 1
+    assert base_store._get_query(table=Case).count() == 1
     assert len(new_samples) == 5
     assert len(base_store._get_query(table=Sample).all()) == 5
     assert base_store.get_all_organisms().count() == 3
@@ -435,7 +427,7 @@ def test_store_microbial_case_data_analysis_stored(
 ):
     # GIVEN a basic store with no samples and a microbial order and one Organism
     assert not base_store._get_query(table=Sample).first()
-    assert base_store._get_query(table=Family).count() == 0
+    assert base_store._get_query(table=Case).count() == 0
 
     submitter = MicrobialSubmitter(lims=orders_api.lims, status=orders_api.status)
 
@@ -447,16 +439,16 @@ def test_store_microbial_case_data_analysis_stored(
         ticket_id=ticket_id,
         items=microbial_status_data["samples"],
         comment="",
-        data_analysis=Pipeline.MICROSALT,
+        data_analysis=Workflow.MICROSALT,
         data_delivery=DataDelivery.FASTQ_QC,
     )
 
     # THEN store the samples under a case with the microbial data_analysis type on case level
     assert len(base_store._get_query(table=Sample).all()) > 0
-    assert base_store._get_query(table=Family).count() == 1
+    assert base_store._get_query(table=Case).count() == 1
 
     microbial_case = base_store.get_cases()[0]
-    assert microbial_case.data_analysis == str(Pipeline.MICROSALT)
+    assert microbial_case.data_analysis == Workflow.MICROSALT
     assert microbial_case.data_delivery == str(DataDelivery.FASTQ_QC)
 
 
@@ -476,7 +468,7 @@ def test_store_microbial_sample_priority(
         ticket_id=ticket_id,
         items=microbial_status_data["samples"],
         comment="",
-        data_analysis=Pipeline.MICROSALT,
+        data_analysis=Workflow.MICROSALT,
         data_delivery=DataDelivery.FASTQ_QC,
     )
 
@@ -512,7 +504,7 @@ def test_store_mip(orders_api, base_store: Store, mip_status_data, ticket_id: st
 
     assert len(new_case.links) == 3
     new_link = new_case.links[0]
-    assert new_case.data_analysis == str(Pipeline.MIP_DNA)
+    assert new_case.data_analysis == Workflow.MIP_DNA
     assert new_case.data_delivery == str(DataDelivery.SCOUT)
     assert set(new_case.cohorts) == {"Other"}
     assert (
@@ -534,12 +526,6 @@ def test_store_mip(orders_api, base_store: Store, mip_status_data, ticket_id: st
 
     assert new_link.sample.age_at_sampling == 17.18192
 
-    assert base_store._get_query(table=Delivery).count() == len(
-        base_store._get_query(table=Sample).all()
-    )
-    for link in new_case.links:
-        assert len(link.sample.deliveries) == 1
-
 
 def test_store_mip_rna(orders_api, base_store, mip_rna_status_data, ticket_id: str):
     # GIVEN a basic store with no samples or nothing in it + rna order
@@ -565,7 +551,7 @@ def test_store_mip_rna(orders_api, base_store, mip_rna_status_data, ticket_id: s
 
     assert len(new_casing.links) == 2
     new_link = new_casing.links[0]
-    assert new_casing.data_analysis == str(Pipeline.MIP_RNA)
+    assert new_casing.data_analysis == Workflow.MIP_RNA
     assert new_casing.data_delivery == str(DataDelivery.SCOUT)
     assert new_link.sample.name == "sample1-rna-t1"
     assert new_link.sample.application_version.application.tag == rna_application_tag
@@ -640,12 +626,12 @@ def test_store_cancer_samples(
     new_case = new_families[0]
     assert new_case.name == "family1"
     assert new_case.data_analysis in [
-        str(Pipeline.BALSAMIC),
-        str(Pipeline.BALSAMIC_QC),
-        str(Pipeline.BALSAMIC_UMI),
+        Workflow.BALSAMIC,
+        Workflow.BALSAMIC_QC,
+        Workflow.BALSAMIC_UMI,
     ]
     assert new_case.data_delivery == str(DataDelivery.FASTQ_ANALYSIS_SCOUT)
-    assert set(new_case.panels) == set()
+    assert not set(new_case.panels)
     assert new_case.priority_human == Priority.standard.name
 
     assert len(new_case.links) == 1
@@ -656,12 +642,6 @@ def test_store_cancer_samples(
     assert new_link.sample.comment == "other Elution buffer"
     assert new_link.sample.is_tumour
 
-    assert base_store._get_query(table=Delivery).count() == len(
-        base_store._get_query(table=Sample).all()
-    )
-    for link in new_case.links:
-        assert len(link.sample.deliveries) == 1
-
 
 def test_store_existing_single_sample_from_trio(
     orders_api, base_store, mip_status_data, ticket_id: str
@@ -740,7 +720,7 @@ def test_store_existing_case(
     )
 
     base_store.session.close()
-    new_cases: List[Family] = base_store.get_cases()
+    new_cases: list[Case] = base_store.get_cases()
 
     # Save internal id
     stored_cases_internal_ids = dict([(case.name, case.internal_id) for case in new_cases])
@@ -756,7 +736,7 @@ def test_store_existing_case(
     )
 
     base_store.session.close()
-    rerun_cases: List[Family] = base_store.get_cases()
+    rerun_cases: list[Case] = base_store.get_cases()
 
     # THEN the sample ticket should be appended to previos ticket and action set to analyze
     assert rerun_cases[0].tickets == f"{ticket_id},{ticket_id}"
