@@ -2,36 +2,36 @@ from pathlib import Path
 
 import pytest
 
-from cg.store.models import Family
+from cg.constants.constants import Workflow
 from cg.models.cg_config import CGConfig
-from cgmodels.cg.constants import Pipeline
+from cg.store.models import Case
 
 
-@pytest.fixture(name="mutant_case")
-def fixture_mutant_case(cg_context: CGConfig, case_id: str, ticket_id: str, helpers) -> Family:
+@pytest.fixture
+def mutant_case(cg_context: CGConfig, case_id: str, ticket_id: str, helpers) -> Case:
     """Return mutant case"""
     case = helpers.add_case(
         store=cg_context.status_db,
         internal_id=case_id,
         name=ticket_id,
-        data_analysis=Pipeline.SARS_COV_2,
+        data_analysis=Workflow.MUTANT,
     )
     return case
 
 
-@pytest.fixture(name="microsalt_case")
-def fixture_microsalt_case(cg_context: CGConfig, case_id: str, ticket_id: str, helpers) -> Family:
+@pytest.fixture
+def microsalt_case(cg_context: CGConfig, case_id: str, ticket_id: str, helpers) -> Case:
     """Return mutant case"""
     case = helpers.add_case(
         store=cg_context.status_db,
         internal_id=case_id,
         name=ticket_id,
-        data_analysis=Pipeline.MICROSALT,
+        data_analysis=Workflow.MICROSALT,
     )
     return case
 
 
-@pytest.fixture(name="destination_path")
-def fixture_destination_path() -> Path:
+@pytest.fixture
+def destination_path() -> Path:
     """Retyrbs a dummy path."""
     return Path("path", "to", "destination")
