@@ -1,8 +1,8 @@
 """Mock models from the store. Used for processing them without using the store"""
-import datetime
-from typing import List
 
-from cg.store.models import Analysis, Customer, Family
+import datetime
+
+from cg.store.models import Analysis, Case, Customer
 
 
 class Customer(Customer):
@@ -12,12 +12,12 @@ class Customer(Customer):
         self.internal_id = "cust000"
 
 
-class Family(Family):
+class Case(Case):
     """Mock a case object"""
 
     def __init__(self):
         self.id: int = 1
-        self.panels: List[str] = ["PEDHEP"]
+        self.panels: list[str] = ["PEDHEP"]
         self.internal_id: str = "yellowhog"
         self.name: str = "analysis_family"
         self.customer: Customer = Customer()
@@ -29,4 +29,4 @@ class Analysis(Analysis):
     def __init__(self):
         self.id = 1
         self.completed_at = datetime.datetime.now()
-        self.family: Family = Family()
+        self.case: Case = Case()
