@@ -1,35 +1,47 @@
 """Utility functions to simply add test data in a cg store."""
+
 import logging
 from datetime import datetime
-from typing import List, Optional, Dict
+from pathlib import Path
 
 from housekeeper.store.models import Bundle, Version
 
 from cg.apps.housekeeper.hk import HousekeeperAPI
-from cg.constants import DataDelivery, Pipeline
+from cg.constants import DataDelivery, SequencingRunDataAvailability, Workflow
+from cg.constants.devices import DeviceType
 from cg.constants.pedigree import Pedigree
 from cg.constants.priority import PriorityTerms
 from cg.constants.sequencing import Sequencers
-from cg.constants.subject import Gender, PhenotypeStatus
-from cg.store import Store
+from cg.constants.subject import PhenotypeStatus, Sex
+from cg.models.run_devices.illumina_run_directory_data import IlluminaRunDirectoryData
+from cg.services.illumina.data_transfer.models import (
+    IlluminaFlowCellDTO,
+    IlluminaSampleSequencingMetricsDTO,
+    IlluminaSequencingRunDTO,
+)
 from cg.store.models import (
     Analysis,
     Application,
+    ApplicationLimitations,
     ApplicationVersion,
     Bed,
     BedVersion,
+    Case,
+    CaseSample,
     Collaboration,
     Customer,
-    Family,
-    FamilySample,
-    Flowcell,
+    IlluminaFlowCell,
+    IlluminaSampleSequencingMetrics,
+    IlluminaSequencingRun,
     Invoice,
+    Order,
     Organism,
     Panel,
     Pool,
     Sample,
     User,
 )
+from cg.store.store import Store
 
 LOG = logging.getLogger(__name__)
 
@@ -59,14 +71,52 @@ class StoreHelpers:
 
         return _bundle
 
+    @staticmethod
+    def format_hk_bundle_dict(
+        bundle_name: str, files: list[Path], all_tags: list[list[str]]
+    ) -> dict:
+        """Creates the dict representation for a housekeeper bundle with necessary values set."""
+        return {
+            "name": bundle_name,
+            "created_at": datetime.now(),
+            "expires_at": datetime.now(),
+            "files": [
+                {
+                    "path": file.as_posix(),
+                    "tags": tags,
+                    "archive": False,
+                }
+                for file, tags in zip(files, all_tags)
+            ],
+        }
+
+    @staticmethod
+    def quick_hk_bundle(
+        bundle_name: str, files: list[Path], store: HousekeeperAPI, tags: list[list[str]]
+    ):
+        """Adds a bundle to housekeeper with the given files and tags. Returns the new bundle.
+
+        Arguments:
+            bundle_name = The name of the bundle to be created.
+            files = A list of files to be added to the bundle.
+            store = The database instance where the bundle should be added.
+            tags = A list where each entry is the set of tags for the corresponding file.
+                   The length of this list should be the same as the length of the files list.
+        """
+        bundle_data: dict = StoreHelpers.format_hk_bundle_dict(
+            bundle_name=bundle_name, files=files, all_tags=tags
+        )
+        return StoreHelpers.ensure_hk_bundle(store=store, bundle_data=bundle_data)
+
     @staticmethod
     def ensure_hk_version(store: HousekeeperAPI, bundle_data: dict) -> Version:
         """Utility function to return existing or create an version for tests."""
         _bundle = StoreHelpers.ensure_hk_bundle(store, bundle_data)
         return store.last_version(_bundle.name)
 
-    @staticmethod
+    @classmethod
     def ensure_application_version(
+        cls,
         store: Store,
         application_tag: str = "dummy_tag",
         prep_category: str = "wgs",
@@ -86,7 +136,7 @@ class StoreHelpers:
 
         application: Application = store.get_application_by_tag(tag=application_tag)
         if not application:
-            application: Application = StoreHelpers.add_application(
+            application: Application = cls.add_application(
                 store=store,
                 application_tag=application_tag,
                 prep_category=prep_category,
@@ -117,7 +167,7 @@ class StoreHelpers:
     def add_application_version(
         store: Store,
         application: Application,
-        prices: Dict,
+        prices: dict,
         version: int = 1,
         valid_from: datetime = datetime.now(),
     ) -> ApplicationVersion:
@@ -138,8 +188,9 @@ class StoreHelpers:
         store.session.commit()
         return new_record
 
-    @staticmethod
+    @classmethod
     def ensure_application(
+        cls,
         store: Store,
         tag: str,
         prep_category: str = "wgs",
@@ -150,7 +201,7 @@ class StoreHelpers:
         """Ensure that application exists in store."""
         application: Application = store.get_application_by_tag(tag=tag)
         if not application:
-            application: Application = StoreHelpers.add_application(
+            application: Application = cls.add_application(
                 store=store,
                 application_tag=tag,
                 prep_category=prep_category,
@@ -196,10 +247,33 @@ class StoreHelpers:
         store.session.commit()
         return application
 
+    @staticmethod
+    def ensure_application_limitation(
+        store: Store,
+        application: Application,
+        workflow: str = Workflow.MIP_DNA,
+        limitations: str = "Dummy limitations",
+        **kwargs,
+    ) -> ApplicationLimitations:
+        """Ensure that application limitations exist in store."""
+        application_limitation: ApplicationLimitations = (
+            store.get_application_limitation_by_tag_and_workflow(
+                tag=application.tag, workflow=workflow
+            )
+        )
+        if application_limitation:
+            return application_limitation
+        application_limitation: ApplicationLimitations = store.add_application_limitation(
+            application=application, workflow=workflow, limitations=limitations, **kwargs
+        )
+        store.session.add(application_limitation)
+        store.session.commit()
+        return application_limitation
+
     @staticmethod
     def ensure_bed_version(store: Store, bed_name: str = "dummy_bed") -> BedVersion:
         """Return existing or create and return bed version for tests."""
-        bed: Optional[Bed] = store._get_query(table=Bed).filter(Bed.name == bed_name)
+        bed: Bed | None = store.get_bed_by_name(bed_name)
         if not bed:
             bed: Bed = store.add_bed(name=bed_name)
             store.session.add(bed)
@@ -218,15 +292,16 @@ class StoreHelpers:
             collaboration = store.add_collaboration(collaboration_id, collaboration_id)
         return collaboration
 
-    @staticmethod
+    @classmethod
     def ensure_customer(
+        cls,
         store: Store,
         customer_id: str = "cust000",
         customer_name: str = "Production",
         scout_access: bool = False,
     ) -> Customer:
         """Utility function to return existing or create customer for tests."""
-        collaboration: Collaboration = StoreHelpers.ensure_collaboration(store)
+        collaboration: Collaboration = cls.ensure_collaboration(store)
         customer: Customer = store.get_customer_by_internal_id(customer_internal_id=customer_id)
 
         if not customer:
@@ -245,26 +320,25 @@ class StoreHelpers:
     @staticmethod
     def add_analysis(
         store: Store,
-        case: Family = None,
+        case: Case = None,
         started_at: datetime = None,
         completed_at: datetime = None,
         uploaded_at: datetime = None,
         upload_started: datetime = None,
         delivery_reported_at: datetime = None,
         cleaned_at: datetime = None,
-        pipeline: Pipeline = Pipeline.BALSAMIC,
-        pipeline_version: str = "1.0",
+        workflow: Workflow = Workflow.BALSAMIC,
+        workflow_version: str = "1.0",
         data_delivery: DataDelivery = DataDelivery.FASTQ_QC,
         uploading: bool = False,
         config_path: str = None,
-        uploaded_to_vogue_at: datetime = None,
     ) -> Analysis:
         """Utility function to add an analysis for tests."""
 
         if not case:
-            case = StoreHelpers.add_case(store, data_analysis=pipeline, data_delivery=data_delivery)
+            case = StoreHelpers.add_case(store, data_analysis=workflow, data_delivery=data_delivery)
 
-        analysis = store.add_analysis(pipeline=pipeline, version=pipeline_version)
+        analysis = store.add_analysis(workflow=workflow, version=workflow_version, case_id=case.id)
 
         analysis.started_at = started_at or datetime.now()
         if completed_at:
@@ -279,13 +353,11 @@ class StoreHelpers:
             analysis.upload_started_at = upload_started or datetime.now()
         if config_path:
             analysis.config_path = config_path
-        if pipeline:
-            analysis.pipeline = str(pipeline)
-        if uploaded_to_vogue_at:
-            analysis.uploaded_to_vogue_at = uploaded_to_vogue_at
+        if workflow:
+            analysis.workflow = str(workflow)
 
         analysis.limitations = "A limitation"
-        analysis.family = case
+        analysis.case = case
         store.session.add(analysis)
         store.session.commit()
         return analysis
@@ -297,7 +369,7 @@ class StoreHelpers:
         application_type: str = "tgs",
         control: str = "",
         customer_id: str = None,
-        gender: str = Gender.FEMALE,
+        sex: str = Sex.FEMALE,
         is_external: bool = False,
         is_rna: bool = False,
         is_tumour: bool = False,
@@ -326,7 +398,7 @@ class StoreHelpers:
 
         sample = store.add_sample(
             name=name,
-            sex=gender,
+            sex=sex,
             control=control,
             original_ticket=original_ticket,
             tumour=is_tumour,
@@ -339,9 +411,7 @@ class StoreHelpers:
         sample.ordered_at = datetime.now()
 
         for key, value in kwargs.items():
-            if key == "flowcell":
-                sample.flowcells.append(kwargs["flowcell"])
-            elif hasattr(sample, key):
+            if hasattr(sample, key):
                 setattr(sample, key, value)
             else:
                 raise AttributeError(f"Unknown sample attribute/feature: {key}, {value}")
@@ -374,21 +444,22 @@ class StoreHelpers:
     def add_case(
         store: Store,
         name: str = "case_test",
-        data_analysis: str = Pipeline.MIP_DNA,
+        data_analysis: str = Workflow.MIP_DNA,
         data_delivery: DataDelivery = DataDelivery.SCOUT,
         action: str = None,
         internal_id: str = None,
         customer_id: str = "cust000",
-        panels: List[str] = [],
-        case_obj: Family = None,
+        panels: list[str] = [],
+        priority: str = PriorityTerms.STANDARD,
+        case_obj: Case = None,
         ticket: str = "123456",
-    ) -> Family:
+    ) -> Case:
         """Utility function to add a case to use in tests,
         If no case object is used a autogenerated case id will be used.
 
         """
         if not panels:
-            panels: List[str] = ["panel_test"]
+            panels: list[str] = ["panel_test"]
         customer = StoreHelpers.ensure_customer(store, customer_id=customer_id)
         if case_obj:
             panels = case_obj.panels
@@ -398,7 +469,7 @@ class StoreHelpers:
             )
 
         if not case_obj:
-            case_obj: Optional[Family] = store.get_case_by_internal_id(internal_id=name)
+            case_obj: Case | None = store.get_case_by_internal_id(internal_id=name)
         if not case_obj:
             case_obj = store.add_case(
                 data_analysis=data_analysis,
@@ -406,6 +477,7 @@ class StoreHelpers:
                 name=name,
                 panels=panels,
                 ticket=ticket,
+                priority=priority,
             )
         if action:
             case_obj.action = action
@@ -417,15 +489,31 @@ class StoreHelpers:
         store.session.commit()
         return case_obj
 
+    @staticmethod
+    def add_order(
+        store: Store,
+        customer_id: int,
+        ticket_id: int,
+        order_date: datetime = datetime(year=2023, month=12, day=24),
+        workflow: Workflow = Workflow.MIP_DNA,
+    ) -> Order:
+        order = Order(
+            customer_id=customer_id, ticket_id=ticket_id, order_date=order_date, workflow=workflow
+        )
+        store.session.add(order)
+        store.session.commit()
+        return order
+
     @staticmethod
     def ensure_case(
         store: Store,
         case_name: str = "test-case",
         case_id: str = "blueeagle",
         customer: Customer = None,
-        data_analysis: Pipeline = Pipeline.MIP_DNA,
+        data_analysis: Workflow = Workflow.MIP_DNA,
         data_delivery: DataDelivery = DataDelivery.SCOUT,
         action: str = None,
+        order: Order = None,
     ):
         """Load a case with samples and link relations."""
         if not customer:
@@ -443,6 +531,8 @@ class StoreHelpers:
                 action=action,
             )
             case.customer = customer
+        if order:
+            store.link_case_to_order(order_id=order.id, case_id=case.id)
         return case
 
     @staticmethod
@@ -453,15 +543,16 @@ class StoreHelpers:
         ordered_at: datetime = None,
         completed_at: datetime = None,
         created_at: datetime = datetime.now(),
+        started_at: datetime = None,
     ):
         """Load a case with samples and link relations from a dictionary."""
         customer_obj = StoreHelpers.ensure_customer(store)
-        case = Family(
+        case = Case(
             name=case_info["name"],
             panels=case_info["panels"],
             internal_id=case_info["internal_id"],
             ordered_at=ordered_at,
-            data_analysis=case_info.get("data_analysis", str(Pipeline.MIP_DNA)),
+            data_analysis=case_info.get("data_analysis", Workflow.MIP_DNA),
             data_delivery=case_info.get("data_delivery", str(DataDelivery.SCOUT)),
             created_at=created_at,
             action=case_info.get("action"),
@@ -479,13 +570,13 @@ class StoreHelpers:
             sample_id = sample_data["internal_id"]
             sample_obj = StoreHelpers.add_sample(
                 store,
-                gender=sample_data["sex"],
-                name=sample_data.get("name"),
-                internal_id=sample_id,
-                application_type=app_type,
                 application_tag=app_tag,
-                original_ticket=sample_data["original_ticket"],
+                application_type=app_type,
+                sex=sample_data["sex"],
+                internal_id=sample_id,
                 reads=sample_data["reads"],
+                name=sample_data.get("name"),
+                original_ticket=sample_data["original_ticket"],
                 capture_kit=sample_data["capture_kit"],
             )
             sample_objs[sample_id] = sample_obj
@@ -503,9 +594,10 @@ class StoreHelpers:
 
         StoreHelpers.add_analysis(
             store,
-            pipeline=Pipeline.MIP_DNA,
             case=case,
+            started_at=started_at or datetime.now(),
             completed_at=completed_at or datetime.now(),
+            workflow=Workflow.MIP_DNA,
         )
         return case
 
@@ -560,21 +652,21 @@ class StoreHelpers:
             application_version=application_version,
             organism=organism,
             reads=6000000,
-            sex=Gender.UNKNOWN,
+            sex=Sex.UNKNOWN,
         )
         sample.customer = customer
         case = StoreHelpers.ensure_case(
             store=store,
             case_name=str(ticket),
             customer=customer,
-            data_analysis=Pipeline.MICROSALT,
+            data_analysis=Workflow.MICROSALT,
             data_delivery=DataDelivery.FASTQ_QC,
         )
         StoreHelpers.add_relationship(store=store, case=case, sample=sample)
         return sample
 
     @staticmethod
-    def add_samples(store: Store, nr_samples: int = 5) -> List[Sample]:
+    def add_samples(store: Store, nr_samples: int = 5) -> list[Sample]:
         """Utility function to add a number of samples to use in tests."""
         nr_samples = max(nr_samples, 2)
         return [
@@ -582,44 +674,176 @@ class StoreHelpers:
         ]
 
     @staticmethod
-    def add_flowcell(
-        store: Store,
-        flow_cell_name: str = "flowcell_test",
-        archived_at: datetime = None,
-        sequencer_type: str = Sequencers.HISEQX,
-        samples: List[Sample] = None,
-        status: str = None,
-        date: datetime = datetime.now(),
-    ) -> Flowcell:
-        """Utility function to add a flow cell to the store and return an object."""
-        flow_cell = store.add_flow_cell(
-            flow_cell_name=flow_cell_name,
-            sequencer_name="dummy_sequencer",
-            sequencer_type=sequencer_type,
-            date=date,
+    def add_illumina_flow_cell(
+        store: Store, flow_cell_id: str = "flow_cell_test", model: str = "10B"
+    ) -> IlluminaFlowCell:
+        """Add an Illumina flow cell to the store and return it assuming it does not exist."""
+        flow_cell_dto = IlluminaFlowCellDTO(
+            internal_id=flow_cell_id, type=DeviceType.ILLUMINA, model=model
         )
-        flow_cell.archived_at = archived_at
-        if samples:
-            flow_cell.samples = samples
-        if status:
-            flow_cell.status = status
-
-        store.session.add(flow_cell)
+        flow_cell: IlluminaFlowCell = store.add_illumina_flow_cell(flow_cell_dto)
         store.session.commit()
         return flow_cell
 
+    @classmethod
+    def ensure_illumina_flow_cell(
+        cls,
+        store: Store,
+        flow_cell_id: str = "flow_cell_test",
+        model: str = "10B",
+    ) -> IlluminaFlowCell:
+        """Return an Illumina flow cell if exists, otherwise add it to the store and return it."""
+        flow_cell: IlluminaFlowCell | None = store.get_illumina_flow_cell_by_internal_id(
+            internal_id=flow_cell_id
+        )
+        if flow_cell:
+            return flow_cell
+        flow_cell: IlluminaFlowCell = cls.add_illumina_flow_cell(
+            store=store, flow_cell_id=flow_cell_id, model=model
+        )
+        return flow_cell
+
+    @staticmethod
+    def add_illumina_sequencing_run(
+        store: Store,
+        flow_cell: IlluminaFlowCell,
+        timestamp_now: datetime = datetime.now(),
+        sequencer_type: Sequencers = Sequencers.NOVASEQ,
+        sequencer_name: str = "dummy_sequencer",
+        data_availability: SequencingRunDataAvailability = SequencingRunDataAvailability.ON_DISK,
+        archived_at: datetime = None,
+        has_backup: bool | None = False,
+    ) -> IlluminaSequencingRun:
+        """Add an Illumina sequencing run to the store and return it assuming it does not exist."""
+        illumina_run_dto = IlluminaSequencingRunDTO(
+            type=DeviceType.ILLUMINA,
+            sequencer_type=sequencer_type,
+            sequencer_name=sequencer_name,
+            data_availability=data_availability,
+            archived_at=archived_at,
+            has_backup=has_backup,
+            total_reads=100_000_000,
+            total_undetermined_reads=10,
+            percent_undetermined_reads=0.1,
+            percent_q30=90,
+            mean_quality_score=35,
+            total_yield=100,
+            yield_q30=50,
+            cycles=151,
+            demultiplexing_software="dragen",
+            demultiplexing_software_version="1.0.0",
+            sequencing_started_at=timestamp_now,
+            sequencing_completed_at=timestamp_now,
+            demultiplexing_started_at=timestamp_now,
+            demultiplexing_completed_at=timestamp_now,
+        )
+        illumina_run: IlluminaSequencingRun = store.add_illumina_sequencing_run(
+            sequencing_run_dto=illumina_run_dto, flow_cell=flow_cell
+        )
+        store.session.commit()
+        return illumina_run
+
+    @classmethod
+    def ensure_illumina_sequencing_run(
+        cls,
+        store: Store,
+        flow_cell: IlluminaFlowCell,
+        sequencer_type: Sequencers = Sequencers.NOVASEQ,
+        sequencer_name: str = "dummy_sequencer",
+        data_availability: SequencingRunDataAvailability = SequencingRunDataAvailability.ON_DISK,
+        archived_at: datetime = None,
+        has_backup: bool | None = False,
+    ) -> IlluminaSequencingRun:
+        """
+        Return an Illumina sequencing run if exists, otherwise add it to the store and return it.
+        """
+        illumina_run: IlluminaSequencingRun | None = (
+            store.get_illumina_sequencing_run_by_device_internal_id(
+                device_internal_id=flow_cell.internal_id
+            )
+        )
+        if illumina_run:
+            return illumina_run
+        illumina_run: IlluminaSequencingRun = cls.add_illumina_sequencing_run(
+            store=store,
+            flow_cell=flow_cell,
+            sequencer_type=sequencer_type,
+            sequencer_name=sequencer_name,
+            data_availability=data_availability,
+            archived_at=archived_at,
+            has_backup=has_backup,
+        )
+        return illumina_run
+
+    @staticmethod
+    def add_illumina_sample_sequencing_metrics_object(
+        store: Store, sample_id: str, sequencing_run: IlluminaSequencingRun, lane: int
+    ) -> IlluminaSampleSequencingMetrics:
+        """
+        Add an Illumina sample sequencing metrics object to the store given for a sample and lane,
+        and return it assuming it does not exist.
+        """
+
+        metrics_dto = IlluminaSampleSequencingMetricsDTO(
+            sample_id=sample_id,
+            type=DeviceType.ILLUMINA,
+            flow_cell_lane=lane,
+            total_reads_in_lane=100,
+            base_passing_q30_percent=90,
+            base_mean_quality_score=35,
+            yield_=100,
+            yield_q30=0.9,
+            created_at=datetime.now(),
+        )
+        metrics: IlluminaSampleSequencingMetrics = store.add_illumina_sample_metrics_entry(
+            metrics_dto=metrics_dto, sequencing_run=sequencing_run
+        )
+        store.session.commit()
+        return metrics
+
+    @classmethod
+    def ensure_illumina_sample_sequencing_metrics_object(
+        cls,
+        store: Store,
+        sequencing_run: IlluminaSequencingRun,
+        sample_id: str,
+        lane: int,
+    ) -> IlluminaSampleSequencingMetrics:
+        """
+        Return an Illumina sample sequencing metrics object if exists,
+        otherwise add it to the store and return it.
+        """
+        illumina_sample_metrics: IlluminaSampleSequencingMetrics | None = (
+            store.get_illumina_metrics_entry_by_device_sample_and_lane(
+                device_internal_id=sequencing_run.device.internal_id,
+                sample_internal_id=sample_id,
+                lane=lane,
+            )
+        )
+        if illumina_sample_metrics:
+            return illumina_sample_metrics
+        metrics: IlluminaSampleSequencingMetrics = (
+            cls.add_illumina_sample_sequencing_metrics_object(
+                store=store,
+                sample_id=sample_id,
+                sequencing_run=sequencing_run,
+                lane=lane,
+            )
+        )
+        return metrics
+
     @staticmethod
     def add_relationship(
         store: Store,
         sample: Sample,
-        case: Family,
+        case: Case,
         status: str = PhenotypeStatus.UNKNOWN,
         father: Sample = None,
         mother: Sample = None,
-    ) -> FamilySample:
+    ) -> CaseSample:
         """Utility function to link a sample to a case."""
         link = store.relate_sample(
-            sample=sample, family=case, status=status, father=father, mother=mother
+            sample=sample, case=case, status=status, father=father, mother=mother
         )
         store.session.add(link)
         store.session.commit()
@@ -628,9 +852,9 @@ class StoreHelpers:
     @staticmethod
     def add_synopsis_to_case(
         store: Store, case_id: str, synopsis: str = "a synopsis"
-    ) -> Optional[Family]:
+    ) -> Case | None:
         """Function for adding a synopsis to a case in the database."""
-        case_obj: Family = store.get_case_by_internal_id(internal_id=case_id)
+        case_obj: Case = store.get_case_by_internal_id(internal_id=case_id)
         if not case_obj:
             LOG.warning("Could not find case")
             return None
@@ -641,7 +865,7 @@ class StoreHelpers:
     @staticmethod
     def add_phenotype_groups_to_sample(
         store: Store, sample_id: str, phenotype_groups: [str] = None
-    ) -> Optional[Sample]:
+    ) -> Sample | None:
         """Function for adding a phenotype group to a sample in the database."""
         if phenotype_groups is None:
             phenotype_groups = ["a phenotype group"]
@@ -655,11 +879,11 @@ class StoreHelpers:
 
     @staticmethod
     def add_phenotype_terms_to_sample(
-        store: Store, sample_id: str, phenotype_terms: List[str] = []
-    ) -> Optional[Sample]:
+        store: Store, sample_id: str, phenotype_terms: list[str] = []
+    ) -> Sample | None:
         """Function for adding a phenotype term to a sample in the database."""
         if not phenotype_terms:
-            phenotype_terms: List[str] = ["a phenotype term"]
+            phenotype_terms: list[str] = ["a phenotype term"]
         sample_obj: Sample = store.get_sample_by_internal_id(internal_id=sample_id)
         if not sample_obj:
             LOG.warning("Could not find sample")
@@ -671,7 +895,7 @@ class StoreHelpers:
     @staticmethod
     def add_subject_id_to_sample(
         store: Store, sample_id: str, subject_id: str = "a subject_id"
-    ) -> Optional[Sample]:
+    ) -> Sample | None:
         """Function for adding a subject_id to a sample in the database."""
         sample_obj: Sample = store.get_sample_by_internal_id(internal_id=sample_id)
         if not sample_obj:
@@ -682,12 +906,12 @@ class StoreHelpers:
         return sample_obj
 
     @classmethod
-    def relate_samples(cls, base_store: Store, case: Family, samples: List[Sample]):
+    def relate_samples(cls, base_store: Store, case: Case, samples: list[Sample]):
         """Utility function to relate many samples to one case."""
 
         for sample in samples:
             link = base_store.relate_sample(
-                family=case, sample=sample, status=PhenotypeStatus.UNKNOWN
+                case=case, sample=sample, status=PhenotypeStatus.UNKNOWN
             )
             base_store.session.add(link)
             base_store.session.commit()
@@ -699,25 +923,25 @@ class StoreHelpers:
         case_id: str,
         nr_samples: int,
         sequenced_at: datetime = datetime.now(),
-    ) -> Family:
+    ) -> Case:
         """Utility function to add one case with many samples and return the case."""
 
-        samples: List[Sample] = cls.add_samples(store=base_store, nr_samples=nr_samples)
+        samples: list[Sample] = cls.add_samples(store=base_store, nr_samples=nr_samples)
         for sample in samples:
-            sample.sequenced_at: datetime = sequenced_at
-        case: Family = cls.add_case(store=base_store, internal_id=case_id, name=case_id)
+            sample.last_sequenced_at: datetime = sequenced_at
+        case: Case = cls.add_case(store=base_store, internal_id=case_id, name=case_id)
         cls.relate_samples(base_store=base_store, case=case, samples=samples)
         return case
 
     @classmethod
     def add_cases_with_samples(
         cls, base_store: Store, nr_cases: int, sequenced_at: datetime
-    ) -> List[Family]:
+    ) -> list[Case]:
         """Utility function to add many cases with two samples to use in tests."""
 
-        cases: List[Family] = []
+        cases: list[Case] = []
         for i in range(nr_cases):
-            case: List[Family] = cls.add_case_with_samples(
+            case: list[Case] = cls.add_case_with_samples(
                 base_store, f"f{i}", 2, sequenced_at=sequenced_at
             )
             cases.append(case)
@@ -792,9 +1016,9 @@ class StoreHelpers:
         invoice_id: int = 0,
         customer_id: str = "cust000",
         discount: int = 0,
-        pools: Optional[List[Pool]] = None,
-        samples: Optional[List[Sample]] = None,
-        invoiced_at: Optional[datetime] = None,
+        pools: list[Pool] | None = None,
+        samples: list[Sample] | None = None,
+        invoiced_at: datetime | None = None,
     ) -> Invoice:
         """Utility function to create an invoice with a costumer and samples or pools."""
         invoice = store.get_invoice_by_entry_id(entry_id=invoice_id)
@@ -820,10 +1044,43 @@ class StoreHelpers:
         return invoice
 
     @classmethod
-    def add_case_with_sample(cls, base_store: Store, case_id: str, sample_id: str) -> Family:
+    def add_case_with_sample(cls, base_store: Store, case_id: str, sample_id: str) -> Case:
         """Helper function to add a case associated with a sample with the given ids."""
 
         case = cls.add_case(store=base_store, internal_id=case_id, name=case_id)
         sample = cls.add_sample(store=base_store, internal_id=sample_id)
         cls.add_relationship(store=base_store, sample=sample, case=case)
         return case
+
+    @classmethod
+    def add_illumina_flow_cell_and_samples_with_sequencing_metrics(
+        cls,
+        run_directory_data: IlluminaRunDirectoryData,
+        sample_ids: list[str],
+        case_ids: list[str],
+        store: Store,
+    ) -> None:
+        """Add an Illumina flow cell and the given samples with sequencing metrics to a store."""
+        flow_cell: IlluminaFlowCell = cls.add_illumina_flow_cell(
+            store=store,
+            flow_cell_id=run_directory_data.id,
+        )
+        sequencing_run: IlluminaSequencingRun = cls.add_illumina_sequencing_run(
+            store=store,
+            flow_cell=flow_cell,
+            sequencer_type=run_directory_data.sequencer_type,
+        )
+        for i, sample_id in enumerate(sample_ids):
+            cls.add_case(store=store, internal_id=case_ids[i], name=case_ids[i])
+            cls.add_sample(store=store, internal_id=sample_id, name=f"sample_{i}")
+            cls.relate_samples(
+                base_store=store,
+                case=store.get_case_by_internal_id(case_ids[i]),
+                samples=[store.get_sample_by_internal_id(sample_id)],
+            )
+            cls.add_illumina_sample_sequencing_metrics_object(
+                store=store,
+                sample_id=sample_id,
+                sequencing_run=sequencing_run,
+                lane=i + 1,
+            )
